@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -28,6 +28,7 @@ import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Properties;
 import java.util.Set;
 import java.util.SortedMap;
@@ -68,7 +69,12 @@ import static org.junit.Assert.*;
  * @author Chris Beams
  * @author Dave Syer
  */
-public final class BeanWrapperTests {
+public final class BeanWrapperTests extends AbstractConfigurablePropertyAccessorTests {
+
+	@Override
+	protected ConfigurablePropertyAccessor createAccessor(Object target) {
+		return new BeanWrapperImpl(target);
+	}
 
 	@Test
 	public void testNullNestedTypeDescriptor() {
@@ -116,48 +122,6 @@ public final class BeanWrapperTests {
 		assertEquals("9", foo.listOfMaps.get(0).get("luckyNumber"));
 	}
 
-	@Test
-	public void testIsReadablePropertyNotReadable() {
-		NoRead nr = new NoRead();
-		BeanWrapper bw = new BeanWrapperImpl(nr);
-		assertFalse(bw.isReadableProperty("age"));
-	}
-
-	/**
-	 * Shouldn't throw an exception: should just return false
-	 */
-	@Test
-	public void testIsReadablePropertyNoSuchProperty() {
-		NoRead nr = new NoRead();
-		BeanWrapper bw = new BeanWrapperImpl(nr);
-		assertFalse(bw.isReadableProperty("xxxxx"));
-	}
-
-	@Test
-	public void testIsReadablePropertyNull() {
-		NoRead nr = new NoRead();
-		BeanWrapper bw = new BeanWrapperImpl(nr);
-		try {
-			bw.isReadableProperty(null);
-			fail("Can't inquire into readability of null property");
-		}
-		catch (IllegalArgumentException ex) {
-			// expected
-		}
-	}
-
-	@Test
-	public void testIsWritablePropertyNull() {
-		NoRead nr = new NoRead();
-		BeanWrapper bw = new BeanWrapperImpl(nr);
-		try {
-			bw.isWritableProperty(null);
-			fail("Can't inquire into writability of null property");
-		}
-		catch (IllegalArgumentException ex) {
-			// expected
-		}
-	}
 
 	@Test
 	public void testReadableAndWritableForIndexedProperties() {
@@ -554,6 +518,36 @@ public final class BeanWrapperTests {
 		assertTrue("correct values", pt.stringArray[0].equals("a1") && pt.stringArray[1].equals("b2"));
 	}
 
+	@Test
+	public void testStringArrayAutoGrow() throws Exception {
+		StringArrayBean target = new StringArrayBean();
+		BeanWrapper bw = new BeanWrapperImpl(target);
+		bw.setAutoGrowNestedPaths(true);
+
+		bw.setPropertyValue("array[0]", "Test0");
+		assertEquals(1, target.getArray().length);
+
+		bw.setPropertyValue("array[2]", "Test2");
+		assertEquals(3, target.getArray().length);
+		assertTrue("correct values", target.getArray()[0].equals("Test0") && target.getArray()[1] == null &&
+				target.getArray()[2].equals("Test2"));
+	}
+
+	@Test
+	public void testPrimitiveArrayAutoGrow() throws Exception {
+		PrimitiveArrayBean target = new PrimitiveArrayBean();
+		BeanWrapper bw = new BeanWrapperImpl(target);
+		bw.setAutoGrowNestedPaths(true);
+
+		bw.setPropertyValue("array[0]", 1);
+		assertEquals(1, target.getArray().length);
+
+		bw.setPropertyValue("array[2]", 3);
+		assertEquals(3, target.getArray().length);
+		assertTrue("correct values", target.getArray()[0] == 1 && target.getArray()[1] == 0 &&
+				target.getArray()[2] == 3);
+	}
+
 	@Test
 	public void testStringPropertyWithCustomEditor() throws Exception {
 		TestBean tb = new TestBean();
@@ -1574,9 +1568,45 @@ public final class BeanWrapperTests {
 		BeanWrapperImpl bwi = new BeanWrapperImpl(foo);
 		bwi.setPropertyValue("object", "a String");
 		assertEquals("a String", foo.value);
+		assertTrue(foo.getObject() == 8);
 		assertEquals(8, bwi.getPropertyValue("object"));
 	}
 
+	@Test
+	public void testGetterWithOptional() {
+		GetterWithOptional foo = new GetterWithOptional();
+		TestBean tb = new TestBean("x");
+		BeanWrapperImpl bwi = new BeanWrapperImpl(foo);
+
+		bwi.setPropertyValue("object", tb);
+		assertSame(tb, foo.value);
+		assertSame(tb, foo.getObject().get());
+		assertSame(tb, ((Optional<String>) bwi.getPropertyValue("object")).get());
+		assertEquals("x", foo.value.getName());
+		assertEquals("x", foo.getObject().get().getName());
+		assertEquals("x", bwi.getPropertyValue("object.name"));
+
+		bwi.setPropertyValue("object.name", "y");
+		assertSame(tb, foo.value);
+		assertSame(tb, foo.getObject().get());
+		assertSame(tb, ((Optional<String>) bwi.getPropertyValue("object")).get());
+		assertEquals("y", foo.value.getName());
+		assertEquals("y", foo.getObject().get().getName());
+		assertEquals("y", bwi.getPropertyValue("object.name"));
+	}
+
+	@Test
+	public void testGetterWithOptionalAndAutoGrowing() {
+		GetterWithOptional foo = new GetterWithOptional();
+		BeanWrapperImpl bwi = new BeanWrapperImpl(foo);
+		bwi.setAutoGrowNestedPaths(true);
+
+		bwi.setPropertyValue("object.name", "x");
+		assertEquals("x", foo.value.getName());
+		assertEquals("x", foo.getObject().get().getName());
+		assertEquals("x", bwi.getPropertyValue("object.name"));
+	}
+
 	@Test
 	public void testGenericArraySetter() {
 		SkipReaderStub foo = new SkipReaderStub();
@@ -1636,12 +1666,6 @@ public final class BeanWrapperTests {
 	}
 
 
-	@SuppressWarnings("unused")
-	private static class NoRead {
-
-		public void setAge(int age) {
-		}
-	}
 
 
 	@SuppressWarnings("unused")
@@ -1729,6 +1753,20 @@ public final class BeanWrapperTests {
 		}
 	}
 
+	@SuppressWarnings("unused")
+	private static class StringArrayBean {
+
+		private String[] array;
+
+		public String[] getArray() {
+			return array;
+		}
+
+		public void setArray(String[] array) {
+			this.array = array;
+		}
+	}
+
 
 	@SuppressWarnings("unused")
 	private static class NumberPropertyBean {
@@ -2010,6 +2048,20 @@ public final class BeanWrapperTests {
 	}
 
 
+	public static class GetterWithOptional {
+
+		public TestBean value;
+
+		public void setObject(TestBean object) {
+			this.value = object;
+		}
+
+		public Optional<TestBean> getObject() {
+			return Optional.ofNullable(this.value);
+		}
+	}
+
+
 	public static class SkipReaderStub<T> {
 
 		public T[] items;
