@@ -183,6 +183,7 @@ public class ExtendedBeanInfoTests {
 			}
 		}
 		class Child extends Parent {
+			@Override
 			public Integer getProperty1() {
 				return 2;
 			}
@@ -200,6 +201,7 @@ public class ExtendedBeanInfoTests {
 	@Test
 	public void cornerSpr9453() throws IntrospectionException {
 		final class Bean implements Spr9453<Class<?>> {
+			@Override
 			public Class<?> getProp() {
 				return null;
 			}
@@ -584,7 +586,9 @@ public class ExtendedBeanInfoTests {
 			public Number setFoo(String foo) { return null; }
 		}
 		class C extends B {
+			@Override
 			public String getFoo() { return null; }
+			@Override
 			public Integer setFoo(String foo) { return null; }
 		}
 
@@ -772,7 +776,7 @@ public class ExtendedBeanInfoTests {
 
 	@Test
 	public void propertyDescriptorComparator() throws IntrospectionException {
-		PropertyDescriptorComparator c = new PropertyDescriptorComparator();
+		ExtendedBeanInfo.PropertyDescriptorComparator c = new ExtendedBeanInfo.PropertyDescriptorComparator();
 
 		assertThat(c.compare(new PropertyDescriptor("a", null, null), new PropertyDescriptor("a", null, null)), equalTo(0));
 		assertThat(c.compare(new PropertyDescriptor("abc", null, null), new PropertyDescriptor("abc", null, null)), equalTo(0));
@@ -789,6 +793,103 @@ public class ExtendedBeanInfoTests {
 		assertThat(c.compare(new PropertyDescriptor("a", null, null), new PropertyDescriptor("A", null, null)), greaterThan(0));
 	}
 
+	@Test
+	public void reproSpr8806() throws IntrospectionException {
+		// does not throw
+		Introspector.getBeanInfo(LawLibrary.class);
+
+		// does not throw after the changes introduced in SPR-8806
+		new ExtendedBeanInfo(Introspector.getBeanInfo(LawLibrary.class));
+	}
+
+	@Test
+	public void cornerSpr8949() throws IntrospectionException {
+		class A {
+			@SuppressWarnings("unused")
+			public boolean isTargetMethod() {
+				return false;
+			}
+		}
+
+		class B extends A {
+			@Override
+			public boolean isTargetMethod() {
+				return false;
+			}
+		}
+
+		BeanInfo bi = Introspector.getBeanInfo(B.class);
+
+		// java.beans.Introspector returns the "wrong" declaring class for overridden read
+		// methods, which in turn violates expectations in {@link ExtendedBeanInfo} regarding
+		// method equality. Spring's {@link ClassUtils#getMostSpecificMethod(Method, Class)}
+		// helps out here, and is now put into use in ExtendedBeanInfo as well.
+		BeanInfo ebi = new ExtendedBeanInfo(bi);
+
+		assertThat(hasReadMethodForProperty(bi, "targetMethod"), is(true));
+		assertThat(hasWriteMethodForProperty(bi, "targetMethod"), is(false));
+
+		assertThat(hasReadMethodForProperty(ebi, "targetMethod"), is(true));
+		assertThat(hasWriteMethodForProperty(ebi, "targetMethod"), is(false));
+	}
+
+	@Test
+	public void cornerSpr8937() throws IntrospectionException {
+		@SuppressWarnings("unused") class A {
+			public void setAddress(String addr){ }
+			public void setAddress(int index, String addr) { }
+			public String getAddress(int index){ return null; }
+		}
+
+		// Baseline: ExtendedBeanInfo needs to behave exactly like the following...
+		boolean hasReadMethod;
+		boolean hasWriteMethod;
+		boolean hasIndexedReadMethod;
+		boolean hasIndexedWriteMethod;
+		{
+			BeanInfo bi = Introspector.getBeanInfo(A.class);
+			hasReadMethod = hasReadMethodForProperty(bi, "address");
+			hasWriteMethod = hasWriteMethodForProperty(bi, "address");
+			hasIndexedReadMethod = hasIndexedReadMethodForProperty(bi, "address");
+			hasIndexedWriteMethod = hasIndexedWriteMethodForProperty(bi, "address");
+		}
+		{
+			BeanInfo bi = new ExtendedBeanInfo(Introspector.getBeanInfo(A.class));
+			assertEquals(hasReadMethodForProperty(bi, "address"), hasReadMethod);
+			assertEquals(hasWriteMethodForProperty(bi, "address"), hasWriteMethod);
+			assertEquals(hasIndexedReadMethodForProperty(bi, "address"), hasIndexedReadMethod);
+			assertEquals(hasIndexedWriteMethodForProperty(bi, "address"), hasIndexedWriteMethod);
+		}
+	}
+
+	@Test
+	public void shouldSupportStaticWriteMethod() throws IntrospectionException {
+		{
+			BeanInfo bi = Introspector.getBeanInfo(WithStaticWriteMethod.class);
+			assertThat(hasReadMethodForProperty(bi, "prop1"), is(false));
+			assertThat(hasWriteMethodForProperty(bi, "prop1"), is(false));
+			assertThat(hasIndexedReadMethodForProperty(bi, "prop1"), is(false));
+			assertThat(hasIndexedWriteMethodForProperty(bi, "prop1"), is(false));
+		}
+		{
+			BeanInfo bi = new ExtendedBeanInfo(Introspector.getBeanInfo(WithStaticWriteMethod.class));
+			assertThat(hasReadMethodForProperty(bi, "prop1"), is(false));
+			assertThat(hasWriteMethodForProperty(bi, "prop1"), is(true));
+			assertThat(hasIndexedReadMethodForProperty(bi, "prop1"), is(false));
+			assertThat(hasIndexedWriteMethodForProperty(bi, "prop1"), is(false));
+		}
+	}
+
+	@Test  // SPR-12434
+	public void shouldDetectValidPropertiesAndIgnoreInvalidProperties() throws IntrospectionException {
+		BeanInfo bi = new ExtendedBeanInfo(Introspector.getBeanInfo(java.awt.Window.class));
+		assertThat(hasReadMethodForProperty(bi, "locationByPlatform"), is(true));
+		assertThat(hasWriteMethodForProperty(bi, "locationByPlatform"), is(true));
+		assertThat(hasIndexedReadMethodForProperty(bi, "locationByPlatform"), is(false));
+		assertThat(hasIndexedWriteMethodForProperty(bi, "locationByPlatform"), is(false));
+	}
+
+
 	private boolean hasWriteMethodForProperty(BeanInfo beanInfo, String propertyName) {
 		for (PropertyDescriptor pd : beanInfo.getPropertyDescriptors()) {
 			if (pd.getName().equals(propertyName)) {
@@ -836,111 +937,24 @@ public class ExtendedBeanInfoTests {
 	}
 
 
-	@Test
-	public void reproSpr8806() throws IntrospectionException {
-		// does not throw
-		Introspector.getBeanInfo(LawLibrary.class);
-
-		// does not throw after the changes introduced in SPR-8806
-		new ExtendedBeanInfo(Introspector.getBeanInfo(LawLibrary.class));
-	}
-
-	@Test
-	public void cornerSpr8949() throws IntrospectionException {
-		class A {
-			@SuppressWarnings("unused")
-			public boolean isTargetMethod() {
-				return false;
-			}
-		}
-
-		class B extends A {
-			public boolean isTargetMethod() {
-				return false;
-			}
-		}
-
-		BeanInfo bi = Introspector.getBeanInfo(B.class);
-
-		// java.beans.Introspector returns the "wrong" declaring class for overridden read
-		// methods, which in turn violates expectations in {@link ExtendedBeanInfo} regarding
-		// method equality. Spring's {@link ClassUtils#getMostSpecificMethod(Method, Class)}
-		// helps out here, and is now put into use in ExtendedBeanInfo as well.
-		BeanInfo ebi = new ExtendedBeanInfo(bi);
-
-		assertThat(hasReadMethodForProperty(bi, "targetMethod"), is(true));
-		assertThat(hasWriteMethodForProperty(bi, "targetMethod"), is(false));
-
-		assertThat(hasReadMethodForProperty(ebi, "targetMethod"), is(true));
-		assertThat(hasWriteMethodForProperty(ebi, "targetMethod"), is(false));
-	}
-
-	@Test
-	public void cornerSpr8937() throws IntrospectionException {
-		@SuppressWarnings("unused") class A {
-			public void setAddress(String addr){ }
-			public void setAddress(int index, String addr) { }
-			public String getAddress(int index){ return null; }
-		}
-
-		{ // baseline. ExtendedBeanInfo needs to behave exactly like the following
-			BeanInfo bi = Introspector.getBeanInfo(A.class);
-			assertThat(hasReadMethodForProperty(bi, "address"), is(false));
-			assertThat(hasWriteMethodForProperty(bi, "address"), is(false));
-			assertThat(hasIndexedReadMethodForProperty(bi, "address"), is(true));
-			assertThat(hasIndexedWriteMethodForProperty(bi, "address"), is(true));
-		}
-		{
-			BeanInfo bi = new ExtendedBeanInfo(Introspector.getBeanInfo(A.class));
-			assertThat(hasReadMethodForProperty(bi, "address"), is(false));
-			assertThat(hasWriteMethodForProperty(bi, "address"), is(false));
-			assertThat(hasIndexedReadMethodForProperty(bi, "address"), is(true));
-			assertThat(hasIndexedWriteMethodForProperty(bi, "address"), is(true));
-		}
-	}
-
-	@Test
-	public void shouldSupportStaticWriteMethod() throws IntrospectionException {
-		{
-			BeanInfo bi = Introspector.getBeanInfo(WithStaticWriteMethod.class);
-			assertThat(hasReadMethodForProperty(bi, "prop1"), is(false));
-			assertThat(hasWriteMethodForProperty(bi, "prop1"), is(false));
-			assertThat(hasIndexedReadMethodForProperty(bi, "prop1"), is(false));
-			assertThat(hasIndexedWriteMethodForProperty(bi, "prop1"), is(false));
-		}
-		{
-			BeanInfo bi = new ExtendedBeanInfo(Introspector.getBeanInfo(WithStaticWriteMethod.class));
-			assertThat(hasReadMethodForProperty(bi, "prop1"), is(false));
-			assertThat(hasWriteMethodForProperty(bi, "prop1"), is(true));
-			assertThat(hasIndexedReadMethodForProperty(bi, "prop1"), is(false));
-			assertThat(hasIndexedWriteMethodForProperty(bi, "prop1"), is(false));
-		}
-	}
-
-	@Test  // SPR-12434
-	public void shouldDetectValidPropertiesAndIgnoreInvalidProperties() throws IntrospectionException {
-		BeanInfo bi = new ExtendedBeanInfo(Introspector.getBeanInfo(java.awt.Window.class));
-		assertThat(hasReadMethodForProperty(bi, "locationByPlatform"), is(true));
-		assertThat(hasWriteMethodForProperty(bi, "locationByPlatform"), is(true));
-		assertThat(hasIndexedReadMethodForProperty(bi, "locationByPlatform"), is(false));
-		assertThat(hasIndexedWriteMethodForProperty(bi, "locationByPlatform"), is(false));
-	}
-
-
 	interface Spr9453<T> {
 
 		T getProp();
 	}
 
+
 	interface Book {
 	}
 
+
 	interface TextBook extends Book {
 	}
 
+
 	interface LawBook extends TextBook {
 	}
 
+
 	interface BookOperations {
 
 		Book getBook();
@@ -948,12 +962,14 @@ public class ExtendedBeanInfoTests {
 		void setBook(Book book);
 	}
 
+
 	interface TextBookOperations extends BookOperations {
 
 		@Override
 		TextBook getBook();
 	}
 
+
 	abstract class Library {
 
 		public Book getBook() {
@@ -964,6 +980,7 @@ public class ExtendedBeanInfoTests {
 		}
 	}
 
+
 	class LawLibrary extends Library implements TextBookOperations {
 
 		@Override
@@ -972,6 +989,7 @@ public class ExtendedBeanInfoTests {
 		}
 	}
 
+
 	static class WithStaticWriteMethod {
 
 		public static void setProp1(String prop1) {
