@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ package org.springframework.beans.factory.annotation;
 import java.io.Serializable;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import javax.inject.Inject;
 import javax.inject.Named;
 import javax.inject.Provider;
@@ -573,6 +574,174 @@ public class InjectAnnotationBeanPostProcessorTests {
 		bf.destroySingletons();
 	}
 
+	@Test
+	public void testOptionalFieldInjectionWithBeanAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(OptionalFieldInjectionBean.class));
+		bf.registerBeanDefinition("testBean", new RootBeanDefinition(TestBean.class));
+
+		OptionalFieldInjectionBean bean = (OptionalFieldInjectionBean) bf.getBean("annotatedBean");
+		assertTrue(bean.getTestBean().isPresent());
+		assertSame(bf.getBean("testBean"), bean.getTestBean().get());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testOptionalFieldInjectionWithBeanNotAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(OptionalFieldInjectionBean.class));
+
+		OptionalFieldInjectionBean bean = (OptionalFieldInjectionBean) bf.getBean("annotatedBean");
+		assertFalse(bean.getTestBean().isPresent());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testOptionalMethodInjectionWithBeanAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(OptionalMethodInjectionBean.class));
+		bf.registerBeanDefinition("testBean", new RootBeanDefinition(TestBean.class));
+
+		OptionalMethodInjectionBean bean = (OptionalMethodInjectionBean) bf.getBean("annotatedBean");
+		assertTrue(bean.getTestBean().isPresent());
+		assertSame(bf.getBean("testBean"), bean.getTestBean().get());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testOptionalMethodInjectionWithBeanNotAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(OptionalMethodInjectionBean.class));
+
+		OptionalMethodInjectionBean bean = (OptionalMethodInjectionBean) bf.getBean("annotatedBean");
+		assertFalse(bean.getTestBean().isPresent());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testOptionalListFieldInjectionWithBeanAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(OptionalListFieldInjectionBean.class));
+		bf.registerBeanDefinition("testBean", new RootBeanDefinition(TestBean.class));
+
+		OptionalListFieldInjectionBean bean = (OptionalListFieldInjectionBean) bf.getBean("annotatedBean");
+		assertTrue(bean.getTestBean().isPresent());
+		assertSame(bf.getBean("testBean"), bean.getTestBean().get().get(0));
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testOptionalListFieldInjectionWithBeanNotAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(OptionalListFieldInjectionBean.class));
+
+		OptionalListFieldInjectionBean bean = (OptionalListFieldInjectionBean) bf.getBean("annotatedBean");
+		assertFalse(bean.getTestBean().isPresent());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testOptionalListMethodInjectionWithBeanAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(OptionalListMethodInjectionBean.class));
+		bf.registerBeanDefinition("testBean", new RootBeanDefinition(TestBean.class));
+
+		OptionalListMethodInjectionBean bean = (OptionalListMethodInjectionBean) bf.getBean("annotatedBean");
+		assertTrue(bean.getTestBean().isPresent());
+		assertSame(bf.getBean("testBean"), bean.getTestBean().get().get(0));
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testOptionalListMethodInjectionWithBeanNotAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(OptionalListMethodInjectionBean.class));
+
+		OptionalListMethodInjectionBean bean = (OptionalListMethodInjectionBean) bf.getBean("annotatedBean");
+		assertFalse(bean.getTestBean().isPresent());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testProviderOfOptionalFieldInjectionWithBeanAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(ProviderOfOptionalFieldInjectionBean.class));
+		bf.registerBeanDefinition("testBean", new RootBeanDefinition(TestBean.class));
+
+		ProviderOfOptionalFieldInjectionBean bean = (ProviderOfOptionalFieldInjectionBean) bf.getBean("annotatedBean");
+		assertTrue(bean.getTestBean().isPresent());
+		assertSame(bf.getBean("testBean"), bean.getTestBean().get());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testProviderOfOptionalFieldInjectionWithBeanNotAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(ProviderOfOptionalFieldInjectionBean.class));
+
+		ProviderOfOptionalFieldInjectionBean bean = (ProviderOfOptionalFieldInjectionBean) bf.getBean("annotatedBean");
+		assertFalse(bean.getTestBean().isPresent());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testProviderOfOptionalMethodInjectionWithBeanAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(ProviderOfOptionalMethodInjectionBean.class));
+		bf.registerBeanDefinition("testBean", new RootBeanDefinition(TestBean.class));
+
+		ProviderOfOptionalMethodInjectionBean bean = (ProviderOfOptionalMethodInjectionBean) bf.getBean("annotatedBean");
+		assertTrue(bean.getTestBean().isPresent());
+		assertSame(bf.getBean("testBean"), bean.getTestBean().get());
+		bf.destroySingletons();
+	}
+
+	@Test
+	public void testProviderOfOptionalMethodInjectionWithBeanNotAvailable() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		AutowiredAnnotationBeanPostProcessor bpp = new AutowiredAnnotationBeanPostProcessor();
+		bpp.setBeanFactory(bf);
+		bf.addBeanPostProcessor(bpp);
+		bf.registerBeanDefinition("annotatedBean", new RootBeanDefinition(ProviderOfOptionalMethodInjectionBean.class));
+
+		ProviderOfOptionalMethodInjectionBean bean = (ProviderOfOptionalMethodInjectionBean) bf.getBean("annotatedBean");
+		assertFalse(bean.getTestBean().isPresent());
+		bf.destroySingletons();
+	}
+
 
 	public static class ResourceInjectionBean {
 
@@ -1099,4 +1268,82 @@ public class InjectAnnotationBeanPostProcessorTests {
 		}
 	}
 
+
+	public static class OptionalFieldInjectionBean {
+
+		@Inject
+		private Optional<TestBean> testBean;
+
+		public Optional<TestBean> getTestBean() {
+			return this.testBean;
+		}
+	}
+
+
+	public static class OptionalMethodInjectionBean {
+
+		private Optional<TestBean> testBean;
+
+		@Inject
+		public void setTestBean(Optional<TestBean> testBeanFactory) {
+			this.testBean = testBeanFactory;
+		}
+
+		public Optional<TestBean> getTestBean() {
+			return this.testBean;
+		}
+	}
+
+
+	public static class OptionalListFieldInjectionBean {
+
+		@Inject
+		private Optional<List<TestBean>> testBean;
+
+		public Optional<List<TestBean>> getTestBean() {
+			return this.testBean;
+		}
+	}
+
+
+	public static class OptionalListMethodInjectionBean {
+
+		private Optional<List<TestBean>> testBean;
+
+		@Inject
+		public void setTestBean(Optional<List<TestBean>> testBeanFactory) {
+			this.testBean = testBeanFactory;
+		}
+
+		public Optional<List<TestBean>> getTestBean() {
+			return this.testBean;
+		}
+	}
+
+
+	public static class ProviderOfOptionalFieldInjectionBean {
+
+		@Inject
+		private Provider<Optional<TestBean>> testBean;
+
+		public Optional<TestBean> getTestBean() {
+			return this.testBean.get();
+		}
+	}
+
+
+	public static class ProviderOfOptionalMethodInjectionBean {
+
+		private Provider<Optional<TestBean>> testBean;
+
+		@Inject
+		public void setTestBean(Provider<Optional<TestBean>> testBeanFactory) {
+			this.testBean = testBeanFactory;
+		}
+
+		public Optional<TestBean> getTestBean() {
+			return this.testBean.get();
+		}
+	}
+
 }
