@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -769,6 +769,36 @@ public class BeanFactoryGenericsTests {
 		assertEquals(1, beans.size());
 	}
 
+	@Test
+	public void testGenericMatchingWithBeanNameDifferentiation() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		bf.setAutowireCandidateResolver(new GenericTypeAwareAutowireCandidateResolver());
+
+		bf.registerBeanDefinition("doubleStore", new RootBeanDefinition(NumberStore.class));
+		bf.registerBeanDefinition("floatStore", new RootBeanDefinition(NumberStore.class));
+		bf.registerBeanDefinition("numberBean",
+				new RootBeanDefinition(NumberBean.class, RootBeanDefinition.AUTOWIRE_CONSTRUCTOR, false));
+
+		NumberBean nb = bf.getBean(NumberBean.class);
+		assertSame(bf.getBean("doubleStore"), nb.getDoubleStore());
+		assertSame(bf.getBean("floatStore"), nb.getFloatStore());
+	}
+
+	@Test
+	public void testGenericMatchingWithFullTypeDifferentiation() {
+		DefaultListableBeanFactory bf = new DefaultListableBeanFactory();
+		bf.setAutowireCandidateResolver(new GenericTypeAwareAutowireCandidateResolver());
+
+		bf.registerBeanDefinition("store1", new RootBeanDefinition(DoubleStore.class));
+		bf.registerBeanDefinition("store2", new RootBeanDefinition(FloatStore.class));
+		bf.registerBeanDefinition("numberBean",
+				new RootBeanDefinition(NumberBean.class, RootBeanDefinition.AUTOWIRE_CONSTRUCTOR, false));
+
+		NumberBean nb = bf.getBean(NumberBean.class);
+		assertSame(bf.getBean("store1"), nb.getDoubleStore());
+		assertSame(bf.getBean("store2"), nb.getFloatStore());
+	}
+
 
 	@SuppressWarnings("serial")
 	public static class NamedUrlList extends LinkedList<URL> {
@@ -831,4 +861,37 @@ public class BeanFactoryGenericsTests {
 		}
 	}
 
+
+	public static class NumberStore<T extends Number> {
+	}
+
+
+	public static class DoubleStore extends NumberStore<Double> {
+	}
+
+
+	public static class FloatStore extends NumberStore<Float> {
+	}
+
+
+	public static class NumberBean {
+
+		private final NumberStore<Double> doubleStore;
+
+		private final NumberStore<Float> floatStore;
+
+		public NumberBean(NumberStore<Double> doubleStore, NumberStore<Float> floatStore) {
+			this.doubleStore = doubleStore;
+			this.floatStore = floatStore;
+		}
+
+		public NumberStore<Double> getDoubleStore() {
+			return this.doubleStore;
+		}
+
+		public NumberStore<Float> getFloatStore() {
+			return this.floatStore;
+		}
+	}
+
 }
