@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,7 +23,6 @@ import java.util.Date;
 import java.util.GregorianCalendar;
 import java.util.List;
 import java.util.Properties;
-
 import javax.activation.FileTypeMap;
 import javax.mail.Address;
 import javax.mail.Message;
@@ -41,6 +40,7 @@ import junit.framework.TestCase;
 import org.springframework.mail.MailParseException;
 import org.springframework.mail.MailSendException;
 import org.springframework.mail.SimpleMailMessage;
+import org.springframework.util.ObjectUtils;
 
 /**
  * @author Juergen Hoeller
@@ -75,19 +75,19 @@ public class JavaMailSenderTests extends TestCase {
 
 		assertEquals(1, sender.transport.getSentMessages().size());
 		MimeMessage sentMessage = sender.transport.getSentMessage(0);
-		List froms = Arrays.asList(sentMessage.getFrom());
+		List<Address> froms = Arrays.asList(sentMessage.getFrom());
 		assertEquals(1, froms.size());
 		assertEquals("me@mail.org", ((InternetAddress) froms.get(0)).getAddress());
-		List replyTos = Arrays.asList(sentMessage.getReplyTo());
+		List<Address> replyTos = Arrays.asList(sentMessage.getReplyTo());
 		assertEquals("reply@mail.org", ((InternetAddress) replyTos.get(0)).getAddress());
-		List tos = Arrays.asList(sentMessage.getRecipients(Message.RecipientType.TO));
+		List<Address> tos = Arrays.asList(sentMessage.getRecipients(Message.RecipientType.TO));
 		assertEquals(1, tos.size());
 		assertEquals("you@mail.org", ((InternetAddress) tos.get(0)).getAddress());
-		List ccs = Arrays.asList(sentMessage.getRecipients(Message.RecipientType.CC));
+		List<Address> ccs = Arrays.asList(sentMessage.getRecipients(Message.RecipientType.CC));
 		assertEquals(2, ccs.size());
 		assertEquals("he@mail.org", ((InternetAddress) ccs.get(0)).getAddress());
 		assertEquals("she@mail.org", ((InternetAddress) ccs.get(1)).getAddress());
-		List bccs = Arrays.asList(sentMessage.getRecipients(Message.RecipientType.BCC));
+		List<Address> bccs = Arrays.asList(sentMessage.getRecipients(Message.RecipientType.BCC));
 		assertEquals(2, bccs.size());
 		assertEquals("us@mail.org", ((InternetAddress) bccs.get(0)).getAddress());
 		assertEquals("them@mail.org", ((InternetAddress) bccs.get(1)).getAddress());
@@ -106,7 +106,7 @@ public class JavaMailSenderTests extends TestCase {
 		simpleMessage1.setTo("he@mail.org");
 		SimpleMailMessage simpleMessage2 = new SimpleMailMessage();
 		simpleMessage2.setTo("she@mail.org");
-		sender.send(new SimpleMailMessage[] {simpleMessage1, simpleMessage2});
+		sender.send(simpleMessage1, simpleMessage2);
 
 		assertEquals("host", sender.transport.getConnectedHost());
 		assertEquals("username", sender.transport.getConnectedUsername());
@@ -115,11 +115,11 @@ public class JavaMailSenderTests extends TestCase {
 
 		assertEquals(2, sender.transport.getSentMessages().size());
 		MimeMessage sentMessage1 = sender.transport.getSentMessage(0);
-		List tos1 = Arrays.asList(sentMessage1.getRecipients(Message.RecipientType.TO));
+		List<Address> tos1 = Arrays.asList(sentMessage1.getRecipients(Message.RecipientType.TO));
 		assertEquals(1, tos1.size());
 		assertEquals("he@mail.org", ((InternetAddress) tos1.get(0)).getAddress());
 		MimeMessage sentMessage2 = sender.transport.getSentMessage(1);
-		List tos2 = Arrays.asList(sentMessage2.getRecipients(Message.RecipientType.TO));
+		List<Address> tos2 = Arrays.asList(sentMessage2.getRecipients(Message.RecipientType.TO));
 		assertEquals(1, tos2.size());
 		assertEquals("she@mail.org", ((InternetAddress) tos2.get(0)).getAddress());
 	}
@@ -152,7 +152,7 @@ public class JavaMailSenderTests extends TestCase {
 		mimeMessage1.setRecipient(Message.RecipientType.TO, new InternetAddress("he@mail.org"));
 		MimeMessage mimeMessage2 = sender.createMimeMessage();
 		mimeMessage2.setRecipient(Message.RecipientType.TO, new InternetAddress("she@mail.org"));
-		sender.send(new MimeMessage[] {mimeMessage1, mimeMessage2});
+		sender.send(mimeMessage1, mimeMessage2);
 
 		assertEquals("host", sender.transport.getConnectedHost());
 		assertEquals("username", sender.transport.getConnectedUsername());
@@ -210,7 +210,7 @@ public class JavaMailSenderTests extends TestCase {
 				messages.add(mimeMessage);
 			}
 		};
-		sender.send(new MimeMessagePreparator[] {preparator1, preparator2});
+		sender.send(preparator1, preparator2);
 
 		assertEquals("host", sender.transport.getConnectedHost());
 		assertEquals("username", sender.transport.getConnectedUsername());
@@ -425,7 +425,7 @@ public class JavaMailSenderTests extends TestCase {
 		simpleMessage2.setTo("she@mail.org");
 
 		try {
-			sender.send(new SimpleMailMessage[] {simpleMessage1, simpleMessage2});
+			sender.send(simpleMessage1, simpleMessage2);
 		}
 		catch (MailSendException ex) {
 			ex.printStackTrace();
@@ -456,7 +456,7 @@ public class JavaMailSenderTests extends TestCase {
 		mimeMessage2.setRecipient(Message.RecipientType.TO, new InternetAddress("she@mail.org"));
 
 		try {
-			sender.send(new MimeMessage[] {mimeMessage1, mimeMessage2});
+			sender.send(mimeMessage1, mimeMessage2);
 		}
 		catch (MailSendException ex) {
 			ex.printStackTrace();
@@ -520,7 +520,7 @@ public class JavaMailSenderTests extends TestCase {
 			return closeCalled;
 		}
 
-		public List getSentMessages() {
+		public List<Message> getSentMessages() {
 			return sentMessages;
 		}
 
@@ -537,6 +537,7 @@ public class JavaMailSenderTests extends TestCase {
 			this.connectedPort = port;
 			this.connectedUsername = username;
 			this.connectedPassword = password;
+			setConnected(true);
 		}
 
 		@Override
@@ -552,9 +553,7 @@ public class JavaMailSenderTests extends TestCase {
 			if ("fail".equals(message.getSubject())) {
 				throw new MessagingException("failed");
 			}
-			List addr1 = Arrays.asList(message.getAllRecipients());
-			List addr2 = Arrays.asList(addresses);
-			if (!addr1.equals(addr2)) {
+			if (!ObjectUtils.nullSafeEquals(addresses, message.getAllRecipients())) {
 				throw new MessagingException("addresses not correct");
 			}
 			if (message.getSentDate() == null) {
