@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2011 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,8 +18,9 @@ package org.springframework.cache.config;
 
 import org.junit.Assert;
 import org.junit.Test;
+
 import org.springframework.cache.interceptor.CacheInterceptor;
-import org.springframework.context.ApplicationContext;
+import org.springframework.context.ConfigurableApplicationContext;
 import org.springframework.context.support.GenericXmlApplicationContext;
 
 /**
@@ -29,7 +30,7 @@ import org.springframework.context.support.GenericXmlApplicationContext;
 public class CacheAdviceNamespaceTests extends AbstractAnnotationTests {
 
 	@Override
-	protected ApplicationContext getApplicationContext() {
+	protected ConfigurableApplicationContext getApplicationContext() {
 		return new GenericXmlApplicationContext(
 				"/org/springframework/cache/config/cache-advice.xml");
 	}
@@ -39,4 +40,5 @@ public class CacheAdviceNamespaceTests extends AbstractAnnotationTests {
 		CacheInterceptor bean = ctx.getBean("cacheAdviceClass", CacheInterceptor.class);
 		Assert.assertSame(ctx.getBean("keyGenerator"), bean.getKeyGenerator());
 	}
+
 }
