@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,9 +22,13 @@ import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 import java.lang.reflect.Method;
+import java.util.Calendar;
+import java.util.Date;
 import java.util.List;
 import java.util.Properties;
+import java.util.TimeZone;
 
+import org.junit.After;
 import org.junit.Test;
 
 import org.springframework.beans.DirectFieldAccessor;
@@ -33,12 +37,18 @@ import org.springframework.beans.factory.config.BeanDefinition;
 import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;
 import org.springframework.beans.factory.support.RootBeanDefinition;
 import org.springframework.context.support.StaticApplicationContext;
+import org.springframework.scheduling.Trigger;
+import org.springframework.scheduling.TriggerContext;
 import org.springframework.scheduling.config.CronTask;
 import org.springframework.scheduling.config.IntervalTask;
 import org.springframework.scheduling.config.ScheduledTaskRegistrar;
+import org.springframework.scheduling.support.CronTrigger;
 import org.springframework.scheduling.support.ScheduledMethodRunnable;
+import org.springframework.scheduling.support.SimpleTriggerContext;
 import org.springframework.tests.Assume;
 import org.springframework.tests.TestGroup;
+import org.springframework.validation.annotation.Validated;
+import org.springframework.validation.beanvalidation.MethodValidationPostProcessor;
 
 import static org.junit.Assert.*;
 
@@ -46,12 +56,22 @@ import static org.junit.Assert.*;
  * @author Mark Fisher
  * @author Juergen Hoeller
  * @author Chris Beams
+ * @author Sam Brannen
+ * @author Stevo Slavić
  */
 public class ScheduledAnnotationBeanPostProcessorTests {
 
+	private final StaticApplicationContext context = new StaticApplicationContext();
+
+
+	@After
+	public void closeContextAfterTest() {
+		context.close();
+	}
+
+
 	@Test
 	public void fixedDelayTask() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(FixedDelayTestBean.class);
 		context.registerBeanDefinition("postProcessor", processorDefinition);
@@ -77,7 +97,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test
 	public void fixedRateTask() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(
 				ScheduledAnnotationBeanPostProcessorTests.FixedRateTestBean.class);
@@ -104,7 +123,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test
 	public void fixedRateTaskWithInitialDelay() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(FixedRateWithInitialDelayTestBean.class);
 		context.registerBeanDefinition("postProcessor", processorDefinition);
@@ -128,11 +146,60 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 		assertEquals(3000L, task.getInterval());
 	}
 
+	@Test
+	public void severalFixedRatesWithRepeatedScheduledAnnotation() {
+		BeanDefinition processorDefinition = new
+		RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
+		BeanDefinition targetDefinition = new RootBeanDefinition(
+				SeveralFixedRatesWithRepeatedScheduledAnnotationTestBean.class);
+		severalFixedRates(context, processorDefinition, targetDefinition);
+	}
+
+	@Test
+	public void severalFixedRatesWithSchedulesContainerAnnotation() {
+		BeanDefinition processorDefinition = new RootBeanDefinition(
+				ScheduledAnnotationBeanPostProcessor.class);
+		BeanDefinition targetDefinition = new RootBeanDefinition(
+				SeveralFixedRatesWithSchedulesContainerAnnotationTestBean.class);
+		severalFixedRates(context, processorDefinition, targetDefinition);
+	}
+
+	private void severalFixedRates(StaticApplicationContext context,
+			BeanDefinition processorDefinition, BeanDefinition targetDefinition) {
+
+		context.registerBeanDefinition("postProcessor", processorDefinition);
+		context.registerBeanDefinition("target", targetDefinition);
+		context.refresh();
+		Object postProcessor = context.getBean("postProcessor");
+		Object target = context.getBean("target");
+		ScheduledTaskRegistrar registrar = (ScheduledTaskRegistrar)
+				new DirectFieldAccessor(postProcessor).getPropertyValue("registrar");
+		@SuppressWarnings("unchecked")
+		List<IntervalTask> fixedRateTasks = (List<IntervalTask>)
+				new DirectFieldAccessor(registrar).getPropertyValue("fixedRateTasks");
+		assertEquals(2, fixedRateTasks.size());
+		IntervalTask task1 = fixedRateTasks.get(0);
+		ScheduledMethodRunnable runnable1 = (ScheduledMethodRunnable) task1.getRunnable();
+		Object targetObject = runnable1.getTarget();
+		Method targetMethod = runnable1.getMethod();
+		assertEquals(target, targetObject);
+		assertEquals("fixedRate", targetMethod.getName());
+		assertEquals(0, task1.getInitialDelay());
+		assertEquals(4000L, task1.getInterval());
+		IntervalTask task2 = fixedRateTasks.get(1);
+		ScheduledMethodRunnable runnable2 = (ScheduledMethodRunnable) task2.getRunnable();
+		targetObject = runnable2.getTarget();
+		targetMethod = runnable2.getMethod();
+		assertEquals(target, targetObject);
+		assertEquals("fixedRate", targetMethod.getName());
+		assertEquals(2000L, task2.getInitialDelay());
+		assertEquals(4000L, task2.getInterval());
+	}
+
 	@Test
 	public void cronTask() throws InterruptedException {
 		Assume.group(TestGroup.LONG_RUNNING);
 
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(
 				ScheduledAnnotationBeanPostProcessorTests.CronTestBean.class);
@@ -157,9 +224,78 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 		Thread.sleep(10000);
 	}
 
+	@Test
+	public void cronTaskWithZone() throws InterruptedException {
+		Assume.group(TestGroup.LONG_RUNNING);
+
+		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
+		BeanDefinition targetDefinition = new RootBeanDefinition(
+				ScheduledAnnotationBeanPostProcessorTests.CronWithTimezoneTestBean.class);
+		context.registerBeanDefinition("postProcessor", processorDefinition);
+		context.registerBeanDefinition("target", targetDefinition);
+		context.refresh();
+		Object postProcessor = context.getBean("postProcessor");
+		Object target = context.getBean("target");
+		ScheduledTaskRegistrar registrar = (ScheduledTaskRegistrar)
+				new DirectFieldAccessor(postProcessor).getPropertyValue("registrar");
+		@SuppressWarnings("unchecked")
+		List<CronTask> cronTasks = (List<CronTask>)
+				new DirectFieldAccessor(registrar).getPropertyValue("cronTasks");
+		assertEquals(1, cronTasks.size());
+		CronTask task = cronTasks.get(0);
+		ScheduledMethodRunnable runnable = (ScheduledMethodRunnable) task.getRunnable();
+		Object targetObject = runnable.getTarget();
+		Method targetMethod = runnable.getMethod();
+		assertEquals(target, targetObject);
+		assertEquals("cron", targetMethod.getName());
+		assertEquals("0 0 0-4,6-23 * * ?", task.getExpression());
+		Trigger trigger = task.getTrigger();
+		assertNotNull(trigger);
+		assertTrue(trigger instanceof CronTrigger);
+		CronTrigger cronTrigger = (CronTrigger) trigger;
+		Calendar cal = Calendar.getInstance(TimeZone.getTimeZone("GMT+10"));
+		cal.clear();
+		cal.set(2013, 3, 15, 4, 0); // 15-04-2013 4:00 GMT+10
+		Date lastScheduledExecutionTime = cal.getTime();
+		Date lastActualExecutionTime = cal.getTime();
+		cal.add(Calendar.MINUTE, 30); // 4:30
+		Date lastCompletionTime = cal.getTime();
+		TriggerContext triggerContext = new SimpleTriggerContext(
+				lastScheduledExecutionTime, lastActualExecutionTime, lastCompletionTime);
+		cal.add(Calendar.MINUTE, 30);
+		cal.add(Calendar.HOUR_OF_DAY, 1); // 6:00
+		Date nextExecutionTime = cronTrigger.nextExecutionTime(triggerContext);
+		assertEquals(cal.getTime(), nextExecutionTime); // assert that 6:00 is next execution time
+		Thread.sleep(10000);
+	}
+
+	@Test(expected = BeanCreationException.class)
+	public void cronTaskWithInvalidZone() throws InterruptedException {
+		Assume.group(TestGroup.LONG_RUNNING);
+
+		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
+		BeanDefinition targetDefinition = new RootBeanDefinition(
+				ScheduledAnnotationBeanPostProcessorTests.CronWithInvalidTimezoneTestBean.class);
+		context.registerBeanDefinition("postProcessor", processorDefinition);
+		context.registerBeanDefinition("target", targetDefinition);
+		context.refresh();
+		Thread.sleep(10000);
+	}
+
+	@Test(expected = BeanCreationException.class)
+	public void cronTaskWithMethodValidation() throws InterruptedException {
+		BeanDefinition validationDefinition = new RootBeanDefinition(MethodValidationPostProcessor.class);
+		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
+		BeanDefinition targetDefinition = new RootBeanDefinition(
+				ScheduledAnnotationBeanPostProcessorTests.CronTestBean.class);
+		context.registerBeanDefinition("methodValidation", validationDefinition);
+		context.registerBeanDefinition("postProcessor", processorDefinition);
+		context.registerBeanDefinition("target", targetDefinition);
+		context.refresh();
+	}
+
 	@Test
 	public void metaAnnotationWithFixedRate() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(MetaAnnotationFixedRateTestBean.class);
 		context.registerBeanDefinition("postProcessor", processorDefinition);
@@ -184,7 +320,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test
 	public void metaAnnotationWithCronExpression() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(
 				ScheduledAnnotationBeanPostProcessorTests.MetaAnnotationCronTestBean.class);
@@ -211,7 +346,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 	@Test
 	public void propertyPlaceholderWithCron() {
 		String businessHoursCronExpression = "0 0 9-17 * * MON-FRI";
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition placeholderDefinition = new RootBeanDefinition(PropertyPlaceholderConfigurer.class);
 		Properties properties = new Properties();
@@ -241,7 +375,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test
 	public void propertyPlaceholderWithFixedDelay() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition placeholderDefinition = new RootBeanDefinition(PropertyPlaceholderConfigurer.class);
 		Properties properties = new Properties();
@@ -273,7 +406,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test
 	public void propertyPlaceholderWithFixedRate() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition placeholderDefinition = new RootBeanDefinition(PropertyPlaceholderConfigurer.class);
 		Properties properties = new Properties();
@@ -306,7 +438,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 	@Test
 	public void propertyPlaceholderForMetaAnnotation() {
 		String businessHoursCronExpression = "0 0 9-17 * * MON-FRI";
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition placeholderDefinition = new RootBeanDefinition(PropertyPlaceholderConfigurer.class);
 		Properties properties = new Properties();
@@ -337,7 +468,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test(expected = BeanCreationException.class)
 	public void emptyAnnotation() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(
 				ScheduledAnnotationBeanPostProcessorTests.EmptyAnnotationTestBean.class);
@@ -348,7 +478,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test(expected = BeanCreationException.class)
 	public void invalidCron() throws Throwable {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(
 				ScheduledAnnotationBeanPostProcessorTests.InvalidCronTestBean.class);
@@ -359,7 +488,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test(expected = BeanCreationException.class)
 	public void nonVoidReturnType() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(
 				ScheduledAnnotationBeanPostProcessorTests.NonVoidReturnTypeTestBean.class);
@@ -370,7 +498,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 
 	@Test(expected = BeanCreationException.class)
 	public void nonEmptyParamList() {
-		StaticApplicationContext context = new StaticApplicationContext();
 		BeanDefinition processorDefinition = new RootBeanDefinition(ScheduledAnnotationBeanPostProcessor.class);
 		BeanDefinition targetDefinition = new RootBeanDefinition(
 				ScheduledAnnotationBeanPostProcessorTests.NonEmptyParamListTestBean.class);
@@ -404,13 +531,52 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 	}
 
 
+	static class SeveralFixedRatesWithSchedulesContainerAnnotationTestBean {
+
+		@Schedules({ @Scheduled(fixedRate = 4000),
+			@Scheduled(fixedRate = 4000, initialDelay = 2000) })
+		public void fixedRate() {
+		}
+	}
+
+
+	static class SeveralFixedRatesWithRepeatedScheduledAnnotationTestBean {
+
+		// can use Java 8 repeated @Scheduled once we have Eclipse IDE support for it
+		@Schedules({
+			@Scheduled(fixedRate=4000),
+			@Scheduled(fixedRate=4000, initialDelay=2000)
+		})
+		public void fixedRate() {
+		}
+	}
+
+
+	@Validated
 	static class CronTestBean {
 
 		@Scheduled(cron="*/7 * * * * ?")
+		private void cron() throws IOException {
+			throw new IOException("no no no");
+		}
+	}
+
+
+	static class CronWithTimezoneTestBean {
+
+		@Scheduled(cron="0 0 0-4,6-23 * * ?", zone = "GMT+10")
+		protected void cron() throws IOException {
+			throw new IOException("no no no");
+		}
+	}
+
+
+	static class CronWithInvalidTimezoneTestBean {
+
+		@Scheduled(cron="0 0 0-4,6-23 * * ?", zone = "FOO")
 		public void cron() throws IOException {
 			throw new IOException("no no no");
 		}
-
 	}
 
 
@@ -419,7 +585,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 		@Scheduled
 		public void invalid() {
 		}
-
 	}
 
 
@@ -428,7 +593,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 		@Scheduled(cron="abc")
 		public void invalid() {
 		}
-
 	}
 
 
@@ -438,7 +602,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 		public String invalid() {
 			return "oops";
 		}
-
 	}
 
 
@@ -447,7 +610,6 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 		@Scheduled(fixedRate=3000)
 		public void invalid(String oops) {
 		}
-
 	}
 
 
@@ -506,7 +668,8 @@ public class ScheduledAnnotationBeanPostProcessorTests {
 	@Scheduled(cron="${schedules.businessHours}")
 	@Target(ElementType.METHOD)
 	@Retention(RetentionPolicy.RUNTIME)
-	private static @interface BusinessHours {}
+	private static @interface BusinessHours {
+	}
 
 
 	static class PropertyPlaceholderMetaAnnotationTestBean {
