@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -28,6 +28,7 @@ import org.apache.commons.logging.LogFactory;
 import org.springframework.core.SpringProperties;
 import org.springframework.core.convert.support.ConfigurableConversionService;
 import org.springframework.util.Assert;
+import org.springframework.util.ObjectUtils;
 import org.springframework.util.StringUtils;
 
 import static java.lang.String.*;
@@ -103,9 +104,9 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 
 	protected final Log logger = LogFactory.getLog(getClass());
 
-	private Set<String> activeProfiles = new LinkedHashSet<String>();
+	private final Set<String> activeProfiles = new LinkedHashSet<String>();
 
-	private Set<String> defaultProfiles = new LinkedHashSet<String>(getReservedDefaultProfiles());
+	private final Set<String> defaultProfiles = new LinkedHashSet<String>(getReservedDefaultProfiles());
 
 	private final MutablePropertySources propertySources = new MutablePropertySources(this.logger);
 
@@ -223,6 +224,7 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 	// Implementation of ConfigurableEnvironment interface
 	//---------------------------------------------------------------------
 
+	@Override
 	public String[] getActiveProfiles() {
 		return StringUtils.toStringArray(doGetActiveProfiles());
 	}
@@ -236,34 +238,43 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 	 * @see #ACTIVE_PROFILES_PROPERTY_NAME
 	 */
 	protected Set<String> doGetActiveProfiles() {
-		if (this.activeProfiles.isEmpty()) {
-			String profiles = getProperty(ACTIVE_PROFILES_PROPERTY_NAME);
-			if (StringUtils.hasText(profiles)) {
-				setActiveProfiles(commaDelimitedListToStringArray(trimAllWhitespace(profiles)));
+		synchronized (this.activeProfiles) {
+			if (this.activeProfiles.isEmpty()) {
+				String profiles = getProperty(ACTIVE_PROFILES_PROPERTY_NAME);
+				if (StringUtils.hasText(profiles)) {
+					setActiveProfiles(commaDelimitedListToStringArray(trimAllWhitespace(profiles)));
+				}
 			}
+			return this.activeProfiles;
 		}
-		return this.activeProfiles;
 	}
 
+	@Override
 	public void setActiveProfiles(String... profiles) {
 		Assert.notNull(profiles, "Profile array must not be null");
-		this.activeProfiles.clear();
-		for (String profile : profiles) {
-			validateProfile(profile);
-			this.activeProfiles.add(profile);
+		synchronized (this.activeProfiles) {
+			this.activeProfiles.clear();
+			for (String profile : profiles) {
+				validateProfile(profile);
+				this.activeProfiles.add(profile);
+			}
 		}
 	}
 
+	@Override
 	public void addActiveProfile(String profile) {
 		if (this.logger.isDebugEnabled()) {
 			this.logger.debug(format("Activating profile '%s'", profile));
 		}
 		validateProfile(profile);
 		doGetActiveProfiles();
-		this.activeProfiles.add(profile);
+		synchronized (this.activeProfiles) {
+			this.activeProfiles.add(profile);
+		}
 	}
 
 
+	@Override
 	public String[] getDefaultProfiles() {
 		return StringUtils.toStringArray(doGetDefaultProfiles());
 	}
@@ -281,13 +292,15 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 	 * @see #getReservedDefaultProfiles()
 	 */
 	protected Set<String> doGetDefaultProfiles() {
-		if (this.defaultProfiles.equals(getReservedDefaultProfiles())) {
-			String profiles = getProperty(DEFAULT_PROFILES_PROPERTY_NAME);
-			if (StringUtils.hasText(profiles)) {
-				setDefaultProfiles(commaDelimitedListToStringArray(trimAllWhitespace(profiles)));
+		synchronized (this.defaultProfiles) {
+			if (this.defaultProfiles.equals(getReservedDefaultProfiles())) {
+				String profiles = getProperty(DEFAULT_PROFILES_PROPERTY_NAME);
+				if (StringUtils.hasText(profiles)) {
+					setDefaultProfiles(commaDelimitedListToStringArray(trimAllWhitespace(profiles)));
+				}
 			}
+			return this.defaultProfiles;
 		}
-		return this.defaultProfiles;
 	}
 
 	/**
@@ -298,19 +311,23 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 	 * @see #AbstractEnvironment()
 	 * @see #getReservedDefaultProfiles()
 	 */
+	@Override
 	public void setDefaultProfiles(String... profiles) {
 		Assert.notNull(profiles, "Profile array must not be null");
-		this.defaultProfiles.clear();
-		for (String profile : profiles) {
-			validateProfile(profile);
-			this.defaultProfiles.add(profile);
+		synchronized (this.defaultProfiles) {
+			this.defaultProfiles.clear();
+			for (String profile : profiles) {
+				validateProfile(profile);
+				this.defaultProfiles.add(profile);
+			}
 		}
 	}
 
+	@Override
 	public boolean acceptsProfiles(String... profiles) {
 		Assert.notEmpty(profiles, "Must specify at least one profile");
 		for (String profile : profiles) {
-			if (profile != null && profile.length() > 0 && profile.charAt(0) == '!') {
+			if (StringUtils.hasLength(profile) && profile.charAt(0) == '!') {
 				if (!isProfileActive(profile.substring(1))) {
 					return true;
 				}
@@ -329,8 +346,9 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 	 */
 	protected boolean isProfileActive(String profile) {
 		validateProfile(profile);
-		return doGetActiveProfiles().contains(profile) ||
-				(doGetActiveProfiles().isEmpty() && doGetDefaultProfiles().contains(profile));
+		Set<String> currentActiveProfiles = doGetActiveProfiles();
+		return (currentActiveProfiles.contains(profile) ||
+				(currentActiveProfiles.isEmpty() && doGetDefaultProfiles().contains(profile)));
 	}
 
 	/**
@@ -352,11 +370,13 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 		}
 	}
 
+	@Override
 	public MutablePropertySources getPropertySources() {
 		return this.propertySources;
 	}
 
-	@SuppressWarnings("unchecked")
+	@Override
+	@SuppressWarnings({"unchecked", "rawtypes"})
 	public Map<String, Object> getSystemEnvironment() {
 		if (suppressGetenvAccess()) {
 			return Collections.emptyMap();
@@ -399,7 +419,8 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 		return SpringProperties.getFlag(IGNORE_GETENV_PROPERTY_NAME);
 	}
 
-	@SuppressWarnings("unchecked")
+	@Override
+	@SuppressWarnings({"unchecked", "rawtypes"})
 	public Map<String, Object> getSystemProperties() {
 		try {
 			return (Map) System.getProperties();
@@ -424,19 +445,28 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 		}
 	}
 
+	@Override
 	public void merge(ConfigurableEnvironment parent) {
 		for (PropertySource<?> ps : parent.getPropertySources()) {
 			if (!this.propertySources.contains(ps.getName())) {
 				this.propertySources.addLast(ps);
 			}
 		}
-		for (String profile : parent.getActiveProfiles()) {
-			this.activeProfiles.add(profile);
+		String[] parentActiveProfiles = parent.getActiveProfiles();
+		if (!ObjectUtils.isEmpty(parentActiveProfiles)) {
+			synchronized (this.activeProfiles) {
+				for (String profile : parentActiveProfiles) {
+					this.activeProfiles.add(profile);
+				}
+			}
 		}
-		if (parent.getDefaultProfiles().length > 0) {
-			this.defaultProfiles.remove(RESERVED_DEFAULT_PROFILE_NAME);
-			for (String profile : parent.getDefaultProfiles()) {
-				this.defaultProfiles.add(profile);
+		String[] parentDefaultProfiles = parent.getDefaultProfiles();
+		if (!ObjectUtils.isEmpty(parentDefaultProfiles)) {
+			synchronized (this.defaultProfiles) {
+				this.defaultProfiles.remove(RESERVED_DEFAULT_PROFILE_NAME);
+				for (String profile : parentDefaultProfiles) {
+					this.defaultProfiles.add(profile);
+				}
 			}
 		}
 	}
@@ -446,34 +476,42 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 	// Implementation of ConfigurablePropertyResolver interface
 	//---------------------------------------------------------------------
 
+	@Override
 	public ConfigurableConversionService getConversionService() {
 		return this.propertyResolver.getConversionService();
 	}
 
+	@Override
 	public void setConversionService(ConfigurableConversionService conversionService) {
 		this.propertyResolver.setConversionService(conversionService);
 	}
 
+	@Override
 	public void setPlaceholderPrefix(String placeholderPrefix) {
 		this.propertyResolver.setPlaceholderPrefix(placeholderPrefix);
 	}
 
+	@Override
 	public void setPlaceholderSuffix(String placeholderSuffix) {
 		this.propertyResolver.setPlaceholderSuffix(placeholderSuffix);
 	}
 
+	@Override
 	public void setValueSeparator(String valueSeparator) {
 		this.propertyResolver.setValueSeparator(valueSeparator);
 	}
 
+	@Override
 	public void setIgnoreUnresolvableNestedPlaceholders(boolean ignoreUnresolvableNestedPlaceholders) {
 		this.propertyResolver.setIgnoreUnresolvableNestedPlaceholders(ignoreUnresolvableNestedPlaceholders);
 	}
 
+	@Override
 	public void setRequiredProperties(String... requiredProperties) {
 		this.propertyResolver.setRequiredProperties(requiredProperties);
 	}
 
+	@Override
 	public void validateRequiredProperties() throws MissingRequiredPropertiesException {
 		this.propertyResolver.validateRequiredProperties();
 	}
@@ -488,38 +526,47 @@ public abstract class AbstractEnvironment implements ConfigurableEnvironment {
 		return this.propertyResolver.containsProperty(key);
 	}
 
+	@Override
 	public String getProperty(String key) {
 		return this.propertyResolver.getProperty(key);
 	}
 
+	@Override
 	public String getProperty(String key, String defaultValue) {
 		return this.propertyResolver.getProperty(key, defaultValue);
 	}
 
+	@Override
 	public <T> T getProperty(String key, Class<T> targetType) {
 		return this.propertyResolver.getProperty(key, targetType);
 	}
 
+	@Override
 	public <T> T getProperty(String key, Class<T> targetType, T defaultValue) {
 		return this.propertyResolver.getProperty(key, targetType, defaultValue);
 	}
 
+	@Override
 	public <T> Class<T> getPropertyAsClass(String key, Class<T> targetType) {
 		return this.propertyResolver.getPropertyAsClass(key, targetType);
 	}
 
+	@Override
 	public String getRequiredProperty(String key) throws IllegalStateException {
 		return this.propertyResolver.getRequiredProperty(key);
 	}
 
+	@Override
 	public <T> T getRequiredProperty(String key, Class<T> targetType) throws IllegalStateException {
 		return this.propertyResolver.getRequiredProperty(key, targetType);
 	}
 
+	@Override
 	public String resolvePlaceholders(String text) {
 		return this.propertyResolver.resolvePlaceholders(text);
 	}
 
+	@Override
 	public String resolveRequiredPlaceholders(String text) throws IllegalArgumentException {
 		return this.propertyResolver.resolveRequiredPlaceholders(text);
 	}
