@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,17 +18,22 @@ package org.springframework.core.annotation;
 
 import java.lang.annotation.Annotation;
 import java.lang.annotation.Inherited;
+import java.lang.annotation.Repeatable;
 import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.reflect.Method;
 import java.util.Arrays;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 
 import org.junit.Test;
 
 import org.springframework.core.Ordered;
+import org.springframework.core.annotation.subpackage.NonPublicAnnotatedClass;
 import org.springframework.stereotype.Component;
 
+import static org.hamcrest.Matchers.*;
 import static org.junit.Assert.*;
 import static org.springframework.core.annotation.AnnotationUtils.*;
 
@@ -39,6 +44,7 @@ import static org.springframework.core.annotation.AnnotationUtils.*;
  * @author Juergen Hoeller
  * @author Sam Brannen
  * @author Chris Beams
+ * @author Phillip Webb
  */
 public class AnnotationUtilsTests {
 
@@ -93,6 +99,66 @@ public class AnnotationUtilsTests {
 	// assertNotNull(o);
 	// }
 
+	/**
+	 * @since 4.1.2
+	 */
+	@Test
+	public void findAnnotationFavorsLocalMetaAnnotationsOverInterfaces() {
+		Component component = AnnotationUtils.findAnnotation(
+				ClassWithLocalMetaAnnotationAndMetaAnnotatedInterface.class, Component.class);
+		assertNotNull(component);
+		assertEquals("meta2", component.value());
+	}
+
+	/**
+	 * @since 4.0.3
+	 */
+	@Test
+	public void findAnnotationFavorsInheritedAnnotationsOverMoreLocallyDeclaredComposedAnnotations() {
+		Transactional transactional = AnnotationUtils.findAnnotation(
+				SubSubClassWithInheritedAnnotation.class, Transactional.class);
+		assertNotNull(transactional);
+		assertTrue("readOnly flag for SubSubClassWithInheritedAnnotation", transactional.readOnly());
+	}
+
+	/**
+	 * @since 4.0.3
+	 */
+	@Test
+	public void findAnnotationFavorsInheritedComposedAnnotationsOverMoreLocallyDeclaredComposedAnnotations() {
+		Component component = AnnotationUtils.findAnnotation(
+				SubSubClassWithInheritedMetaAnnotation.class, Component.class);
+		assertNotNull(component);
+		assertEquals("meta2", component.value());
+	}
+
+	@Test
+	public void findAnnotationOnMetaMetaAnnotatedClass() {
+		Component component = AnnotationUtils.findAnnotation(MetaMetaAnnotatedClass.class, Component.class);
+		assertNotNull("Should find meta-annotation on composed annotation on class", component);
+		assertEquals("meta2", component.value());
+	}
+
+	@Test
+	public void findAnnotationOnMetaMetaMetaAnnotatedClass() {
+		Component component = AnnotationUtils.findAnnotation(MetaMetaMetaAnnotatedClass.class, Component.class);
+		assertNotNull("Should find meta-annotation on meta-annotation on composed annotation on class", component);
+		assertEquals("meta2", component.value());
+	}
+
+	@Test
+	public void findAnnotationOnAnnotatedClassWithMissingTargetMetaAnnotation() {
+		// TransactionalClass is NOT annotated or meta-annotated with @Component
+		Component component = AnnotationUtils.findAnnotation(TransactionalClass.class, Component.class);
+		assertNull("Should not find @Component on TransactionalClass", component);
+	}
+
+	@Test
+	public void findAnnotationOnMetaCycleAnnotatedClassWithMissingTargetMetaAnnotation() {
+		Component component = AnnotationUtils.findAnnotation(MetaCycleAnnotatedClass.class, Component.class);
+		assertNull("Should not find @Component on MetaCycleAnnotatedClass", component);
+	}
+
 	@Test
 	public void testFindAnnotationDeclaringClass() throws Exception {
 		// no class-level annotation
@@ -235,11 +301,13 @@ public class AnnotationUtilsTests {
 
 	@Test
 	public void getValueFromNonPublicAnnotation() throws Exception {
-		Method method = SimpleFoo.class.getMethod("something", Object.class);
-		Order order = findAnnotation(method, Order.class);
-
-		assertEquals(Ordered.LOWEST_PRECEDENCE, AnnotationUtils.getDefaultValue(order, AnnotationUtils.VALUE));
-		assertEquals(Ordered.LOWEST_PRECEDENCE, AnnotationUtils.getDefaultValue(order));
+		Annotation[] declaredAnnotations = NonPublicAnnotatedClass.class.getDeclaredAnnotations();
+		assertEquals(1, declaredAnnotations.length);
+		Annotation annotation = declaredAnnotations[0];
+		assertNotNull(annotation);
+		assertEquals("NonPublicAnnotation", annotation.annotationType().getSimpleName());
+		assertEquals(42, AnnotationUtils.getValue(annotation, AnnotationUtils.VALUE));
+		assertEquals(42, AnnotationUtils.getValue(annotation));
 	}
 
 	@Test
@@ -253,6 +321,23 @@ public class AnnotationUtilsTests {
 
 	@Test
 	public void getDefaultValueFromNonPublicAnnotation() throws Exception {
+		Annotation[] declaredAnnotations = NonPublicAnnotatedClass.class.getDeclaredAnnotations();
+		assertEquals(1, declaredAnnotations.length);
+		Annotation annotation = declaredAnnotations[0];
+		assertNotNull(annotation);
+		assertEquals("NonPublicAnnotation", annotation.annotationType().getSimpleName());
+		assertEquals(-1, AnnotationUtils.getDefaultValue(annotation, AnnotationUtils.VALUE));
+		assertEquals(-1, AnnotationUtils.getDefaultValue(annotation));
+	}
+
+	@Test
+	public void getDefaultValueFromAnnotationType() throws Exception {
+		assertEquals(Ordered.LOWEST_PRECEDENCE, AnnotationUtils.getDefaultValue(Order.class, AnnotationUtils.VALUE));
+		assertEquals(Ordered.LOWEST_PRECEDENCE, AnnotationUtils.getDefaultValue(Order.class));
+	}
+
+	@Test
+	public void findAnnotationFromInterface() throws Exception {
 		Method method = ImplementsInterfaceWithAnnotatedMethod.class.getMethod("foo");
 		Order order = findAnnotation(method, Order.class);
 		assertNotNull(order);
@@ -272,21 +357,105 @@ public class AnnotationUtilsTests {
 		assertNotNull(order);
 	}
 
+	@Test
+	public void findRepeatableAnnotationOnComposedAnnotation() {
+		Repeatable repeatable = findAnnotation(MyRepeatableMeta.class, Repeatable.class);
+		assertNotNull(repeatable);
+		assertEquals(MyRepeatableContainer.class, repeatable.value());
+	}
+
+	@Test
+	public void getRepeatableFromMethod() throws Exception {
+		Method method = InterfaceWithRepeated.class.getMethod("foo");
+		Set<MyRepeatable> annotions = AnnotationUtils.getRepeatableAnnotation(method,
+				MyRepeatableContainer.class, MyRepeatable.class);
+		Set<String> values = new HashSet<String>();
+		for (MyRepeatable myRepeatable : annotions) {
+			values.add(myRepeatable.value());
+		}
+		assertThat(values, equalTo((Set<String>) new HashSet<String>(
+				Arrays.asList("a", "b", "c", "meta"))));
+	}
+
 
 	@Component(value = "meta1")
+	@Order
 	@Retention(RetentionPolicy.RUNTIME)
+	@Inherited
 	@interface Meta1 {
 	}
 
 	@Component(value = "meta2")
+	@Transactional(readOnly = true)
 	@Retention(RetentionPolicy.RUNTIME)
 	@interface Meta2 {
 	}
 
-	@Meta1
-	@Component(value = "local")
 	@Meta2
-	static class HasLocalAndMetaComponentAnnotation {
+	@Retention(RetentionPolicy.RUNTIME)
+	@interface MetaMeta {
+	}
+
+	@MetaMeta
+	@Retention(RetentionPolicy.RUNTIME)
+	@interface MetaMetaMeta {
+	}
+
+	@MetaCycle3
+	@Retention(RetentionPolicy.RUNTIME)
+	@interface MetaCycle1 {
+	}
+
+	@MetaCycle1
+	@Retention(RetentionPolicy.RUNTIME)
+	@interface MetaCycle2 {
+	}
+
+	@MetaCycle2
+	@Retention(RetentionPolicy.RUNTIME)
+	@interface MetaCycle3 {
+	}
+
+	@Meta1
+	static interface InterfaceWithMetaAnnotation {
+	}
+
+	@Meta2
+	static class ClassWithLocalMetaAnnotationAndMetaAnnotatedInterface implements InterfaceWithMetaAnnotation {
+	}
+
+	@Meta1
+	static class ClassWithInheritedMetaAnnotation {
+	}
+
+	@Meta2
+	static class SubClassWithInheritedMetaAnnotation extends ClassWithInheritedMetaAnnotation {
+	}
+
+	static class SubSubClassWithInheritedMetaAnnotation extends SubClassWithInheritedMetaAnnotation {
+	}
+
+	@Transactional
+	static class ClassWithInheritedAnnotation {
+	}
+
+	@Meta2
+	static class SubClassWithInheritedAnnotation extends ClassWithInheritedAnnotation {
+	}
+
+	static class SubSubClassWithInheritedAnnotation extends SubClassWithInheritedAnnotation {
+	}
+
+	@MetaMeta
+	static class MetaMetaAnnotatedClass {
+	}
+
+	@MetaMetaMeta
+	static class MetaMetaMetaAnnotatedClass {
+	}
+
+	@MetaCycle3
+	static class MetaCycleAnnotatedClass {
 	}
 
 	public static interface AnnotatedInterface {
@@ -299,25 +468,20 @@ public class AnnotationUtilsTests {
 
 		@Order(27)
 		public void annotatedOnRoot() {
-
 		}
 
 		public void overrideToAnnotate() {
-
 		}
 
 		@Order(27)
 		public void overrideWithoutNewAnnotation() {
-
 		}
 
 		public void notAnnotated() {
-
 		}
 
 		@Override
 		public void fromInterfaceImplementedByRoot() {
-
 		}
 	}
 
@@ -325,18 +489,15 @@ public class AnnotationUtilsTests {
 
 		@Order(25)
 		public void annotatedOnLeaf() {
-
 		}
 
 		@Override
 		@Order(1)
 		public void overrideToAnnotate() {
-
 		}
 
 		@Override
 		public void overrideWithoutNewAnnotation() {
-
 		}
 	}
 
@@ -344,6 +505,7 @@ public class AnnotationUtilsTests {
 	@Inherited
 	@interface Transactional {
 
+		boolean readOnly() default false;
 	}
 
 	public static abstract class Foo<T> {
@@ -357,7 +519,6 @@ public class AnnotationUtilsTests {
 		@Override
 		@Transactional
 		public void something(final String arg) {
-
 		}
 	}
 
@@ -400,7 +561,7 @@ public class AnnotationUtilsTests {
 	}
 
 	@Order
-	public static class TransactionalAndOrderedClass {
+	public static class TransactionalAndOrderedClass extends TransactionalClass {
 	}
 
 	public static class SubTransactionalAndOrderedClass extends TransactionalAndOrderedClass {
@@ -426,16 +587,45 @@ public class AnnotationUtilsTests {
 		}
 	}
 
-	public abstract static class AbstractDoesNotImplementInterfaceWithAnnotatedMethod implements
-			InterfaceWithAnnotatedMethod {
+	public abstract static class AbstractDoesNotImplementInterfaceWithAnnotatedMethod
+			implements InterfaceWithAnnotatedMethod {
 	}
 
-	public static class SubOfAbstractImplementsInterfaceWithAnnotatedMethod extends
-			AbstractDoesNotImplementInterfaceWithAnnotatedMethod {
+	public static class SubOfAbstractImplementsInterfaceWithAnnotatedMethod
+			extends AbstractDoesNotImplementInterfaceWithAnnotatedMethod {
 
 		@Override
 		public void foo() {
 		}
 	}
 
+	@Retention(RetentionPolicy.RUNTIME)
+	@Inherited
+	@interface MyRepeatableContainer {
+
+		MyRepeatable[] value();
+	}
+
+	@Retention(RetentionPolicy.RUNTIME)
+	@Inherited
+	@Repeatable(MyRepeatableContainer.class)
+	@interface MyRepeatable {
+
+		String value();
+	}
+
+	@Retention(RetentionPolicy.RUNTIME)
+	@Inherited
+	@MyRepeatable("meta")
+	@interface MyRepeatableMeta {
+	}
+
+	public static interface InterfaceWithRepeated {
+
+		@MyRepeatable("a")
+		@MyRepeatableContainer({ @MyRepeatable("b"), @MyRepeatable("c") })
+		@MyRepeatableMeta
+		void foo();
+	}
+
 }
