@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -112,17 +113,17 @@ public class GenericConversionServiceTests {
 		assertEquals(null, conversionService.convert(null, Integer.class));
 	}
 
-	@Test(expected=ConversionFailedException.class)
+	@Test(expected = ConversionFailedException.class)
 	public void convertNullSourcePrimitiveTarget() {
 		assertEquals(null, conversionService.convert(null, int.class));
 	}
 
-	@Test(expected=ConversionFailedException.class)
+	@Test(expected = ConversionFailedException.class)
 	public void convertNullSourcePrimitiveTargetTypeDescriptor() {
 		conversionService.convert(null, TypeDescriptor.valueOf(String.class), TypeDescriptor.valueOf(int.class));
 	}
 
-	@Test(expected=IllegalArgumentException.class)
+	@Test(expected = IllegalArgumentException.class)
 	public void convertNotNullSourceNullSourceTypeDescriptor() {
 		conversionService.convert("3", null, TypeDescriptor.valueOf(int.class));
 	}
@@ -176,18 +177,18 @@ public class GenericConversionServiceTests {
 		assertNull(conversionService.convert(null, Integer.class));
 	}
 
-	@Test(expected=IllegalArgumentException.class)
+	@Test(expected = IllegalArgumentException.class)
 	public void convertNullTargetClass() {
 		assertNull(conversionService.convert("3", (Class<?>) null));
 		assertNull(conversionService.convert("3", TypeDescriptor.valueOf(String.class), null));
 	}
 
-	@Test(expected=IllegalArgumentException.class)
+	@Test(expected = IllegalArgumentException.class)
 	public void convertNullTypeDescriptor() {
 		assertNull(conversionService.convert("3", TypeDescriptor.valueOf(String.class), null));
 	}
 
-	@Test(expected=IllegalArgumentException.class)
+	@Test(expected = IllegalArgumentException.class)
 	public void convertWrongSourceTypeDescriptor() {
 		conversionService.convert("3", TypeDescriptor.valueOf(Integer.class), TypeDescriptor.valueOf(Long.class));
 	}
@@ -217,8 +218,7 @@ public class GenericConversionServiceTests {
 	}
 
 	// SPR-8718
-
-	@Test(expected=ConverterNotFoundException.class)
+	@Test(expected = ConverterNotFoundException.class)
 	public void convertSuperTarget() {
 		conversionService.addConverter(new ColorConverter());
 		conversionService.convert("#000000", SystemColor.class);
@@ -294,7 +294,7 @@ public class GenericConversionServiceTests {
 	@Test
 	public void testInterfaceToString() {
 		GenericConversionService conversionService = new GenericConversionService();
-		conversionService.addConverter(new MyBaseInterfaceConverter());
+		conversionService.addConverter(new MyBaseInterfaceToStringConverter());
 		conversionService.addConverter(new ObjectToStringConverter());
 		Object converted = conversionService.convert(new MyInterfaceImplementer(), String.class);
 		assertEquals("RESULT", converted);
@@ -303,7 +303,7 @@ public class GenericConversionServiceTests {
 	@Test
 	public void testInterfaceArrayToStringArray() {
 		GenericConversionService conversionService = new GenericConversionService();
-		conversionService.addConverter(new MyBaseInterfaceConverter());
+		conversionService.addConverter(new MyBaseInterfaceToStringConverter());
 		conversionService.addConverter(new ArrayToArrayConverter(conversionService));
 		String[] converted = conversionService.convert(new MyInterface[] {new MyInterfaceImplementer()}, String[].class);
 		assertEquals("RESULT", converted[0]);
@@ -312,7 +312,7 @@ public class GenericConversionServiceTests {
 	@Test
 	public void testObjectArrayToStringArray() {
 		GenericConversionService conversionService = new GenericConversionService();
-		conversionService.addConverter(new MyBaseInterfaceConverter());
+		conversionService.addConverter(new MyBaseInterfaceToStringConverter());
 		conversionService.addConverter(new ArrayToArrayConverter(conversionService));
 		String[] converted = conversionService.convert(new MyInterfaceImplementer[] {new MyInterfaceImplementer()}, String[].class);
 		assertEquals("RESULT", converted[0]);
@@ -445,8 +445,6 @@ public class GenericConversionServiceTests {
 		System.out.println(watch.prettyPrint());
 	}
 
-	public static List<Integer> list;
-
 	@Test
 	public void testPerformance3() throws Exception {
 		Assume.group(TestGroup.PERFORMANCE);
@@ -473,8 +471,6 @@ public class GenericConversionServiceTests {
 		System.out.println(watch.prettyPrint());
 	}
 
-	public static Map<String, Integer> map;
-
 	@Test
 	public void emptyListToArray() {
 		conversionService.addConverter(new CollectionToArrayConverter(conversionService));
@@ -483,7 +479,7 @@ public class GenericConversionServiceTests {
 		TypeDescriptor sourceType = TypeDescriptor.forObject(list);
 		TypeDescriptor targetType = TypeDescriptor.valueOf(String[].class);
 		assertTrue(conversionService.canConvert(sourceType, targetType));
-		assertEquals(0, ((String[])conversionService.convert(list, sourceType, targetType)).length);
+		assertEquals(0, ((String[]) conversionService.convert(list, sourceType, targetType)).length);
 	}
 
 	@Test
@@ -497,82 +493,6 @@ public class GenericConversionServiceTests {
 		assertNull(conversionService.convert(list, sourceType, targetType));
 	}
 
-	private interface MyBaseInterface {
-
-	}
-
-
-	private interface MyInterface extends MyBaseInterface {
-
-	}
-
-
-	private static class MyInterfaceImplementer implements MyInterface {
-
-	}
-
-
-	private static class MyBaseInterfaceConverter implements Converter<MyBaseInterface, String> {
-
-		@Override
-		public String convert(MyBaseInterface source) {
-			return "RESULT";
-		}
-	}
-
-
-	private static class MyStringArrayToResourceArrayConverter implements Converter<String[], Resource[]>	{
-
-		@Override
-		public Resource[] convert(String[] source) {
-			Resource[] result = new Resource[source.length];
-			for (int i = 0; i < source.length; i++) {
-				result[i] = new DescriptiveResource(source[i].substring(1));
-			}
-			return result;
-		}
-	}
-
-
-	private static class MyStringArrayToIntegerArrayConverter implements Converter<String[], Integer[]>	{
-
-		@Override
-		public Integer[] convert(String[] source) {
-			Integer[] result = new Integer[source.length];
-			for (int i = 0; i < source.length; i++) {
-				result[i] = Integer.parseInt(source[i].substring(1));
-			}
-			return result;
-		}
-	}
-
-
-	private static class MyStringToIntegerArrayConverter implements Converter<String, Integer[]>	{
-
-		@Override
-		public Integer[] convert(String source) {
-			String[] srcArray = StringUtils.commaDelimitedListToStringArray(source);
-			Integer[] result = new Integer[srcArray.length];
-			for (int i = 0; i < srcArray.length; i++) {
-				result[i] = Integer.parseInt(srcArray[i].substring(1));
-			}
-			return result;
-		}
-	}
-
-
-	public static class WithCopyConstructor {
-
-		public WithCopyConstructor() {
-		}
-
-		public WithCopyConstructor(WithCopyConstructor value) {
-		}
-	}
-
-
-	public static Map<String, ?> wildcardMap;
-
 	@Test
 	public void stringToArrayCanConvert() {
 		conversionService.addConverter(new StringToArrayConverter(conversionService));
@@ -585,14 +505,12 @@ public class GenericConversionServiceTests {
 	public void stringToCollectionCanConvert() throws Exception {
 		conversionService.addConverter(new StringToCollectionConverter(conversionService));
 		assertTrue(conversionService.canConvert(String.class, Collection.class));
-		TypeDescriptor targetType = new TypeDescriptor(getClass().getField("stringToCollection"));
+		TypeDescriptor targetType = new TypeDescriptor(getClass().getField("integerCollection"));
 		assertFalse(conversionService.canConvert(TypeDescriptor.valueOf(String.class), targetType));
 		conversionService.addConverterFactory(new StringToNumberConverterFactory());
 		assertTrue(conversionService.canConvert(TypeDescriptor.valueOf(String.class), targetType));
 	}
 
-	public Collection<Integer> stringToCollection;
-
 	@Test
 	public void testConvertiblePairsInSet() {
 		Set<GenericConverter.ConvertiblePair> set = new HashSet<GenericConverter.ConvertiblePair>();
@@ -767,6 +685,27 @@ public class GenericConversionServiceTests {
 		assertEquals("1", result);
 	}
 
+	@Test
+	public void testStringToEnumWithInterfaceConversion() {
+		conversionService.addConverterFactory(new StringToEnumConverterFactory());
+		conversionService.addConverterFactory(new StringToMyEnumInterfaceConverterFactory());
+		assertEquals(MyEnum.A, conversionService.convert("1", MyEnum.class));
+	}
+
+	@Test
+	public void testStringToEnumWithBaseInterfaceConversion() {
+		conversionService.addConverterFactory(new StringToEnumConverterFactory());
+		conversionService.addConverterFactory(new StringToMyEnumBaseInterfaceConverterFactory());
+		assertEquals(MyEnum.A, conversionService.convert("base1", MyEnum.class));
+	}
+
+	@Test
+	public void testStringToEnumSet() throws Exception {
+		DefaultConversionService.addDefaultConverters(conversionService);
+		assertEquals(EnumSet.of(MyEnum.A),
+				conversionService.convert("A", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("enumSet"))));
+	}
+
 	@Test
 	public void convertNullAnnotatedStringToString() throws Exception {
 		DefaultConversionService.addDefaultConverters(conversionService);
@@ -783,7 +722,7 @@ public class GenericConversionServiceTests {
 		conversionService.addConverter(new MyStringToStringCollectionConverter());
 		conversionService.addConverter(new MyStringToIntegerCollectionConverter());
 
-		assertEquals(Collections.singleton(4),  // should be "testX" from MyStringToStringCollectionConverter, ideally
+		assertEquals(Collections.singleton("testX"),
 				conversionService.convert("test", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("stringCollection"))));
 		assertEquals(Collections.singleton(4),
 				conversionService.convert("test", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("integerCollection"))));
@@ -793,7 +732,7 @@ public class GenericConversionServiceTests {
 				conversionService.convert("test", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("genericCollection"))));
 		assertEquals(Collections.singleton(4),
 				conversionService.convert("test", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("rawCollection"))));
-		assertEquals(Collections.singleton(4),  // should be "testX" from MyStringToStringCollectionConverter, ideally
+		assertEquals(Collections.singleton("testX"),
 				conversionService.convert("test", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("stringCollection"))));
 	}
 
@@ -814,9 +753,13 @@ public class GenericConversionServiceTests {
 		assertEquals(Collections.singleton("testX"),
 				conversionService.convert("test", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("rawCollection"))));
 
-		// The following is unpleasant but simply a consequence of the raw type matching algorithm in Spring 3.x
-		assertEquals(Collections.singleton("testX"),
-				conversionService.convert("test", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("integerCollection"))));
+		try {
+			conversionService.convert("test", TypeDescriptor.valueOf(String.class), new TypeDescriptor(getClass().getField("integerCollection")));
+			fail("Should have thrown ConverterNotFoundException");
+		}
+		catch (ConverterNotFoundException ex) {
+			// expected
+		}
 	}
 
 	@Test
@@ -852,15 +795,80 @@ public class GenericConversionServiceTests {
 	}
 
 
-	@ExampleAnnotation
-	public String annotatedString;
-
-
 	@Retention(RetentionPolicy.RUNTIME)
 	public static @interface ExampleAnnotation {
 	}
 
 
+	private interface MyBaseInterface {
+	}
+
+
+	private interface MyInterface extends MyBaseInterface {
+	}
+
+
+	private static class MyInterfaceImplementer implements MyInterface {
+	}
+
+
+	private static class MyBaseInterfaceToStringConverter implements Converter<MyBaseInterface, String> {
+
+		@Override
+		public String convert(MyBaseInterface source) {
+			return "RESULT";
+		}
+	}
+
+
+	private static class MyStringArrayToResourceArrayConverter implements Converter<String[], Resource[]>	{
+
+		@Override
+		public Resource[] convert(String[] source) {
+			Resource[] result = new Resource[source.length];
+			for (int i = 0; i < source.length; i++) {
+				result[i] = new DescriptiveResource(source[i].substring(1));
+			}
+			return result;
+		}
+	}
+
+
+	private static class MyStringArrayToIntegerArrayConverter implements Converter<String[], Integer[]>	{
+
+		@Override
+		public Integer[] convert(String[] source) {
+			Integer[] result = new Integer[source.length];
+			for (int i = 0; i < source.length; i++) {
+				result[i] = Integer.parseInt(source[i].substring(1));
+			}
+			return result;
+		}
+	}
+
+
+	private static class MyStringToIntegerArrayConverter implements Converter<String, Integer[]>	{
+
+		@Override
+		public Integer[] convert(String source) {
+			String[] srcArray = StringUtils.commaDelimitedListToStringArray(source);
+			Integer[] result = new Integer[srcArray.length];
+			for (int i = 0; i < srcArray.length; i++) {
+				result[i] = Integer.parseInt(srcArray[i].substring(1));
+			}
+			return result;
+		}
+	}
+
+
+	public static class WithCopyConstructor {
+
+		public WithCopyConstructor() {
+		}
+
+		public WithCopyConstructor(WithCopyConstructor value) {
+		}
+	}
 	private static class MyConditionalConverter implements Converter<String, Color>, ConditionalConverter {
 
 		private int matchAttempts = 0;
@@ -936,7 +944,13 @@ public class GenericConversionServiceTests {
 	}
 
 
-	interface MyEnumInterface {
+	interface MyEnumBaseInterface {
+
+		String getBaseCode();
+	}
+
+
+	interface MyEnumInterface extends MyEnumBaseInterface {
 
 		String getCode();
 	}
@@ -944,11 +958,24 @@ public class GenericConversionServiceTests {
 
 	public static enum MyEnum implements MyEnumInterface {
 
-		A {
-			@Override
-			public String getCode() {
-				return "1";
-			}
+		A("1"),
+		B("2"),
+		C("3");
+
+		private String code;
+
+		MyEnum(String code) {
+			this.code = code;
+		}
+
+		@Override
+		public String getCode() {
+			return code;
+		}
+
+		@Override
+		public String getBaseCode() {
+			return "base" + code;
 		}
 	}
 
@@ -991,6 +1018,59 @@ public class GenericConversionServiceTests {
 	}
 
 
+	private static class StringToMyEnumInterfaceConverterFactory implements ConverterFactory<String, MyEnumInterface> {
+
+		@SuppressWarnings("unchecked")
+		public <T extends MyEnumInterface> Converter<String, T> getConverter(Class<T> targetType) {
+			return new StringToMyEnumInterfaceConverter(targetType);
+		}
+
+		private static class StringToMyEnumInterfaceConverter<T extends Enum<?> & MyEnumInterface> implements Converter<String, T> {
+			private final Class<T> enumType;
+
+			public StringToMyEnumInterfaceConverter(Class<T> enumType) {
+				this.enumType = enumType;
+			}
+
+			public T convert(String source) {
+				for (T value : enumType.getEnumConstants()) {
+					if (value.getCode().equals(source)) {
+						return value;
+					}
+				}
+				return null;
+			}
+		}
+	}
+
+
+	private static class StringToMyEnumBaseInterfaceConverterFactory implements ConverterFactory<String, MyEnumBaseInterface> {
+
+		@SuppressWarnings("unchecked")
+		public <T extends MyEnumBaseInterface> Converter<String, T> getConverter(Class<T> targetType) {
+			return new StringToMyEnumBaseInterfaceConverter(targetType);
+		}
+
+		private static class StringToMyEnumBaseInterfaceConverter<T extends Enum<?> & MyEnumBaseInterface> implements Converter<String, T> {
+
+			private final Class<T> enumType;
+
+			public StringToMyEnumBaseInterfaceConverter(Class<T> enumType) {
+				this.enumType = enumType;
+			}
+
+			public T convert(String source) {
+				for (T value : enumType.getEnumConstants()) {
+					if (value.getBaseCode().equals(source)) {
+						return value;
+					}
+				}
+				return null;
+			}
+		}
+	}
+
+
 	public static class MyStringToStringCollectionConverter implements Converter<String, Collection<String>> {
 
 		@Override
@@ -1009,6 +1089,17 @@ public class GenericConversionServiceTests {
 	}
 
 
+	@ExampleAnnotation
+	public String annotatedString;
+
+	public List<Integer> list;
+
+	public Map<String, Integer> map;
+
+	public Map<String, ?> wildcardMap;
+
+	public EnumSet<MyEnum> enumSet;
+
 	public Collection rawCollection;
 
 	public Collection<?> genericCollection;
