@@ -16,11 +16,11 @@
 
 package org.springframework.tests;
 
-import static org.hamcrest.Matchers.startsWith;
-import static org.junit.Assert.*;
-
 import org.junit.Test;
 
+import static org.hamcrest.Matchers.*;
+import static org.junit.Assert.*;
+
 /**
  * Tests for {@link JavaVersion}.
  *
