@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,10 +23,11 @@ import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 
-import static org.junit.Assert.*;
 import org.junit.Before;
 import org.junit.Test;
 
+import static org.junit.Assert.*;
+
 /**
  * @author Alef Arendsen
  * @author Seth Ladd
@@ -62,7 +63,7 @@ public class AntPathMatcherTests {
 		assertFalse(pathMatcher.match("tes?", "testt"));
 		assertFalse(pathMatcher.match("tes?", "tsst"));
 
-		// test matchin with *'s
+		// test matching with *'s
 		assertTrue(pathMatcher.match("*", "test"));
 		assertTrue(pathMatcher.match("test*", "test"));
 		assertTrue(pathMatcher.match("test*", "testTest"));
@@ -147,7 +148,7 @@ public class AntPathMatcherTests {
 		assertFalse(pathMatcher.matchStart("tes?", "testt"));
 		assertFalse(pathMatcher.matchStart("tes?", "tsst"));
 
-		// test matchin with *'s
+		// test matching with *'s
 		assertTrue(pathMatcher.matchStart("*", "test"));
 		assertTrue(pathMatcher.matchStart("test*", "test"));
 		assertTrue(pathMatcher.matchStart("test*", "testTest"));
@@ -236,7 +237,7 @@ public class AntPathMatcherTests {
 		assertFalse(pathMatcher.match("tes?", "testt"));
 		assertFalse(pathMatcher.match("tes?", "tsst"));
 
-		// test matchin with *'s
+		// test matching with *'s
 		assertTrue(pathMatcher.match("*", "test"));
 		assertTrue(pathMatcher.match("test*", "test"));
 		assertTrue(pathMatcher.match("test*", "testTest"));
@@ -293,6 +294,10 @@ public class AntPathMatcherTests {
 		assertEquals("/docs/commit.html", pathMatcher.extractPathWithinPattern("*.html", "/docs/commit.html"));
 		assertEquals("/docs/commit.html", pathMatcher.extractPathWithinPattern("**/*.*", "/docs/commit.html"));
 		assertEquals("/docs/commit.html", pathMatcher.extractPathWithinPattern("*", "/docs/commit.html"));
+		//SPR-10515
+		assertEquals("/docs/cvs/other/commit.html", pathMatcher.extractPathWithinPattern("**/commit.html", "/docs/cvs/other/commit.html"));
+		assertEquals("cvs/other/commit.html", pathMatcher.extractPathWithinPattern("/docs/**/commit.html", "/docs/cvs/other/commit.html"));
+		assertEquals("cvs/other/commit.html", pathMatcher.extractPathWithinPattern("/docs/**/**/**/**", "/docs/cvs/other/commit.html"));
 
 		assertEquals("docs/cvs/commit", pathMatcher.extractPathWithinPattern("/d?cs/*", "/docs/cvs/commit"));
 		assertEquals("cvs/commit.html",
@@ -349,8 +354,9 @@ public class AntPathMatcherTests {
 		assertEquals("1.0.0", result.get("version"));
 	}
 
-	// SPR-7787
-
+	/**
+	 * SPR-7787
+	 */
 	@Test
 	public void extractUriTemplateVarsRegexQualifiers() {
 		Map<String, String> result = pathMatcher.extractUriTemplateVariables(
@@ -375,16 +381,18 @@ public class AntPathMatcherTests {
 		assertEquals("1.0.0.{12}", result.get("version"));
 	}
 
-	// SPR-8455
-
+	/**
+	 * SPR-8455
+	 */
 	@Test
 	public void extractUriTemplateVarsRegexCapturingGroups() {
 		try {
 			pathMatcher.extractUriTemplateVariables("/web/{id:foo(bar)?}", "/web/foobar");
 			fail("Expected exception");
-		} catch (IllegalArgumentException e) {
+		}
+		catch (IllegalArgumentException ex) {
 			assertTrue("Expected helpful message on the use of capturing groups",
-					e.getMessage().contains("The number of capturing groups in the pattern"));
+					ex.getMessage().contains("The number of capturing groups in the pattern"));
 		}
 	}
 
@@ -399,6 +407,7 @@ public class AntPathMatcherTests {
 		assertEquals("/hotels/**/booking", pathMatcher.combine("/hotels/**", "/booking"));
 		assertEquals("/hotels/booking", pathMatcher.combine("/hotels", "/booking"));
 		assertEquals("/hotels/booking", pathMatcher.combine("/hotels", "booking"));
+		assertEquals("/hotels/booking", pathMatcher.combine("/hotels/", "booking"));
 		assertEquals("/hotels/{hotel}", pathMatcher.combine("/hotels/*", "{hotel}"));
 		assertEquals("/hotels/**/{hotel}", pathMatcher.combine("/hotels/**", "{hotel}"));
 		assertEquals("/hotels/{hotel}", pathMatcher.combine("/hotels", "{hotel}"));
@@ -413,6 +422,9 @@ public class AntPathMatcherTests {
 		assertEquals("/{foo}/bar", pathMatcher.combine("/{foo}", "/bar"));	// SPR-8858
 		assertEquals("/user/user", pathMatcher.combine("/user", "/user"));	// SPR-7970
 		assertEquals("/{foo:.*[^0-9].*}/edit/", pathMatcher.combine("/{foo:.*[^0-9].*}", "/edit/")); // SPR-10062
+		assertEquals("/1.0/foo/test", pathMatcher.combine("/1.0", "/foo/test")); // SPR-10554
+		assertEquals("/hotel", pathMatcher.combine("/", "/hotel")); // SPR-12975
+		assertEquals("/hotel/booking", pathMatcher.combine("/hotel/", "/booking")); // SPR-12975
 	}
 
 	@Test
@@ -435,16 +447,37 @@ public class AntPathMatcherTests {
 		assertEquals(-1, comparator.compare("/hotels/{hotel}/booking", "/hotels/{hotel}/bookings/{booking}"));
 		assertEquals(1, comparator.compare("/hotels/{hotel}/bookings/{booking}", "/hotels/{hotel}/booking"));
 
+		//SPR-10550
+		assertEquals(-1, comparator.compare("/hotels/{hotel}/bookings/{booking}/cutomers/{customer}", "/**"));
+		assertEquals(1, comparator.compare("/**","/hotels/{hotel}/bookings/{booking}/cutomers/{customer}"));
+		assertEquals(0, comparator.compare("/**","/**"));
+
 		assertEquals(-1, comparator.compare("/hotels/{hotel}", "/hotels/*"));
 		assertEquals(1, comparator.compare("/hotels/*", "/hotels/{hotel}"));
 
-		assertEquals(-2, comparator.compare("/hotels/*", "/hotels/*/**"));
-		assertEquals(2, comparator.compare("/hotels/*/**", "/hotels/*"));
+		assertEquals(-1, comparator.compare("/hotels/*", "/hotels/*/**"));
+		assertEquals(1, comparator.compare("/hotels/*/**", "/hotels/*"));
 
 		assertEquals(-1, comparator.compare("/hotels/new", "/hotels/new.*"));
+		assertEquals(2, comparator.compare("/hotels/{hotel}", "/hotels/{hotel}.*"));
+
+		//SPR-6741
+		assertEquals(-1, comparator.compare("/hotels/{hotel}/bookings/{booking}/cutomers/{customer}", "/hotels/**"));
+		assertEquals(1, comparator.compare("/hotels/**", "/hotels/{hotel}/bookings/{booking}/cutomers/{customer}"));
+		assertEquals(1, comparator.compare("/hotels/foo/bar/**", "/hotels/{hotel}"));
+		assertEquals(-1, comparator.compare("/hotels/{hotel}", "/hotels/foo/bar/**"));
+		assertEquals(2, comparator.compare("/hotels/**/bookings/**", "/hotels/**"));
+		assertEquals(-2, comparator.compare("/hotels/**", "/hotels/**/bookings/**"));
+
+		//SPR-8683
+		assertEquals(1, comparator.compare("/**", "/hotels/{hotel}"));
 
 		// longer is better
 		assertEquals(1, comparator.compare("/hotels", "/hotels2"));
+		
+		//SPR-13139
+		assertEquals(-1, comparator.compare("*", "*/**"));
+		assertEquals(1, comparator.compare("*/**", "*"));
 	}
 
 	@Test
@@ -543,8 +576,9 @@ public class AntPathMatcherTests {
 		paths.clear();
 	}
 
-	// SPR-8687
-
+	/**
+	 * SPR-8687
+	 */
 	@Test
 	public void trimTokensOff() {
 		pathMatcher.setTrimTokens(false);
@@ -553,4 +587,43 @@ public class AntPathMatcherTests {
 		assertTrue(pathMatcher.match("/group/{groupName}/members", "/group/  sales/members"));
 	}
 
+	@Test
+	public void defaultCacheSetting() {
+		match();
+		assertTrue(pathMatcher.stringMatcherCache.size() > 20);
+
+		for (int i = 0; i < 65536; i++) {
+			pathMatcher.match("test" + i, "test");
+		}
+		// Cache turned off because it went beyond the threshold
+		assertTrue(pathMatcher.stringMatcherCache.isEmpty());
+	}
+
+	@Test
+	public void cachePatternsSetToTrue() {
+		pathMatcher.setCachePatterns(true);
+		match();
+		assertTrue(pathMatcher.stringMatcherCache.size() > 20);
+
+		for (int i = 0; i < 65536; i++) {
+			pathMatcher.match("test" + i, "test");
+		}
+		// Cache keeps being alive due to the explicit cache setting
+		assertTrue(pathMatcher.stringMatcherCache.size() > 65536);
+	}
+
+	@Test
+	public void cachePatternsSetToFalse() {
+		pathMatcher.setCachePatterns(false);
+		match();
+		assertTrue(pathMatcher.stringMatcherCache.isEmpty());
+	}
+
+	@Test
+	public void extensionMappingWithDotPathSeparator() {
+		pathMatcher.setPathSeparator(".");
+		assertEquals("Extension mapping should be disabled with \".\" as path separator",
+				"/*.html.hotel.*", pathMatcher.combine("/*.html", "hotel.*"));
+	}
+
 }
