@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,12 +16,6 @@
 
 package org.springframework.expression.spel;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
@@ -31,6 +25,7 @@ import java.util.List;
 import java.util.Map;
 
 import org.junit.Test;
+
 import org.springframework.expression.EvaluationContext;
 import org.springframework.expression.Expression;
 import org.springframework.expression.ExpressionParser;
@@ -40,6 +35,8 @@ import org.springframework.expression.spel.support.StandardEvaluationContext;
 import org.springframework.expression.spel.testresources.Inventor;
 import org.springframework.expression.spel.testresources.PlaceOfBirth;
 
+import static org.junit.Assert.*;
+
 /**
  * Test the examples specified in the documentation.
  *
@@ -48,7 +45,7 @@ import org.springframework.expression.spel.testresources.PlaceOfBirth;
  *
  * @author Andy Clement
  */
-public class SpelDocumentationTests extends ExpressionTestCase {
+public class SpelDocumentationTests extends AbstractExpressionTests {
 
 	static Inventor tesla ;
 	static Inventor pupin ;
@@ -383,8 +380,8 @@ public class SpelDocumentationTests extends ExpressionTestCase {
 
 	@Test
 	public void testTypes() throws Exception {
-		Class dateClass = parser.parseExpression("T(java.util.Date)").getValue(Class.class);
-		assertEquals(Date.class,dateClass);
+		Class<?> dateClass = parser.parseExpression("T(java.util.Date)").getValue(Class.class);
+		assertEquals(Date.class, dateClass);
 		boolean trueValue = parser.parseExpression("T(java.math.RoundingMode).CEILING < T(java.math.RoundingMode).FLOOR").getValue(Boolean.class);
 		assertTrue(trueValue);
 	}
