@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,9 +24,11 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.List;
+import java.util.ListIterator;
 import java.util.Map;
 import java.util.Properties;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -42,6 +44,7 @@ import org.springframework.expression.BeanResolver;
 import org.springframework.expression.EvaluationContext;
 import org.springframework.expression.EvaluationException;
 import org.springframework.expression.Expression;
+import org.springframework.expression.ExpressionException;
 import org.springframework.expression.ExpressionParser;
 import org.springframework.expression.MethodExecutor;
 import org.springframework.expression.MethodResolver;
@@ -68,7 +71,7 @@ import static org.junit.Assert.*;
  * @author Phillip Webb
  * @author Sam Brannen
  */
-public class SpelReproTests extends ExpressionTestCase {
+public class SpelReproTests extends AbstractExpressionTests {
 
 	@Rule
 	public ExpectedException thrown = ExpectedException.none();
@@ -602,10 +605,14 @@ public class SpelReproTests extends ExpressionTestCase {
 			fail("Should have failed with message: " + expectedMessage);
 		}
 		catch (Exception ex) {
-			if (!ex.getMessage().equals(expectedMessage)) {
+			String message = ex.getMessage();
+			if (ex instanceof ExpressionException) {
+				message = ((ExpressionException) ex).getSimpleMessage();
+			}
+			if (!message.equals(expectedMessage)) {
 				ex.printStackTrace();
 			}
-			assertEquals(expectedMessage, ex.getMessage());
+			assertThat(expectedMessage, equalTo(message));
 		}
 	}
 
@@ -1201,7 +1208,7 @@ public class SpelReproTests extends ExpressionTestCase {
 
 		@Override
 		public Class<?>[] getSpecificTargetClasses() {
-			return new Class[] { ContextObject.class };
+			return new Class<?>[] {ContextObject.class};
 		}
 
 		@Override
@@ -1271,7 +1278,7 @@ public class SpelReproTests extends ExpressionTestCase {
 			protected Method[] getMethods(Class<?> type) {
 				try {
 					return new Method[] {
-							Integer.class.getDeclaredMethod("parseInt", new Class[] { String.class, Integer.TYPE }) };
+							Integer.class.getDeclaredMethod("parseInt", new Class<?>[] {String.class, Integer.TYPE})};
 				}
 				catch (NoSuchMethodException ex) {
 					return new Method[0];
@@ -1787,6 +1794,19 @@ public class SpelReproTests extends ExpressionTestCase {
 		expression.getValue(context, rootObject);
 	}
 
+	@Test
+	public void SPR9194() {
+		TestClass2 one = new TestClass2("abc");
+		TestClass2 two = new TestClass2("abc");
+		Map<String, TestClass2> map = new HashMap<String, TestClass2>();
+		map.put("one", one);
+		map.put("two", two);
+
+		SpelExpressionParser parser = new SpelExpressionParser();
+		Expression expr = parser.parseExpression("['one'] == ['two']");
+		assertTrue(expr.getValue(map, Boolean.class));
+	}
+
 	@Test
 	public void SPR11348() {
 		Collection<String> coll = new LinkedHashSet<String>();
@@ -1820,6 +1840,7 @@ public class SpelReproTests extends ExpressionTestCase {
 	}
 
 	@Test
+	@SuppressWarnings("unchecked")
 	public void SPR11494() {
 		Expression exp = new SpelExpressionParser().parseExpression("T(java.util.Arrays).asList('a','b')");
 		List<String> list = (List<String>) exp.getValue();
@@ -1836,13 +1857,53 @@ public class SpelReproTests extends ExpressionTestCase {
 	}
 
 	@Test
-	public void SPR12502() throws Exception {
+	public void SPR9735() {
+		Item item = new Item();
+		item.setName("parent");
+
+		Item item1 = new Item();
+		item1.setName("child1");
+
+		Item item2 = new Item();
+		item2.setName("child2");
+
+		item.add(item1);
+		item.add(item2);
+
+		ExpressionParser parser = new SpelExpressionParser();
+		EvaluationContext context = new StandardEvaluationContext();
+		Expression exp = parser.parseExpression("#item[0].name");
+		context.setVariable("item", item);
+
+		assertEquals("child1", exp.getValue(context));
+	}
+
+	@Test
+	public void SPR12502() {
 		SpelExpressionParser parser = new SpelExpressionParser();
 		Expression expression = parser.parseExpression("#root.getClass().getName()");
 		assertEquals(UnnamedUser.class.getName(), expression.getValue(new UnnamedUser()));
 		assertEquals(NamedUser.class.getName(), expression.getValue(new NamedUser()));
 	}
 
+	@Test
+	public void SPR12522() {
+		SpelExpressionParser parser = new SpelExpressionParser();
+		Expression expression = parser.parseExpression("T(java.util.Arrays).asList('')");
+		Object value = expression.getValue();
+		assertTrue(value instanceof List);
+		assertTrue(((List) value).isEmpty());
+	}
+
+	@Test
+	public void SPR12803() throws Exception {
+		StandardEvaluationContext sec = new StandardEvaluationContext();
+		sec.setVariable("iterable", Collections.emptyList());
+		SpelExpressionParser parser = new SpelExpressionParser();
+		Expression expression = parser.parseExpression("T(org.springframework.expression.spel.SpelReproTests.GuavaLists).newArrayList(#iterable)");
+		assertTrue(expression.getValue(sec) instanceof ArrayList);
+	}
+
 
 	private static enum ABC { A, B, C }
 
@@ -1979,12 +2040,144 @@ public class SpelReproTests extends ExpressionTestCase {
 	}
 
 
+	@SuppressWarnings({ "rawtypes", "serial" })
 	public static class MapWithConstant extends HashMap {
 
 		public static final int X = 1;
 	}
 
 
+	public class Item implements List<Item> {
+
+		private String name;
+
+		private List<Item> children = new ArrayList<Item>();
+
+		public void setName(String name) {
+			this.name = name;
+		}
+
+		public String getName() {
+			return this.name;
+		}
+
+		@Override
+		public int size() {
+			return this.children.size();
+		}
+
+		@Override
+		public boolean isEmpty() {
+			return this.children.isEmpty();
+		}
+
+		@Override
+		public boolean contains(Object o) {
+			return this.children.contains(o);
+		}
+
+		@Override
+		public Iterator<Item> iterator() {
+			return this.children.iterator();
+		}
+
+		@Override
+		public Object[] toArray() {
+			return this.children.toArray();
+		}
+
+		@Override
+		public <T> T[] toArray(T[] a) {
+			return this.children.toArray(a);
+		}
+
+		@Override
+		public boolean add(Item e) {
+			return this.children.add(e);
+		}
+
+		@Override
+		public boolean remove(Object o) {
+			return this.children.remove(o);
+		}
+
+		@Override
+		public boolean containsAll(Collection<?> c) {
+			return this.children.containsAll(c);
+		}
+
+		@Override
+		public boolean addAll(Collection<? extends Item> c) {
+			return this.children.addAll(c);
+		}
+
+		@Override
+		public boolean addAll(int index, Collection<? extends Item> c) {
+			return this.children.addAll(index, c);
+		}
+
+		@Override
+		public boolean removeAll(Collection<?> c) {
+			return this.children.removeAll(c);
+		}
+
+		@Override
+		public boolean retainAll(Collection<?> c) {
+			return this.children.retainAll(c);
+		}
+
+		@Override
+		public void clear() {
+			this.children.clear();
+		}
+
+		@Override
+		public Item get(int index) {
+			return this.children.get(index);
+		}
+
+		@Override
+		public Item set(int index, Item element) {
+			return this.children.set(index, element);
+		}
+
+		@Override
+		public void add(int index, Item element) {
+			this.children.add(index, element);
+		}
+
+		@Override
+		public Item remove(int index) {
+			return this.children.remove(index);
+		}
+
+		@Override
+		public int indexOf(Object o) {
+			return this.children.indexOf(o);
+		}
+
+		@Override
+		public int lastIndexOf(Object o) {
+			return this.children.lastIndexOf(o);
+		}
+
+		@Override
+		public ListIterator<Item> listIterator() {
+			return this.children.listIterator();
+		}
+
+		@Override
+		public ListIterator<Item> listIterator(int index) {
+			return this.children.listIterator(index);
+		}
+
+		@Override
+		public List<Item> subList(int fromIndex, int toIndex) {
+			return this.children.subList(fromIndex, toIndex);
+		}
+	}
+
+
 	public static class UnnamedUser {
 	}
 
@@ -1996,4 +2189,16 @@ public class SpelReproTests extends ExpressionTestCase {
 		}
 	}
 
+
+	public static class GuavaLists {
+
+		public static <T> List<T> newArrayList(Iterable<T> iterable) {
+			return new ArrayList<T>();
+		}
+
+		public static <T> List<T> newArrayList(Object... elements) {
+			throw new UnsupportedOperationException();
+		}
+	}
+
 }
