@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -56,6 +56,7 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 import org.mockito.InOrder;
+
 import org.springframework.dao.CannotAcquireLockException;
 import org.springframework.dao.DataAccessResourceFailureException;
 import org.springframework.dao.DataIntegrityViolationException;
@@ -73,6 +74,7 @@ import static org.mockito.BDDMockito.*;
  * @author Phillip Webb
  * @since 05.03.2005
  */
+@SuppressWarnings({ "rawtypes", "unchecked" })
 public class HibernateTemplateTests {
 
 	private SessionFactory sessionFactory;
@@ -815,21 +817,6 @@ public class HibernateTemplateTests {
 		verify(session).close();
 	}
 
-	@Test
-	public void testSaveOrUpdateAll() throws HibernateException {
-		TestBean tb1 = new TestBean();
-		TestBean tb2 = new TestBean();
-		given(session.getFlushMode()).willReturn(FlushMode.AUTO);
-		List tbs = new ArrayList();
-		tbs.add(tb1);
-		tbs.add(tb2);
-		hibernateTemplate.saveOrUpdateAll(tbs);
-		verify(session).saveOrUpdate(same(tb1));
-		verify(session).saveOrUpdate(same(tb2));
-		verify(session).flush();
-		verify(session).close();
-	}
-
 	@Test
 	public void testReplicate() throws HibernateException {
 		TestBean tb = new TestBean();
