@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,7 +20,8 @@ import java.io.IOException;
 import java.sql.Connection;
 import java.util.concurrent.Callable;
 import java.util.concurrent.atomic.AtomicInteger;
-
+import javax.servlet.AsyncEvent;
+import javax.servlet.AsyncListener;
 import javax.servlet.FilterChain;
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequest;
@@ -34,7 +35,10 @@ import org.hibernate.classic.Session;
 import org.hibernate.engine.SessionFactoryImplementor;
 import org.junit.Before;
 import org.junit.Test;
+
+import org.springframework.aop.framework.ProxyFactory;
 import org.springframework.core.task.SimpleAsyncTaskExecutor;
+import org.springframework.mock.web.test.MockAsyncContext;
 import org.springframework.mock.web.test.MockFilterConfig;
 import org.springframework.mock.web.test.MockHttpServletRequest;
 import org.springframework.mock.web.test.MockHttpServletResponse;
@@ -50,14 +54,15 @@ import org.springframework.transaction.support.TransactionSynchronizationManager
 import org.springframework.web.context.WebApplicationContext;
 import org.springframework.web.context.request.ServletWebRequest;
 import org.springframework.web.context.request.async.AsyncWebRequest;
+import org.springframework.web.context.request.async.StandardServletAsyncWebRequest;
 import org.springframework.web.context.request.async.WebAsyncManager;
 import org.springframework.web.context.request.async.WebAsyncUtils;
 import org.springframework.web.context.support.StaticWebApplicationContext;
+import org.springframework.web.util.NestedServletException;
 
 import static org.junit.Assert.*;
 import static org.mockito.BDDMockito.*;
 
-
 /**
  * @author Juergen Hoeller
  * @author Rossen Stoyanchev
@@ -79,13 +84,39 @@ public class OpenSessionInViewTests {
 	public void setup() {
 		this.sc = new MockServletContext();
 		this.request = new MockHttpServletRequest(sc);
+		this.request.setAsyncSupported(true);
 		this.response = new MockHttpServletResponse();
 		this.webRequest = new ServletWebRequest(this.request);
 	}
 
 	@Test
-	public void testOpenSessionInViewInterceptorWithSingleSession() throws Exception {
+	public void testOpenSessionInterceptor() throws Exception {
+		final SessionFactory sf = mock(SessionFactory.class);
+		final Session session = mock(Session.class);
 
+		OpenSessionInterceptor interceptor = new OpenSessionInterceptor();
+		interceptor.setSessionFactory(sf);
+
+		Runnable tb = new Runnable() {
+			@Override
+			public void run() {
+				assertTrue(TransactionSynchronizationManager.hasResource(sf));
+				assertEquals(session, SessionFactoryUtils.getSession(sf, false));
+			}
+		};
+		ProxyFactory pf = new ProxyFactory(tb);
+		pf.addAdvice(interceptor);
+		Runnable tbProxy = (Runnable) pf.getProxy();
+
+		given(sf.openSession()).willReturn(session);
+		given(session.isOpen()).willReturn(true);
+		tbProxy.run();
+		verify(session).setFlushMode(FlushMode.MANUAL);
+		verify(session).close();
+	}
+
+	@Test
+	public void testOpenSessionInViewInterceptorWithSingleSession() throws Exception {
 		SessionFactory sf = mock(SessionFactory.class);
 		Session session = mock(Session.class);
 
@@ -127,7 +158,6 @@ public class OpenSessionInViewTests {
 
 	@Test
 	public void testOpenSessionInViewInterceptorAsyncScenario() throws Exception {
-
 		// Initial request thread
 
 		final SessionFactory sf = mock(SessionFactory.class);
@@ -142,12 +172,10 @@ public class OpenSessionInViewTests {
 		interceptor.preHandle(this.webRequest);
 		assertTrue(TransactionSynchronizationManager.hasResource(sf));
 
-		AsyncWebRequest asyncWebRequest = mock(AsyncWebRequest.class);
-
+		AsyncWebRequest asyncWebRequest = new StandardServletAsyncWebRequest(this.request, this.response);
 		WebAsyncManager asyncManager = WebAsyncUtils.getAsyncManager(this.request);
 		asyncManager.setTaskExecutor(new SyncTaskExecutor());
 		asyncManager.setAsyncWebRequest(asyncWebRequest);
-
 		asyncManager.startCallableProcessing(new Callable<String>() {
 			@Override
 			public String call() throws Exception {
@@ -166,13 +194,57 @@ public class OpenSessionInViewTests {
 		interceptor.postHandle(this.webRequest, null);
 		assertTrue(TransactionSynchronizationManager.hasResource(sf));
 
+		verify(session, never()).close();
+
 		interceptor.afterCompletion(this.webRequest, null);
 		assertFalse(TransactionSynchronizationManager.hasResource(sf));
 
 		verify(session).setFlushMode(FlushMode.MANUAL);
-		verify(asyncWebRequest, times(2)).addCompletionHandler(any(Runnable.class));
-		verify(asyncWebRequest).addTimeoutHandler(any(Runnable.class));
-		verify(asyncWebRequest).startAsync();
+		verify(session).close();
+	}
+
+	@Test
+	public void testOpenSessionInViewInterceptorAsyncTimeoutScenario() throws Exception {
+		// Initial request thread
+
+		final SessionFactory sf = mock(SessionFactory.class);
+		Session session = mock(Session.class);
+
+		OpenSessionInViewInterceptor interceptor = new OpenSessionInViewInterceptor();
+		interceptor.setSessionFactory(sf);
+
+		given(sf.openSession()).willReturn(session);
+		given(session.getSessionFactory()).willReturn(sf);
+
+		interceptor.preHandle(this.webRequest);
+		assertTrue(TransactionSynchronizationManager.hasResource(sf));
+
+		AsyncWebRequest asyncWebRequest = new StandardServletAsyncWebRequest(this.request, this.response);
+		WebAsyncManager asyncManager = WebAsyncUtils.getAsyncManager(this.request);
+		asyncManager.setTaskExecutor(new SyncTaskExecutor());
+		asyncManager.setAsyncWebRequest(asyncWebRequest);
+		asyncManager.startCallableProcessing(new Callable<String>() {
+			@Override
+			public String call() throws Exception {
+				return "anything";
+			}
+		});
+
+		interceptor.afterConcurrentHandlingStarted(this.webRequest);
+		assertFalse(TransactionSynchronizationManager.hasResource(sf));
+		verify(session, never()).close();
+
+		// Async request timeout
+
+		MockAsyncContext asyncContext = (MockAsyncContext) this.request.getAsyncContext();
+		for (AsyncListener listener : asyncContext.getListeners()) {
+			listener.onTimeout(new AsyncEvent(asyncContext));
+		}
+		for (AsyncListener listener : asyncContext.getListeners()) {
+			listener.onComplete(new AsyncEvent(asyncContext));
+		}
+
+		verify(session).close();
 	}
 
 	@Test
@@ -195,7 +267,7 @@ public class OpenSessionInViewTests {
 		interceptor.preHandle(this.webRequest);
 		assertTrue(TransactionSynchronizationManager.hasResource(sf));
 
-		// check that further invocations simply participate
+		// Check that further invocations simply participate
 		interceptor.preHandle(this.webRequest);
 
 		assertEquals(session, SessionFactoryUtils.getSession(sf, false));
@@ -376,9 +448,7 @@ public class OpenSessionInViewTests {
 			}
 		};
 
-		AsyncWebRequest asyncWebRequest = mock(AsyncWebRequest.class);
-		given(asyncWebRequest.isAsyncStarted()).willReturn(true);
-
+		AsyncWebRequest asyncWebRequest = new StandardServletAsyncWebRequest(this.request, this.response);
 		WebAsyncManager asyncManager = WebAsyncUtils.getAsyncManager(this.request);
 		asyncManager.setTaskExecutor(new SyncTaskExecutor());
 		asyncManager.setAsyncWebRequest(asyncWebRequest);
@@ -393,19 +463,88 @@ public class OpenSessionInViewTests {
 		filter.doFilter(this.request, this.response, filterChain);
 		assertFalse(TransactionSynchronizationManager.hasResource(sf));
 		assertEquals(1, count.get());
-
+		verify(session, never()).close();
 
 		// Async dispatch after concurrent handling produces result ...
 
+		this.request.setAsyncStarted(false);
 		assertFalse(TransactionSynchronizationManager.hasResource(sf));
 		filter.doFilter(this.request, this.response, filterChain);
 		assertFalse(TransactionSynchronizationManager.hasResource(sf));
 		assertEquals(2, count.get());
 
 		verify(session).setFlushMode(FlushMode.MANUAL);
-		verify(asyncWebRequest, times(2)).addCompletionHandler(any(Runnable.class));
-		verify(asyncWebRequest).addTimeoutHandler(any(Runnable.class));
-		verify(asyncWebRequest).startAsync();
+		verify(session).close();
+
+		wac.close();
+	}
+
+	@Test
+	public void testOpenSessionInViewFilterAsyncTimeoutScenario() throws Exception {
+		final SessionFactory sf = mock(SessionFactory.class);
+		Session session = mock(Session.class);
+
+		// Initial request during which concurrent handling starts..
+
+		given(sf.openSession()).willReturn(session);
+		given(session.getSessionFactory()).willReturn(sf);
+
+		StaticWebApplicationContext wac = new StaticWebApplicationContext();
+		wac.setServletContext(sc);
+		wac.getDefaultListableBeanFactory().registerSingleton("sessionFactory", sf);
+		wac.refresh();
+		sc.setAttribute(WebApplicationContext.ROOT_WEB_APPLICATION_CONTEXT_ATTRIBUTE, wac);
+
+		MockFilterConfig filterConfig = new MockFilterConfig(wac.getServletContext(), "filter");
+		final OpenSessionInViewFilter filter = new OpenSessionInViewFilter();
+		filter.init(filterConfig);
+
+		final AtomicInteger count = new AtomicInteger(0);
+		final AsyncWebRequest asyncWebRequest = new StandardServletAsyncWebRequest(this.request, this.response);
+		final MockHttpServletRequest request = this.request;
+
+		final FilterChain filterChain = new FilterChain() {
+			@Override
+			public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse)
+					throws NestedServletException {
+
+				assertTrue(TransactionSynchronizationManager.hasResource(sf));
+				count.incrementAndGet();
+
+				WebAsyncManager asyncManager = WebAsyncUtils.getAsyncManager(request);
+				asyncManager.setTaskExecutor(new SyncTaskExecutor());
+				asyncManager.setAsyncWebRequest(asyncWebRequest);
+				try {
+					asyncManager.startCallableProcessing(new Callable<String>() {
+						@Override
+						public String call() throws Exception {
+							return "anything";
+						}
+					});
+				}
+				catch (Exception e) {
+					throw new NestedServletException("", e);
+				}
+			}
+		};
+
+		assertFalse(TransactionSynchronizationManager.hasResource(sf));
+		filter.doFilter(this.request, this.response, filterChain);
+		assertFalse(TransactionSynchronizationManager.hasResource(sf));
+		assertEquals(1, count.get());
+		verify(session, never()).close();
+
+		// Async request timeout ...
+
+		MockAsyncContext asyncContext = (MockAsyncContext) this.request.getAsyncContext();
+		for (AsyncListener listener : asyncContext.getListeners()) {
+			listener.onTimeout(new AsyncEvent(asyncContext));
+		}
+		for (AsyncListener listener : asyncContext.getListeners()) {
+			listener.onComplete(new AsyncEvent(asyncContext));
+		}
+
+		verify(session).close();
 
 		wac.close();
 	}
@@ -609,4 +748,5 @@ public class OpenSessionInViewTests {
 			task.run();
 		}
 	}
+
 }
