@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,17 +19,16 @@ package org.springframework.orm.jpa;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.List;
-
 import javax.persistence.EntityManager;
 import javax.persistence.EntityManagerFactory;
 import javax.persistence.EntityTransaction;
-import javax.persistence.PersistenceException;
 import javax.persistence.RollbackException;
 import javax.sql.DataSource;
 
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
+
 import org.springframework.transaction.InvalidIsolationLevelException;
 import org.springframework.transaction.TransactionDefinition;
 import org.springframework.transaction.TransactionStatus;
@@ -50,15 +49,13 @@ import static org.mockito.BDDMockito.*;
  */
 public class JpaTransactionManagerTests {
 
+	private EntityManagerFactory factory;
+
 	private EntityManager manager;
 
 	private EntityTransaction tx;
 
-	private EntityManagerFactory factory;
-
-	private JpaTransactionManager transactionManager;
-
-	private JpaTemplate template;
+	private JpaTransactionManager tm;
 
 	private TransactionTemplate tt;
 
@@ -69,10 +66,8 @@ public class JpaTransactionManagerTests {
 		manager = mock(EntityManager.class);
 		tx = mock(EntityTransaction.class);
 
-		transactionManager = new JpaTransactionManager(factory);
-		template = new JpaTemplate(factory);
-		template.afterPropertiesSet();
-		tt = new TransactionTemplate(transactionManager);
+		tm = new JpaTransactionManager(factory);
+		tt = new TransactionTemplate(tm);
 
 		given(factory.createEntityManager()).willReturn(manager);
 		given(manager.getTransaction()).willReturn(tx);
@@ -87,6 +82,7 @@ public class JpaTransactionManagerTests {
 		assertFalse(TransactionSynchronizationManager.isActualTransactionActive());
 	}
 
+
 	@Test
 	public void testTransactionCommit() {
 		given(manager.getTransaction()).willReturn(tx);
@@ -101,13 +97,8 @@ public class JpaTransactionManagerTests {
 			@Override
 			public Object doInTransaction(TransactionStatus status) {
 				assertTrue(TransactionSynchronizationManager.hasResource(factory));
-				return template.execute(new JpaCallback() {
-					@Override
-					public Object doInJpa(EntityManager em) {
-						em.flush();
-						return l;
-					}
-				});
+				EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+				return l;
 			}
 		});
 		assertSame(l, result);
@@ -137,13 +128,8 @@ public class JpaTransactionManagerTests {
 				@Override
 				public Object doInTransaction(TransactionStatus status) {
 					assertTrue(TransactionSynchronizationManager.hasResource(factory));
-					return template.execute(new JpaCallback() {
-						@Override
-						public Object doInJpa(EntityManager em) {
-							em.flush();
-							return l;
-						}
-					});
+					EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+					return l;
 				}
 			});
 			assertSame(l, result);
@@ -176,12 +162,8 @@ public class JpaTransactionManagerTests {
 				@Override
 				public Object doInTransaction(TransactionStatus status) {
 					assertTrue(TransactionSynchronizationManager.hasResource(factory));
-					return template.execute(new JpaCallback() {
-						@Override
-						public Object doInJpa(EntityManager em) {
-							throw new RuntimeException("some exception");
-						}
-					});
+					EntityManagerFactoryUtils.getTransactionalEntityManager(factory);
+					throw new RuntimeException("some exception");
 				}
 			});
 			fail("Should have propagated RuntimeException");
@@ -213,12 +195,8 @@ public class JpaTransactionManagerTests {
 				@Override
 				public Object doInTransaction(TransactionStatus status) {
 					assertTrue(TransactionSynchronizationManager.hasResource(factory));
-					return template.execute(new JpaCallback() {
-						@Override
-						public Object doInJpa(EntityManager em) {
-							throw new RuntimeException("some exception");
-						}
-					});
+					EntityManagerFactoryUtils.getTransactionalEntityManager(factory);
+					throw new RuntimeException("some exception");
 				}
 			});
 			fail("Should have propagated RuntimeException");
@@ -249,16 +227,10 @@ public class JpaTransactionManagerTests {
 			public Object doInTransaction(TransactionStatus status) {
 				assertTrue(TransactionSynchronizationManager.hasResource(factory));
 
-				Object res = template.execute(new JpaCallback() {
-					@Override
-					public Object doInJpa(EntityManager em) {
-						em.flush();
-						return l;
-					}
-				});
+				EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
 				status.setRollbackOnly();
 
-				return res;
+				return l;
 			}
 		});
 
@@ -288,14 +260,8 @@ public class JpaTransactionManagerTests {
 				return tt.execute(new TransactionCallback() {
 					@Override
 					public Object doInTransaction(TransactionStatus status) {
-
-						return template.execute(new JpaCallback() {
-							@Override
-							public Object doInJpa(EntityManager em) {
-								em.flush();
-								return l;
-							}
-						});
+						EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+						return l;
 					}
 				});
 			}
@@ -328,12 +294,8 @@ public class JpaTransactionManagerTests {
 					return tt.execute(new TransactionCallback() {
 						@Override
 						public Object doInTransaction(TransactionStatus status) {
-							return template.execute(new JpaCallback() {
-								@Override
-								public Object doInJpa(EntityManager em) {
-									throw new RuntimeException("exception");
-								}
-							});
+							EntityManagerFactoryUtils.getTransactionalEntityManager(factory);
+							throw new RuntimeException("some exception");
 						}
 					});
 				}
@@ -374,15 +336,7 @@ public class JpaTransactionManagerTests {
 					return tt.execute(new TransactionCallback() {
 						@Override
 						public Object doInTransaction(TransactionStatus status) {
-
-							template.execute(new JpaCallback() {
-								@Override
-								public Object doInJpa(EntityManager em2) {
-									em2.flush();
-									return l;
-								}
-							});
-
+							EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
 							status.setRollbackOnly();
 							return null;
 						}
@@ -425,13 +379,8 @@ public class JpaTransactionManagerTests {
 				return tt.execute(new TransactionCallback() {
 					@Override
 					public Object doInTransaction(TransactionStatus status) {
-						return template.execute(new JpaCallback() {
-							@Override
-							public Object doInJpa(EntityManager em2) {
-								em2.flush();
-								return l;
-							}
-						});
+						EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+						return l;
 					}
 				});
 			}
@@ -464,25 +413,14 @@ public class JpaTransactionManagerTests {
 			Object result = tt.execute(new TransactionCallback() {
 				@Override
 				public Object doInTransaction(TransactionStatus status) {
-					JpaTemplate template2 = new JpaTemplate(factory);
-					template2.execute(new JpaCallback() {
-						@Override
-						public Object doInJpa(EntityManager em) throws PersistenceException {
-							return null;
-						}
-					});
+					EntityManagerFactoryUtils.getTransactionalEntityManager(factory);
 
 					assertTrue(TransactionSynchronizationManager.hasResource(factory));
 					return tt.execute(new TransactionCallback() {
 						@Override
 						public Object doInTransaction(TransactionStatus status) {
-							return template.execute(new JpaCallback() {
-								@Override
-								public Object doInJpa(EntityManager em2) {
-									em2.flush();
-									return l;
-								}
-							});
+							EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+							return l;
 						}
 					});
 				}
@@ -518,18 +456,13 @@ public class JpaTransactionManagerTests {
 			@Override
 			public Object doInTransaction(TransactionStatus status) {
 				assertFalse(TransactionSynchronizationManager.hasResource(factory));
-				TransactionTemplate tt2 = new TransactionTemplate(transactionManager);
+				TransactionTemplate tt2 = new TransactionTemplate(tm);
 				tt2.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
 				return tt2.execute(new TransactionCallback() {
 					@Override
 					public Object doInTransaction(TransactionStatus status) {
-						return template.execute(new JpaCallback() {
-							@Override
-							public Object doInJpa(EntityManager em2) {
-								em2.flush();
-								return l;
-							}
-						});
+						EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+						return l;
 					}
 				});
 			}
@@ -561,27 +494,16 @@ public class JpaTransactionManagerTests {
 		Object result = tt.execute(new TransactionCallback() {
 			@Override
 			public Object doInTransaction(TransactionStatus status) {
-				JpaTemplate template2 = new JpaTemplate(factory);
-				template2.execute(new JpaCallback() {
-					@Override
-					public Object doInJpa(EntityManager em) throws PersistenceException {
-						return null;
-					}
-				});
+				EntityManagerFactoryUtils.getTransactionalEntityManager(factory);
 
 				assertTrue(TransactionSynchronizationManager.hasResource(factory));
-				TransactionTemplate tt2 = new TransactionTemplate(transactionManager);
+				TransactionTemplate tt2 = new TransactionTemplate(tm);
 				tt2.setPropagationBehavior(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
 				return tt2.execute(new TransactionCallback() {
 					@Override
 					public Object doInTransaction(TransactionStatus status) {
-						return template.execute(new JpaCallback() {
-							@Override
-							public Object doInJpa(EntityManager em2) {
-								em2.flush();
-								return l;
-							}
-						});
+						EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+						return l;
 					}
 				});
 			}
@@ -614,26 +536,15 @@ public class JpaTransactionManagerTests {
 		tt.execute(new TransactionCallback() {
 			@Override
 			public Object doInTransaction(TransactionStatus status) {
-				template.execute(new JpaCallback() {
-					@Override
-					public Object doInJpa(EntityManager em2) {
-						em2.flush();
-						return null;
-					}
-				});
+				EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
 				TransactionSynchronizationManager.registerSynchronization(new TransactionSynchronizationAdapter() {
 					@Override
 					public void afterCompletion(int status) {
 						tt.execute(new TransactionCallback() {
 							@Override
 							public Object doInTransaction(TransactionStatus status) {
-								return template.execute(new JpaCallback() {
-									@Override
-									public Object doInJpa(EntityManager em2) {
-										em2.flush();
-										return null;
-									}
-								});
+								EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+								return null;
 							}
 						});
 					}
@@ -672,13 +583,8 @@ public class JpaTransactionManagerTests {
 				assertTrue(!TransactionSynchronizationManager.hasResource(factory));
 				assertTrue(TransactionSynchronizationManager.isSynchronizationActive());
 				assertTrue(!status.isNewTransaction());
-				return template.execute(new JpaCallback() {
-					@Override
-					public Object doInJpa(EntityManager em) {
-						em.flush();
-						return l;
-					}
-				});
+				EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+				return l;
 			}
 		});
 		assertSame(l, result);
@@ -705,13 +611,7 @@ public class JpaTransactionManagerTests {
 				assertTrue(!TransactionSynchronizationManager.hasResource(factory));
 				assertTrue(TransactionSynchronizationManager.isSynchronizationActive());
 				assertTrue(!status.isNewTransaction());
-				template.execute(new JpaCallback() {
-					@Override
-					public Object doInJpa(EntityManager em) {
-						em.flush();
-						return null;
-					}
-				});
+				EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
 				status.setRollbackOnly();
 				return null;
 			}
@@ -741,12 +641,8 @@ public class JpaTransactionManagerTests {
 				public Object doInTransaction(TransactionStatus status) {
 					assertTrue(TransactionSynchronizationManager.hasResource(factory));
 					assertTrue(TransactionSynchronizationManager.isSynchronizationActive());
-					return template.execute(new JpaCallback() {
-						@Override
-						public Object doInJpa(EntityManager em) {
-							return l;
-						}
-					});
+					EntityManagerFactoryUtils.getTransactionalEntityManager(factory);
+					return l;
 				}
 			});
 			assertSame(l, result);
@@ -764,7 +660,6 @@ public class JpaTransactionManagerTests {
 
 	@Test
 	public void testTransactionRollbackWithPrebound() {
-
 		given(manager.getTransaction()).willReturn(tx);
 		given(tx.isActive()).willReturn(true);
 
@@ -778,12 +673,7 @@ public class JpaTransactionManagerTests {
 				public Object doInTransaction(TransactionStatus status) {
 					assertTrue(TransactionSynchronizationManager.hasResource(factory));
 					assertTrue(TransactionSynchronizationManager.isSynchronizationActive());
-					template.execute(new JpaCallback() {
-						@Override
-						public Object doInJpa(EntityManager em) {
-							return null;
-						}
-					});
+					EntityManagerFactoryUtils.getTransactionalEntityManager(factory);
 					status.setRollbackOnly();
 					return null;
 				}
@@ -803,7 +693,6 @@ public class JpaTransactionManagerTests {
 
 	@Test
 	public void testTransactionCommitWithPreboundAndPropagationSupports() {
-
 		final List<String> l = new ArrayList<String>();
 		l.add("test");
 
@@ -820,13 +709,8 @@ public class JpaTransactionManagerTests {
 					assertTrue(TransactionSynchronizationManager.hasResource(factory));
 					assertTrue(TransactionSynchronizationManager.isSynchronizationActive());
 					assertTrue(!status.isNewTransaction());
-					return template.execute(new JpaCallback() {
-						@Override
-						public Object doInJpa(EntityManager em) {
-							em.flush();
-							return l;
-						}
-					});
+					EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+					return l;
 				}
 			});
 			assertSame(l, result);
@@ -844,7 +728,6 @@ public class JpaTransactionManagerTests {
 
 	@Test
 	public void testTransactionRollbackWithPreboundAndPropagationSupports() {
-
 		tt.setPropagationBehavior(TransactionDefinition.PROPAGATION_SUPPORTS);
 
 		assertTrue(!TransactionSynchronizationManager.hasResource(factory));
@@ -858,13 +741,7 @@ public class JpaTransactionManagerTests {
 					assertTrue(TransactionSynchronizationManager.hasResource(factory));
 					assertTrue(TransactionSynchronizationManager.isSynchronizationActive());
 					assertTrue(!status.isNewTransaction());
-					template.execute(new JpaCallback() {
-						@Override
-						public Object doInJpa(EntityManager em) {
-							em.flush();
-							return null;
-						}
-					});
+					EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
 					status.setRollbackOnly();
 					return null;
 				}
@@ -885,7 +762,7 @@ public class JpaTransactionManagerTests {
 	@Test
 	public void testTransactionCommitWithDataSource() throws SQLException {
 		DataSource ds = mock(DataSource.class);
-		transactionManager.setDataSource(ds);
+		tm.setDataSource(ds);
 
 		given(manager.getTransaction()).willReturn(tx);
 
@@ -900,13 +777,8 @@ public class JpaTransactionManagerTests {
 			public Object doInTransaction(TransactionStatus status) {
 				assertTrue(TransactionSynchronizationManager.hasResource(factory));
 				assertTrue(TransactionSynchronizationManager.isSynchronizationActive());
-				return template.execute(new JpaCallback() {
-					@Override
-					public Object doInJpa(EntityManager em) {
-						em.flush();
-						return l;
-					}
-				});
+				EntityManagerFactoryUtils.getTransactionalEntityManager(factory).flush();
+				return l;
 			}
 		});
 
