@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,8 +16,6 @@
 
 package org.springframework.test.context;
 
-import static org.junit.Assert.*;
-
 import java.util.HashSet;
 import java.util.Set;
 
@@ -29,6 +27,8 @@ import org.springframework.context.support.GenericApplicationContext;
 import org.springframework.test.context.support.AnnotationConfigContextLoader;
 import org.springframework.test.context.support.GenericXmlContextLoader;
 
+import static org.junit.Assert.*;
+
 /**
  * Unit tests for {@link MergedContextConfiguration}.
  *
@@ -41,8 +41,10 @@ import org.springframework.test.context.support.GenericXmlContextLoader;
 public class MergedContextConfigurationTests {
 
 	private static final String[] EMPTY_STRING_ARRAY = new String[0];
+
 	private static final Class<?>[] EMPTY_CLASS_ARRAY = new Class<?>[0];
 
+
 	private final GenericXmlContextLoader loader = new GenericXmlContextLoader();
 
 
@@ -50,7 +52,6 @@ public class MergedContextConfigurationTests {
 	public void hashCodeWithNulls() {
 		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(null, null, null, null, null);
 		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(null, null, null, null, null);
-		assertTrue(mergedConfig1.hashCode() > 0);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -63,19 +64,19 @@ public class MergedContextConfigurationTests {
 
 	@Test
 	public void hashCodeWithEmptyArrays() {
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
 	@Test
 	public void hashCodeWithEmptyArraysAndDifferentLoaders() {
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, new AnnotationConfigContextLoader());
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, new AnnotationConfigContextLoader());
 		assertNotEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -83,9 +84,9 @@ public class MergedContextConfigurationTests {
 	public void hashCodeWithSameLocations() {
 		String[] locations = new String[] { "foo", "bar}" };
 		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), locations,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+				EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), locations,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+				EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -94,19 +95,19 @@ public class MergedContextConfigurationTests {
 		String[] locations1 = new String[] { "foo", "bar}" };
 		String[] locations2 = new String[] { "baz", "quux}" };
 		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), locations1,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+				EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), locations2,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+				EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		assertNotEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
 	@Test
 	public void hashCodeWithSameConfigClasses() {
 		Class<?>[] classes = new Class<?>[] { String.class, Integer.class };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			classes, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			classes, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, classes, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, classes, EMPTY_STRING_ARRAY, loader);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -114,20 +115,20 @@ public class MergedContextConfigurationTests {
 	public void hashCodeWithDifferentConfigClasses() {
 		Class<?>[] classes1 = new Class<?>[] { String.class, Integer.class };
 		Class<?>[] classes2 = new Class<?>[] { Boolean.class, Number.class };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			classes1, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			classes2, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, classes1, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, classes2, EMPTY_STRING_ARRAY, loader);
 		assertNotEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
 	@Test
 	public void hashCodeWithSameProfiles() {
 		String[] activeProfiles = new String[] { "catbert", "dogbert" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles, loader);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -135,10 +136,10 @@ public class MergedContextConfigurationTests {
 	public void hashCodeWithSameProfilesReversed() {
 		String[] activeProfiles1 = new String[] { "catbert", "dogbert" };
 		String[] activeProfiles2 = new String[] { "dogbert", "catbert" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles1, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles2, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles1, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles2, loader);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -146,10 +147,10 @@ public class MergedContextConfigurationTests {
 	public void hashCodeWithSameDuplicateProfiles() {
 		String[] activeProfiles1 = new String[] { "catbert", "dogbert" };
 		String[] activeProfiles2 = new String[] { "catbert", "dogbert", "catbert", "dogbert", "catbert" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles1, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles2, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles1, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles2, loader);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -157,46 +158,46 @@ public class MergedContextConfigurationTests {
 	public void hashCodeWithDifferentProfiles() {
 		String[] activeProfiles1 = new String[] { "catbert", "dogbert" };
 		String[] activeProfiles2 = new String[] { "X", "Y" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles1, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles2, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles1, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles2, loader);
 		assertNotEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
 	@Test
 	public void hashCodeWithSameInitializers() {
-		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses1 = //
-		new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
+		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses1 =
+				new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
 		initializerClasses1.add(FooInitializer.class);
 		initializerClasses1.add(BarInitializer.class);
 
-		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses2 = //
-		new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
+		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses2 =
+				new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
 		initializerClasses2.add(BarInitializer.class);
 		initializerClasses2.add(FooInitializer.class);
 
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, initializerClasses1, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, initializerClasses2, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, initializerClasses1, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, initializerClasses2, EMPTY_STRING_ARRAY, loader);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
 	@Test
 	public void hashCodeWithDifferentInitializers() {
-		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses1 = //
-		new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
+		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses1 =
+				new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
 		initializerClasses1.add(FooInitializer.class);
 
-		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses2 = //
-		new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
+		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses2 =
+				new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
 		initializerClasses2.add(BarInitializer.class);
 
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, initializerClasses1, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, initializerClasses2, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, initializerClasses1, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, initializerClasses2, EMPTY_STRING_ARRAY, loader);
 		assertNotEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -206,12 +207,12 @@ public class MergedContextConfigurationTests {
 	@Test
 	public void hashCodeWithSameParent() {
 		MergedContextConfiguration parent = new MergedContextConfiguration(getClass(), new String[] { "foo", "bar}" },
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+				EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, loader, null, parent);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, loader, null, parent);
 		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, loader, null, parent);
+				EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, loader, null, parent);
 		assertEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -221,14 +222,14 @@ public class MergedContextConfigurationTests {
 	@Test
 	public void hashCodeWithDifferentParents() {
 		MergedContextConfiguration parent1 = new MergedContextConfiguration(getClass(), new String[] { "foo", "bar}" },
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+				EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		MergedContextConfiguration parent2 = new MergedContextConfiguration(getClass(), new String[] { "baz", "quux" },
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+				EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 
 		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, loader, null, parent1);
+				EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, loader, null, parent1);
 		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, loader, null, parent2);
+				EMPTY_CLASS_ARRAY, null, EMPTY_STRING_ARRAY, loader, null, parent2);
 		assertNotEquals(mergedConfig1.hashCode(), mergedConfig2.hashCode());
 	}
 
@@ -237,7 +238,7 @@ public class MergedContextConfigurationTests {
 		MergedContextConfiguration mergedConfig = new MergedContextConfiguration(null, null, null, null, null);
 		assertEquals(mergedConfig, mergedConfig);
 		assertNotEquals(mergedConfig, null);
-		assertNotEquals(mergedConfig, new Integer(1));
+		assertNotEquals(mergedConfig, 1);
 	}
 
 	@Test
@@ -256,19 +257,19 @@ public class MergedContextConfigurationTests {
 
 	@Test
 	public void equalsWithEmptyArrays() {
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		assertEquals(mergedConfig1, mergedConfig2);
 	}
 
 	@Test
 	public void equalsWithEmptyArraysAndDifferentLoaders() {
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, new AnnotationConfigContextLoader());
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, new AnnotationConfigContextLoader());
 		assertNotEquals(mergedConfig1, mergedConfig2);
 		assertNotEquals(mergedConfig2, mergedConfig1);
 	}
@@ -276,10 +277,10 @@ public class MergedContextConfigurationTests {
 	@Test
 	public void equalsWithSameLocations() {
 		String[] locations = new String[] { "foo", "bar}" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), locations,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), locations,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				locations, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				locations, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		assertEquals(mergedConfig1, mergedConfig2);
 	}
 
@@ -287,10 +288,10 @@ public class MergedContextConfigurationTests {
 	public void equalsWithDifferentLocations() {
 		String[] locations1 = new String[] { "foo", "bar}" };
 		String[] locations2 = new String[] { "baz", "quux}" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), locations1,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), locations2,
-			EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				locations1, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				locations2, EMPTY_CLASS_ARRAY, EMPTY_STRING_ARRAY, loader);
 		assertNotEquals(mergedConfig1, mergedConfig2);
 		assertNotEquals(mergedConfig2, mergedConfig1);
 	}
@@ -298,10 +299,10 @@ public class MergedContextConfigurationTests {
 	@Test
 	public void equalsWithSameConfigClasses() {
 		Class<?>[] classes = new Class<?>[] { String.class, Integer.class };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			classes, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			classes, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, classes, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, classes, EMPTY_STRING_ARRAY, loader);
 		assertEquals(mergedConfig1, mergedConfig2);
 	}
 
@@ -309,10 +310,10 @@ public class MergedContextConfigurationTests {
 	public void equalsWithDifferentConfigClasses() {
 		Class<?>[] classes1 = new Class<?>[] { String.class, Integer.class };
 		Class<?>[] classes2 = new Class<?>[] { Boolean.class, Number.class };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			classes1, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			classes2, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, classes1, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, classes2, EMPTY_STRING_ARRAY, loader);
 		assertNotEquals(mergedConfig1, mergedConfig2);
 		assertNotEquals(mergedConfig2, mergedConfig1);
 	}
@@ -320,10 +321,10 @@ public class MergedContextConfigurationTests {
 	@Test
 	public void equalsWithSameProfiles() {
 		String[] activeProfiles = new String[] { "catbert", "dogbert" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles, loader);
 		assertEquals(mergedConfig1, mergedConfig2);
 	}
 
@@ -331,10 +332,10 @@ public class MergedContextConfigurationTests {
 	public void equalsWithSameProfilesReversed() {
 		String[] activeProfiles1 = new String[] { "catbert", "dogbert" };
 		String[] activeProfiles2 = new String[] { "dogbert", "catbert" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles1, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles2, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles1, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles2, loader);
 		assertEquals(mergedConfig1, mergedConfig2);
 	}
 
@@ -342,10 +343,10 @@ public class MergedContextConfigurationTests {
 	public void equalsWithSameDuplicateProfiles() {
 		String[] activeProfiles1 = new String[] { "catbert", "dogbert" };
 		String[] activeProfiles2 = new String[] { "catbert", "dogbert", "catbert", "dogbert", "catbert" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles1, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles2, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles1, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles2, loader);
 		assertEquals(mergedConfig1, mergedConfig2);
 	}
 
@@ -353,47 +354,47 @@ public class MergedContextConfigurationTests {
 	public void equalsWithDifferentProfiles() {
 		String[] activeProfiles1 = new String[] { "catbert", "dogbert" };
 		String[] activeProfiles2 = new String[] { "X", "Y" };
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles1, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, activeProfiles2, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles1, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, activeProfiles2, loader);
 		assertNotEquals(mergedConfig1, mergedConfig2);
 		assertNotEquals(mergedConfig2, mergedConfig1);
 	}
 
 	@Test
 	public void equalsWithSameInitializers() {
-		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses1 = //
-		new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
+		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses1 =
+				new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
 		initializerClasses1.add(FooInitializer.class);
 		initializerClasses1.add(BarInitializer.class);
 
-		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses2 = //
-		new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
+		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses2 =
+				new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
 		initializerClasses2.add(BarInitializer.class);
 		initializerClasses2.add(FooInitializer.class);
 
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, initializerClasses1, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, initializerClasses2, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, initializerClasses1, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, initializerClasses2, EMPTY_STRING_ARRAY, loader);
 		assertEquals(mergedConfig1, mergedConfig2);
 	}
 
 	@Test
 	public void equalsWithDifferentInitializers() {
-		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses1 = //
-		new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
+		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses1 =
+				new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
 		initializerClasses1.add(FooInitializer.class);
 
-		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses2 = //
-		new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
+		Set<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>> initializerClasses2 =
+				new HashSet<Class<? extends ApplicationContextInitializer<? extends ConfigurableApplicationContext>>>();
 		initializerClasses2.add(BarInitializer.class);
 
-		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, initializerClasses1, EMPTY_STRING_ARRAY, loader);
-		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(), EMPTY_STRING_ARRAY,
-			EMPTY_CLASS_ARRAY, initializerClasses2, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig1 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, initializerClasses1, EMPTY_STRING_ARRAY, loader);
+		MergedContextConfiguration mergedConfig2 = new MergedContextConfiguration(getClass(),
+				EMPTY_STRING_ARRAY, EMPTY_CLASS_ARRAY, initializerClasses2, EMPTY_STRING_ARRAY, loader);
 		assertNotEquals(mergedConfig1, mergedConfig2);
 		assertNotEquals(mergedConfig2, mergedConfig1);
 	}
@@ -440,6 +441,7 @@ public class MergedContextConfigurationTests {
 		}
 	}
 
+
 	private static class BarInitializer implements ApplicationContextInitializer<GenericApplicationContext> {
 
 		@Override
