@@ -25,11 +25,11 @@ import java.lang.annotation.Target;
 import java.lang.reflect.Method;
 import javax.ejb.TransactionAttributeType;
 
-import static org.junit.Assert.*;
 import org.junit.Test;
 
 import org.springframework.aop.framework.Advised;
 import org.springframework.aop.framework.ProxyFactory;
+import org.springframework.core.annotation.AnnotationUtils;
 import org.springframework.tests.transaction.CallCountingTransactionManager;
 import org.springframework.transaction.interceptor.NoRollbackRuleAttribute;
 import org.springframework.transaction.interceptor.RollbackRuleAttribute;
@@ -38,9 +38,12 @@ import org.springframework.transaction.interceptor.TransactionAttribute;
 import org.springframework.transaction.interceptor.TransactionInterceptor;
 import org.springframework.util.SerializationTestUtils;
 
+import static org.junit.Assert.*;
+
 /**
  * @author Colin Sampaleanu
  * @author Juergen Hoeller
+ * @author Sam Brannen
  */
 public class AnnotationTransactionAttributeSourceTests {
 
@@ -214,7 +217,7 @@ public class AnnotationTransactionAttributeSourceTests {
 		Method method = TestBean6.class.getMethod("getAge", (Class[]) null);
 
 		AnnotationTransactionAttributeSource atas = new AnnotationTransactionAttributeSource();
-		TransactionAttribute actual = atas.getTransactionAttribute(method, TestBean5.class);
+		TransactionAttribute actual = atas.getTransactionAttribute(method, TestBean6.class);
 
 		RuleBasedTransactionAttribute rbta = new RuleBasedTransactionAttribute();
 		rbta.getRollbackRules().add(new RollbackRuleAttribute(Exception.class));
@@ -222,6 +225,79 @@ public class AnnotationTransactionAttributeSourceTests {
 		assertEquals(rbta.getRollbackRules(), ((RuleBasedTransactionAttribute) actual).getRollbackRules());
 	}
 
+	@Test
+	public void testCustomClassAttributeWithReadOnlyOverrideDetected() throws Exception {
+		Method method = TestBean7.class.getMethod("getAge", (Class[]) null);
+
+		AnnotationTransactionAttributeSource atas = new AnnotationTransactionAttributeSource();
+		TransactionAttribute actual = atas.getTransactionAttribute(method, TestBean7.class);
+
+		RuleBasedTransactionAttribute rbta = new RuleBasedTransactionAttribute();
+		rbta.getRollbackRules().add(new RollbackRuleAttribute(Exception.class));
+		rbta.getRollbackRules().add(new NoRollbackRuleAttribute(IOException.class));
+		assertEquals(rbta.getRollbackRules(), ((RuleBasedTransactionAttribute) actual).getRollbackRules());
+
+		assertTrue(actual.isReadOnly());
+	}
+
+	@Test
+	public void testCustomMethodAttributeWithReadOnlyOverrideDetected() throws Exception {
+		Method method = TestBean8.class.getMethod("getAge", (Class[]) null);
+
+		AnnotationTransactionAttributeSource atas = new AnnotationTransactionAttributeSource();
+		TransactionAttribute actual = atas.getTransactionAttribute(method, TestBean8.class);
+
+		RuleBasedTransactionAttribute rbta = new RuleBasedTransactionAttribute();
+		rbta.getRollbackRules().add(new RollbackRuleAttribute(Exception.class));
+		rbta.getRollbackRules().add(new NoRollbackRuleAttribute(IOException.class));
+		assertEquals(rbta.getRollbackRules(), ((RuleBasedTransactionAttribute) actual).getRollbackRules());
+
+		assertTrue(actual.isReadOnly());
+	}
+
+	@Test
+	public void customClassAttributeWithReadOnlyOverrideOnInterface() throws Exception {
+		Method method = TestInterface9.class.getMethod("getAge", (Class[]) null);
+
+		Transactional annotation = AnnotationUtils.findAnnotation(method, Transactional.class);
+		assertNull("AnnotationUtils.findAnnotation should not find @Transactional for TestBean9.getAge()", annotation);
+		annotation = AnnotationUtils.findAnnotation(TestBean9.class, Transactional.class);
+		assertNotNull("AnnotationUtils.findAnnotation failed to find @Transactional for TestBean9", annotation);
+
+		AnnotationTransactionAttributeSource atas = new AnnotationTransactionAttributeSource();
+		TransactionAttribute actual = atas.getTransactionAttribute(method, TestBean9.class);
+		assertNotNull("Retrieved TransactionAttribute for TestBean9", actual);
+
+		RuleBasedTransactionAttribute rbta = new RuleBasedTransactionAttribute();
+		rbta.getRollbackRules().add(new RollbackRuleAttribute(Exception.class));
+		rbta.getRollbackRules().add(new NoRollbackRuleAttribute(IOException.class));
+		assertEquals(rbta.getRollbackRules(), ((RuleBasedTransactionAttribute) actual).getRollbackRules());
+
+		assertTrue(actual.isReadOnly());
+	}
+
+	@Test
+	public void customMethodAttributeWithReadOnlyOverrideOnInterface() throws Exception {
+		Method method = TestInterface10.class.getMethod("getAge", (Class[]) null);
+
+		Transactional annotation = AnnotationUtils.findAnnotation(method, Transactional.class);
+		assertNotNull("AnnotationUtils.findAnnotation failed to find @Transactional for TestBean10.getAge()",
+				annotation);
+		annotation = AnnotationUtils.findAnnotation(TestBean10.class, Transactional.class);
+		assertNull("AnnotationUtils.findAnnotation should not find @Transactional for TestBean10", annotation);
+
+		AnnotationTransactionAttributeSource atas = new AnnotationTransactionAttributeSource();
+		TransactionAttribute actual = atas.getTransactionAttribute(method, TestBean10.class);
+		assertNotNull("Retrieved TransactionAttribute for TestBean10", actual);
+
+		RuleBasedTransactionAttribute rbta = new RuleBasedTransactionAttribute();
+		rbta.getRollbackRules().add(new RollbackRuleAttribute(Exception.class));
+		rbta.getRollbackRules().add(new NoRollbackRuleAttribute(IOException.class));
+		assertEquals(rbta.getRollbackRules(), ((RuleBasedTransactionAttribute) actual).getRollbackRules());
+
+		assertTrue(actual.isReadOnly());
+	}
+
 	@Test
 	public void testTransactionAttributeDeclaredOnClassMethodWithEjb3() throws Exception {
 		Method getAgeMethod = ITestBean.class.getMethod("getAge", (Class[]) null);
@@ -258,6 +334,42 @@ public class AnnotationTransactionAttributeSourceTests {
 		assertEquals(TransactionAttribute.PROPAGATION_SUPPORTS, getNameAttr.getPropagationBehavior());
 	}
 
+	@Test
+	public void testTransactionAttributeDeclaredOnClassMethodWithJta() throws Exception {
+		Method getAgeMethod = ITestBean.class.getMethod("getAge", (Class[]) null);
+		Method getNameMethod = ITestBean.class.getMethod("getName", (Class[]) null);
+
+		AnnotationTransactionAttributeSource atas = new AnnotationTransactionAttributeSource();
+		TransactionAttribute getAgeAttr = atas.getTransactionAttribute(getAgeMethod, JtaAnnotatedBean1.class);
+		assertEquals(TransactionAttribute.PROPAGATION_REQUIRED, getAgeAttr.getPropagationBehavior());
+		TransactionAttribute getNameAttr = atas.getTransactionAttribute(getNameMethod, JtaAnnotatedBean1.class);
+		assertEquals(TransactionAttribute.PROPAGATION_SUPPORTS, getNameAttr.getPropagationBehavior());
+	}
+
+	@Test
+	public void testTransactionAttributeDeclaredOnClassWithJta() throws Exception {
+		Method getAgeMethod = ITestBean.class.getMethod("getAge", (Class[]) null);
+		Method getNameMethod = ITestBean.class.getMethod("getName", (Class[]) null);
+
+		AnnotationTransactionAttributeSource atas = new AnnotationTransactionAttributeSource();
+		TransactionAttribute getAgeAttr = atas.getTransactionAttribute(getAgeMethod, JtaAnnotatedBean2.class);
+		assertEquals(TransactionAttribute.PROPAGATION_REQUIRED, getAgeAttr.getPropagationBehavior());
+		TransactionAttribute getNameAttr = atas.getTransactionAttribute(getNameMethod, JtaAnnotatedBean2.class);
+		assertEquals(TransactionAttribute.PROPAGATION_SUPPORTS, getNameAttr.getPropagationBehavior());
+	}
+
+	@Test
+	public void testTransactionAttributeDeclaredOnInterfaceWithJta() throws Exception {
+		Method getAgeMethod = ITestEjb.class.getMethod("getAge", (Class[]) null);
+		Method getNameMethod = ITestEjb.class.getMethod("getName", (Class[]) null);
+
+		AnnotationTransactionAttributeSource atas = new AnnotationTransactionAttributeSource();
+		TransactionAttribute getAgeAttr = atas.getTransactionAttribute(getAgeMethod, JtaAnnotatedBean3.class);
+		assertEquals(TransactionAttribute.PROPAGATION_REQUIRED, getAgeAttr.getPropagationBehavior());
+		TransactionAttribute getNameAttr = atas.getTransactionAttribute(getNameMethod, JtaAnnotatedBean3.class);
+		assertEquals(TransactionAttribute.PROPAGATION_SUPPORTS, getNameAttr.getPropagationBehavior());
+	}
+
 
 	public interface ITestBean {
 
@@ -507,6 +619,61 @@ public class AnnotationTransactionAttributeSourceTests {
 	}
 
 
+	@Target({ElementType.TYPE, ElementType.METHOD})
+	@Retention(RetentionPolicy.RUNTIME)
+	@Transactional(rollbackFor=Exception.class, noRollbackFor={IOException.class})
+	public @interface TxWithAttribute {
+
+		boolean readOnly();
+	}
+
+
+	@TxWithAttribute(readOnly=true)
+	public static class TestBean7 {
+
+		public int getAge() {
+			return 10;
+		}
+	}
+
+
+	public static class TestBean8 {
+
+		@TxWithAttribute(readOnly = true)
+		public int getAge() {
+			return 10;
+		}
+	}
+
+	@TxWithAttribute(readOnly = true)
+	public static interface TestInterface9 {
+
+		public int getAge();
+	}
+
+	public static class TestBean9 implements TestInterface9 {
+
+		@Override
+		public int getAge() {
+			return 10;
+		}
+	}
+
+	public static interface TestInterface10 {
+
+		@TxWithAttribute(readOnly=true)
+		public int getAge();
+	}
+
+	public static class TestBean10 implements TestInterface10 {
+
+		@Override
+		public int getAge() {
+			return 10;
+		}
+	}
+
+
 	public static interface Foo<T> {
 
 		void doSomething(T theArgument);
@@ -624,4 +791,106 @@ public class AnnotationTransactionAttributeSourceTests {
 		}
 	}
 
+
+	public static class JtaAnnotatedBean1 implements ITestBean {
+
+		private String name;
+
+		private int age;
+
+		@Override
+		@javax.transaction.Transactional(javax.transaction.Transactional.TxType.SUPPORTS)
+		public String getName() {
+			return name;
+		}
+
+		@Override
+		public void setName(String name) {
+			this.name = name;
+		}
+
+		@Override
+		@javax.transaction.Transactional
+		public int getAge() {
+			return age;
+		}
+
+		@Override
+		public void setAge(int age) {
+			this.age = age;
+		}
+	}
+
+
+	@javax.transaction.Transactional(javax.transaction.Transactional.TxType.SUPPORTS)
+	public static class JtaAnnotatedBean2 implements ITestBean {
+
+		private String name;
+
+		private int age;
+
+		@Override
+		public String getName() {
+			return name;
+		}
+
+		@Override
+		public void setName(String name) {
+			this.name = name;
+		}
+
+		@Override
+		@javax.transaction.Transactional
+		public int getAge() {
+			return age;
+		}
+
+		@Override
+		public void setAge(int age) {
+			this.age = age;
+		}
+	}
+
+
+	@javax.transaction.Transactional(javax.transaction.Transactional.TxType.SUPPORTS)
+	public interface ITestJta {
+
+		@javax.transaction.Transactional
+		int getAge();
+
+		void setAge(int age);
+
+		String getName();
+
+		void setName(String name);
+	}
+
+
+	public static class JtaAnnotatedBean3 implements ITestEjb {
+
+		private String name;
+
+		private int age;
+
+		@Override
+		public String getName() {
+			return name;
+		}
+
+		@Override
+		public void setName(String name) {
+			this.name = name;
+		}
+
+		@Override
+		public int getAge() {
+			return age;
+		}
+
+		@Override
+		public void setAge(int age) {
+			this.age = age;
+		}
+	}
+
 }
