@@ -28,9 +28,9 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.Date;
 import java.util.Enumeration;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
+import java.util.LinkedHashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
@@ -52,15 +52,14 @@ import javax.servlet.http.Part;
 
 import org.springframework.util.Assert;
 import org.springframework.util.LinkedCaseInsensitiveMap;
+import org.springframework.util.LinkedMultiValueMap;
+import org.springframework.util.MultiValueMap;
 import org.springframework.util.StringUtils;
 
 /**
- * Mock implementation of the {@link javax.servlet.http.HttpServletRequest}
- * interface. Supports the Servlet 2.5 API level; throws
- * {@link UnsupportedOperationException} for some methods introduced in Servlet 3.0.
+ * Mock implementation of the {@link javax.servlet.http.HttpServletRequest} interface.
  *
- * <p>Used for testing the web framework; also useful for testing
- * application controllers.
+ * <p>As of Spring 4.0, this set of mocks is designed on a Servlet 3.0 baseline.
  *
  * @author Juergen Hoeller
  * @author Rod Johnson
@@ -68,6 +67,7 @@ import org.springframework.util.StringUtils;
  * @author Mark Fisher
  * @author Chris Beams
  * @author Sam Brannen
+ * @author Brian Clozel
  * @since 1.0.2
  */
 public class MockHttpServletRequest implements HttpServletRequest {
@@ -106,6 +106,9 @@ public class MockHttpServletRequest implements HttpServletRequest {
 
 	private static final String CHARSET_PREFIX = "charset=";
 
+	private static final ServletInputStream EMPTY_SERVLET_INPUT_STREAM =
+			new DelegatingServletInputStream(new ByteArrayInputStream(new byte[0]));
+
 
 	private boolean active = true;
 
@@ -151,7 +154,13 @@ public class MockHttpServletRequest implements HttpServletRequest {
 
 	private int localPort = DEFAULT_SERVER_PORT;
 
-	private final Map<String, Part> parts = new HashMap<String, Part>();
+	private boolean asyncStarted = false;
+
+	private boolean asyncSupported = false;
+
+	private MockAsyncContext asyncContext;
+
+	private DispatcherType dispatcherType = DispatcherType.REQUEST;
 
 
 	// ---------------------------------------------------------------------
@@ -192,13 +201,7 @@ public class MockHttpServletRequest implements HttpServletRequest {
 
 	private boolean requestedSessionIdFromURL = false;
 
-	private boolean asyncSupported = false;
-
-	private boolean asyncStarted = false;
-
-	private MockAsyncContext asyncContext;
-
-	private DispatcherType dispatcherType = DispatcherType.REQUEST;
+	private final MultiValueMap<String, Part> parts = new LinkedMultiValueMap<String, Part>();
 
 
 	// ---------------------------------------------------------------------
@@ -229,8 +232,8 @@ public class MockHttpServletRequest implements HttpServletRequest {
 
 	/**
 	 * Create a new {@code MockHttpServletRequest} with the supplied {@link ServletContext}.
-	 * @param servletContext the ServletContext that the request runs in (may be
-	 * {@code null} to use a default {@link MockServletContext})
+	 * @param servletContext the ServletContext that the request runs in
+	 * (may be {@code null} to use a default {@link MockServletContext})
 	 * @see #MockHttpServletRequest(ServletContext, String, String)
 	 */
 	public MockHttpServletRequest(ServletContext servletContext) {
@@ -317,7 +320,7 @@ public class MockHttpServletRequest implements HttpServletRequest {
 	@Override
 	public Enumeration<String> getAttributeNames() {
 		checkActive();
-		return Collections.enumeration(this.attributes.keySet());
+		return Collections.enumeration(new LinkedHashSet<String>(this.attributes.keySet()));
 	}
 
 	@Override
@@ -351,6 +354,10 @@ public class MockHttpServletRequest implements HttpServletRequest {
 		return (this.content != null ? this.content.length : -1);
 	}
 
+	public long getContentLengthLong() {
+		return getContentLength();
+	}
+
 	public void setContentType(String contentType) {
 		this.contentType = contentType;
 		if (contentType != null) {
@@ -373,7 +380,7 @@ public class MockHttpServletRequest implements HttpServletRequest {
 			return new DelegatingServletInputStream(new ByteArrayInputStream(this.content));
 		}
 		else {
-			return null;
+			return EMPTY_SERVLET_INPUT_STREAM;
 		}
 	}
 
@@ -689,10 +696,61 @@ public class MockHttpServletRequest implements HttpServletRequest {
 		return this.localPort;
 	}
 
+	@Override
+	public AsyncContext startAsync() {
+		return startAsync(this, null);
+	}
 
-	//---------------------------------------------------------------------
+	@Override
+	public AsyncContext startAsync(ServletRequest request, ServletResponse response) {
+		if (!this.asyncSupported) {
+			throw new IllegalStateException("Async not supported");
+		}
+		this.asyncStarted = true;
+		this.asyncContext = new MockAsyncContext(request, response);
+		return this.asyncContext;
+	}
+
+	public void setAsyncStarted(boolean asyncStarted) {
+		this.asyncStarted = asyncStarted;
+	}
+
+	@Override
+	public boolean isAsyncStarted() {
+		return this.asyncStarted;
+	}
+
+	public void setAsyncSupported(boolean asyncSupported) {
+		this.asyncSupported = asyncSupported;
+	}
+
+	@Override
+	public boolean isAsyncSupported() {
+		return this.asyncSupported;
+	}
+
+	public void setAsyncContext(MockAsyncContext asyncContext) {
+		this.asyncContext = asyncContext;
+	}
+
+	@Override
+	public AsyncContext getAsyncContext() {
+		return this.asyncContext;
+	}
+
+	public void setDispatcherType(DispatcherType dispatcherType) {
+		this.dispatcherType = dispatcherType;
+	}
+
+	@Override
+	public DispatcherType getDispatcherType() {
+		return this.dispatcherType;
+	}
+
+
+	// ---------------------------------------------------------------------
 	// HttpServletRequest interface
-	//---------------------------------------------------------------------
+	// ---------------------------------------------------------------------
 
 	public void setAuthType(String authType) {
 		this.authType = authType;
@@ -714,15 +772,15 @@ public class MockHttpServletRequest implements HttpServletRequest {
 
 	/**
 	 * Add a header entry for the given name.
-	 * <p>If there was no entry for that header name before,
-	 * the value will be used as-is. In case of an existing entry,
-	 * a String array will be created, adding the given value (more
-	 * specifically, its toString representation) as further element.
-	 * <p>Multiple values can only be stored as list of Strings,
-	 * following the Servlet spec (see {@code getHeaders} accessor).
-	 * As alternative to repeated {@code addHeader} calls for
-	 * individual elements, you can use a single call with an entire
-	 * array or Collection of values as parameter.
+	 * <p>If there was no entry for that header name before, the value will be used
+	 * as-is. In case of an existing entry, a String array will be created,
+	 * adding the given value (more specifically, its toString representation)
+	 * as further element.
+	 * <p>Multiple values can only be stored as list of Strings, following the
+	 * Servlet spec (see {@code getHeaders} accessor). As alternative to
+	 * repeated {@code addHeader} calls for individual elements, you can
+	 * use a single call with an entire array or Collection of values as
+	 * parameter.
 	 * @see #getHeaderNames
 	 * @see #getHeader
 	 * @see #getHeaders
@@ -899,9 +957,17 @@ public class MockHttpServletRequest implements HttpServletRequest {
 
 	@Override
 	public StringBuffer getRequestURL() {
-		StringBuffer url = new StringBuffer(this.scheme);
-		url.append("://").append(this.serverName).append(':').append(this.serverPort);
-		url.append(getRequestURI());
+		StringBuffer url = new StringBuffer(this.scheme).append("://").append(this.serverName);
+
+		if (this.serverPort > 0
+				&& (("http".equalsIgnoreCase(scheme) && this.serverPort != 80) || ("https".equalsIgnoreCase(scheme) && this.serverPort != 443))) {
+			url.append(':').append(this.serverPort);
+		}
+
+		if (StringUtils.hasText(getRequestURI())) {
+			url.append(getRequestURI());
+		}
+
 		return url;
 	}
 
@@ -941,6 +1007,20 @@ public class MockHttpServletRequest implements HttpServletRequest {
 		return getSession(true);
 	}
 
+	/**
+	 * The implementation of this (Servlet 3.1+) method calls
+	 * {@link MockHttpSession#changeSessionId()} if the session is a mock session.
+	 * Otherwise it simply returns the current session id.
+	 * @since 4.0.3
+	 */
+	public String changeSessionId() {
+		Assert.isTrue(this.session != null, "The request does not have a session");
+		if (this.session instanceof MockHttpSession) {
+			return ((MockHttpSession) session).changeSessionId();
+		}
+		return this.session.getId();
+	}
+
 	public void setRequestedSessionIdValid(boolean requestedSessionIdValid) {
 		this.requestedSessionIdValid = requestedSessionIdValid;
 	}
@@ -973,89 +1053,39 @@ public class MockHttpServletRequest implements HttpServletRequest {
 		return isRequestedSessionIdFromURL();
 	}
 
-
-	//---------------------------------------------------------------------
-	// Methods introduced in Servlet 3.0
-	//---------------------------------------------------------------------
-
 	@Override
-	public AsyncContext getAsyncContext() {
-		return this.asyncContext;
-	}
-
-	public void setAsyncContext(MockAsyncContext asyncContext) {
-		this.asyncContext = asyncContext;
-	}
-
-	@Override
-	public DispatcherType getDispatcherType() {
-		return this.dispatcherType;
-	}
-
-	public void setDispatcherType(DispatcherType dispatcherType) {
-		this.dispatcherType = dispatcherType;
-	}
-
-	public void setAsyncSupported(boolean asyncSupported) {
-		this.asyncSupported = asyncSupported;
-	}
-
-	@Override
-	public boolean isAsyncSupported() {
-		return this.asyncSupported;
-	}
-
-	@Override
-	public AsyncContext startAsync() {
-		return startAsync(this, null);
-	}
-
-	@Override
-	public AsyncContext startAsync(ServletRequest request, ServletResponse response) {
-		if (!this.asyncSupported) {
-			throw new IllegalStateException("Async not supported");
-		}
-		this.asyncStarted = true;
-		this.asyncContext = new MockAsyncContext(request, response);
-		return this.asyncContext;
-	}
-
-	public void setAsyncStarted(boolean asyncStarted) {
-		this.asyncStarted = asyncStarted;
-	}
-
-	@Override
-	public boolean isAsyncStarted() {
-		return this.asyncStarted;
-	}
-
-	@Override
-	public boolean authenticate(HttpServletResponse arg0) throws IOException, ServletException {
+	public boolean authenticate(HttpServletResponse response) throws IOException, ServletException {
 		throw new UnsupportedOperationException();
 	}
 
-	public void addPart(Part part) {
-		parts.put(part.getName(), part);
-	}
-
 	@Override
-	public Part getPart(String key) throws IOException, IllegalStateException, ServletException {
-		return parts.get(key);
-	}
-
-	@Override
-	public Collection<Part> getParts() throws IOException, IllegalStateException, ServletException {
-		return parts.values();
-	}
-
-	@Override
-	public void login(String arg0, String arg1) throws ServletException {
+	public void login(String username, String password) throws ServletException {
 		throw new UnsupportedOperationException();
 	}
 
 	@Override
 	public void logout() throws ServletException {
-		throw new UnsupportedOperationException();
+		this.userPrincipal = null;
+		this.remoteUser = null;
+		this.authType = null;
+	}
+
+	public void addPart(Part part) {
+		this.parts.add(part.getName(), part);
+	}
+
+	@Override
+	public Part getPart(String name) throws IOException, IllegalStateException, ServletException {
+		return this.parts.getFirst(name);
+	}
+
+	@Override
+	public Collection<Part> getParts() throws IOException, IllegalStateException, ServletException {
+		List<Part> result = new LinkedList<Part>();
+		for(List<Part> list : this.parts.values()) {
+			result.addAll(list);
+		}
+		return result;
 	}
 
 }
