@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -40,7 +40,9 @@ import org.springframework.web.util.WebUtils;
 /**
  * Mock implementation of the {@link javax.servlet.http.HttpServletResponse} interface.
  *
- * <p>Compatible with Servlet 2.5 as well as Servlet 3.0.
+ * <p>As of Spring 4.0, this set of mocks is designed on a Servlet 3.0 baseline.
+ * Beyond that, {@code MockHttpServletResponse} is also compatible with Servlet
+ * 3.1's {@code setContentLengthLong()} method.
  *
  * @author Juergen Hoeller
  * @author Rod Johnson
@@ -69,13 +71,13 @@ public class MockHttpServletResponse implements HttpServletResponse {
 
 	private boolean charset = false;
 
-	private final ByteArrayOutputStream content = new ByteArrayOutputStream();
+	private final ByteArrayOutputStream content = new ByteArrayOutputStream(1024);
 
 	private final ServletOutputStream outputStream = new ResponseServletOutputStream(this.content);
 
 	private PrintWriter writer;
 
-	private int contentLength = 0;
+	private long contentLength = 0;
 
 	private String contentType;
 
@@ -187,8 +189,8 @@ public class MockHttpServletResponse implements HttpServletResponse {
 
 	public String getContentAsString() throws UnsupportedEncodingException {
 		flushBuffer();
-		return (this.characterEncoding != null) ?
-				this.content.toString(this.characterEncoding) : this.content.toString();
+		return (this.characterEncoding != null ?
+				this.content.toString(this.characterEncoding) : this.content.toString());
 	}
 
 	@Override
@@ -198,6 +200,15 @@ public class MockHttpServletResponse implements HttpServletResponse {
 	}
 
 	public int getContentLength() {
+		return (int) this.contentLength;
+	}
+
+	public void setContentLengthLong(long contentLength) {
+		this.contentLength = contentLength;
+		doAddHeaderValue(CONTENT_LENGTH_HEADER, contentLength, true);
+	}
+
+	public long getContentLengthLong() {
 		return this.contentLength;
 	}
 
@@ -207,8 +218,7 @@ public class MockHttpServletResponse implements HttpServletResponse {
 		if (contentType != null) {
 			int charsetIndex = contentType.toLowerCase().indexOf(CHARSET_PREFIX);
 			if (charsetIndex != -1) {
-				String encoding = contentType.substring(charsetIndex + CHARSET_PREFIX.length());
-				this.characterEncoding = encoding;
+				this.characterEncoding = contentType.substring(charsetIndex + CHARSET_PREFIX.length());
 				this.charset = true;
 			}
 			updateContentTypeHeader();
@@ -405,11 +415,13 @@ public class MockHttpServletResponse implements HttpServletResponse {
 	}
 
 	@Override
+	@Deprecated
 	public String encodeUrl(String url) {
 		return encodeURL(url);
 	}
 
 	@Override
+	@Deprecated
 	public String encodeRedirectUrl(String url) {
 		return encodeRedirectURL(url);
 	}
@@ -494,11 +506,12 @@ public class MockHttpServletResponse implements HttpServletResponse {
 
 	private boolean setSpecialHeader(String name, Object value) {
 		if (CONTENT_TYPE_HEADER.equalsIgnoreCase(name)) {
-			setContentType((String) value);
+			setContentType(value.toString());
 			return true;
 		}
 		else if (CONTENT_LENGTH_HEADER.equalsIgnoreCase(name)) {
-			setContentLength(Integer.parseInt((String) value));
+			setContentLength(value instanceof Number ? ((Number) value).intValue() :
+					Integer.parseInt(value.toString()));
 			return true;
 		}
 		else {
@@ -523,13 +536,18 @@ public class MockHttpServletResponse implements HttpServletResponse {
 
 	@Override
 	public void setStatus(int status) {
-		this.status = status;
+		if (!this.isCommitted()) {
+			this.status = status;
+		}
 	}
 
 	@Override
+	@Deprecated
 	public void setStatus(int status, String errorMessage) {
-		this.status = status;
-		this.errorMessage = errorMessage;
+		if (!this.isCommitted()) {
+			this.status = status;
+			this.errorMessage = errorMessage;
+		}
 	}
 
 	@Override
