@@ -16,6 +16,7 @@
 
 package org.springframework.web.client;
 
+import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.net.URI;
 import java.util.Collections;
@@ -27,9 +28,11 @@ import java.util.Set;
 
 import org.junit.Before;
 import org.junit.Test;
+
 import org.springframework.core.ParameterizedTypeReference;
 import org.springframework.http.HttpEntity;
 import org.springframework.http.HttpHeaders;
+import org.springframework.http.HttpInputMessage;
 import org.springframework.http.HttpMethod;
 import org.springframework.http.HttpStatus;
 import org.springframework.http.MediaType;
@@ -59,6 +62,7 @@ public class RestTemplateTests {
 
 	private ResponseErrorHandler errorHandler;
 
+	@SuppressWarnings("rawtypes")
 	private HttpMessageConverter converter;
 
 	@Before
@@ -168,14 +172,15 @@ public class RestTemplateTests {
 		given(request.getHeaders()).willReturn(requestHeaders);
 		given(request.execute()).willReturn(response);
 		given(errorHandler.hasError(response)).willReturn(false);
+		String expected = "Hello World";
 		HttpHeaders responseHeaders = new HttpHeaders();
 		responseHeaders.setContentType(textPlain);
 		responseHeaders.setContentLength(10);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		given(response.getHeaders()).willReturn(responseHeaders);
+		given(response.getBody()).willReturn(new ByteArrayInputStream(expected.getBytes()));
 		given(converter.canRead(String.class, textPlain)).willReturn(true);
-		String expected = "Hello World";
-		given(converter.read(String.class, response)).willReturn(expected);
+		given(converter.read(eq(String.class), any(HttpInputMessage.class))).willReturn(expected);
 		HttpStatus status = HttpStatus.OK;
 		given(response.getStatusCode()).willReturn(status);
 		given(response.getStatusText()).willReturn(status.getReasonPhrase());
@@ -203,6 +208,7 @@ public class RestTemplateTests {
 		responseHeaders.setContentLength(10);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		given(response.getHeaders()).willReturn(responseHeaders);
+		given(response.getBody()).willReturn(new ByteArrayInputStream("Foo".getBytes()));
 		given(converter.canRead(String.class, contentType)).willReturn(false);
 		HttpStatus status = HttpStatus.OK;
 		given(response.getStatusCode()).willReturn(status);
@@ -230,14 +236,15 @@ public class RestTemplateTests {
 		given(request.getHeaders()).willReturn(requestHeaders);
 		given(request.execute()).willReturn(response);
 		given(errorHandler.hasError(response)).willReturn(false);
+		String expected = "Hello World";
 		HttpHeaders responseHeaders = new HttpHeaders();
 		responseHeaders.setContentType(textPlain);
 		responseHeaders.setContentLength(10);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		given(response.getHeaders()).willReturn(responseHeaders);
+		given(response.getBody()).willReturn(new ByteArrayInputStream(expected.getBytes()));
 		given(converter.canRead(String.class, textPlain)).willReturn(true);
-		String expected = "Hello World";
-		given(converter.read(String.class, response)).willReturn(expected);
+		given(converter.read(eq(String.class), any(HttpInputMessage.class))).willReturn(expected);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		HttpStatus status = HttpStatus.OK;
 		given(response.getStatusCode()).willReturn(status);
@@ -403,14 +410,15 @@ public class RestTemplateTests {
 		converter.write(request, null, this.request);
 		given(this.request.execute()).willReturn(response);
 		given(errorHandler.hasError(response)).willReturn(false);
+		Integer expected = 42;
 		HttpHeaders responseHeaders = new HttpHeaders();
 		responseHeaders.setContentType(textPlain);
 		responseHeaders.setContentLength(10);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		given(response.getHeaders()).willReturn(responseHeaders);
-		Integer expected = 42;
+		given(response.getBody()).willReturn(new ByteArrayInputStream(expected.toString().getBytes()));
 		given(converter.canRead(Integer.class, textPlain)).willReturn(true);
-		given(converter.read(Integer.class, response)).willReturn(expected);
+		given(converter.read(eq(Integer.class), any(HttpInputMessage.class))).willReturn(expected);
 		HttpStatus status = HttpStatus.OK;
 		given(response.getStatusCode()).willReturn(status);
 		given(response.getStatusText()).willReturn(status.getReasonPhrase());
@@ -435,14 +443,15 @@ public class RestTemplateTests {
 		converter.write(request, null, this.request);
 		given(this.request.execute()).willReturn(response);
 		given(errorHandler.hasError(response)).willReturn(false);
+		Integer expected = 42;
 		HttpHeaders responseHeaders = new HttpHeaders();
 		responseHeaders.setContentType(textPlain);
 		responseHeaders.setContentLength(10);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		given(response.getHeaders()).willReturn(responseHeaders);
-		Integer expected = 42;
+		given(response.getBody()).willReturn(new ByteArrayInputStream(expected.toString().getBytes()));
 		given(converter.canRead(Integer.class, textPlain)).willReturn(true);
-		given(converter.read(Integer.class, response)).willReturn(expected);
+		given(converter.read(eq(Integer.class), any(HttpInputMessage.class))).willReturn(expected);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		HttpStatus status = HttpStatus.OK;
 		given(response.getStatusCode()).willReturn(status);
@@ -613,14 +622,16 @@ public class RestTemplateTests {
 		converter.write(body, null, this.request);
 		given(this.request.execute()).willReturn(response);
 		given(errorHandler.hasError(response)).willReturn(false);
+		Integer expected = 42;
 		HttpHeaders responseHeaders = new HttpHeaders();
 		responseHeaders.setContentType(MediaType.TEXT_PLAIN);
 		responseHeaders.setContentLength(10);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		given(response.getHeaders()).willReturn(responseHeaders);
-		Integer expected = 42;
+		given(response.getBody()).willReturn(new ByteArrayInputStream(expected.toString().getBytes()));
 		given(converter.canRead(Integer.class, MediaType.TEXT_PLAIN)).willReturn(true);
 		given(converter.read(Integer.class, response)).willReturn(expected);
+		given(converter.read(eq(Integer.class), any(HttpInputMessage.class))).willReturn(expected);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		HttpStatus status = HttpStatus.OK;
 		given(response.getStatusCode()).willReturn(status);
@@ -640,6 +651,7 @@ public class RestTemplateTests {
 	}
 
 	@Test
+	@SuppressWarnings("rawtypes")
 	public void exchangeParameterizedType() throws Exception {
 		GenericHttpMessageConverter converter = mock(GenericHttpMessageConverter.class);
 		template.setMessageConverters(Collections.<HttpMessageConverter<?>>singletonList(converter));
@@ -655,14 +667,15 @@ public class RestTemplateTests {
 		converter.write(requestBody, null, this.request);
 		given(this.request.execute()).willReturn(response);
 		given(errorHandler.hasError(response)).willReturn(false);
+		List<Integer> expected = Collections.singletonList(42);
 		HttpHeaders responseHeaders = new HttpHeaders();
 		responseHeaders.setContentType(MediaType.TEXT_PLAIN);
 		responseHeaders.setContentLength(10);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		given(response.getHeaders()).willReturn(responseHeaders);
-		List<Integer> expected = Collections.singletonList(42);
+		given(response.getBody()).willReturn(new ByteArrayInputStream(new Integer(42).toString().getBytes()));
 		given(converter.canRead(intList.getType(), null, MediaType.TEXT_PLAIN)).willReturn(true);
-		given(converter.read(intList.getType(), null, response)).willReturn(expected);
+		given(converter.read(eq(intList.getType()), eq(null), any(HttpInputMessage.class))).willReturn(expected);
 		given(response.getStatusCode()).willReturn(HttpStatus.OK);
 		HttpStatus status = HttpStatus.OK;
 		given(response.getStatusCode()).willReturn(status);
