@@ -1,57 +1,44 @@
 /*
-* Copyright 2002-2013 the original author or authors.
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-* http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
-*/
+ * Copyright 2002-2014 the original author or authors.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 package org.springframework.web.portlet;
 
-import java.io.IOException;
 import java.util.Locale;
 import java.util.Map;
 import javax.portlet.PortletContext;
 import javax.portlet.PortletException;
 import javax.portlet.PortletMode;
 import javax.portlet.PortletSecurityException;
-import javax.portlet.PortletSession;
 
 import junit.framework.TestCase;
 
-import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.context.ApplicationContext;
 import org.springframework.context.ConfigurableApplicationContext;
-import org.springframework.context.i18n.LocaleContext;
-import org.springframework.context.i18n.LocaleContextHolder;
 import org.springframework.mock.web.portlet.MockActionRequest;
 import org.springframework.mock.web.portlet.MockActionResponse;
-import org.springframework.mock.web.portlet.MockEvent;
-import org.springframework.mock.web.portlet.MockEventRequest;
-import org.springframework.mock.web.portlet.MockEventResponse;
 import org.springframework.mock.web.portlet.MockPortletConfig;
 import org.springframework.mock.web.portlet.MockPortletContext;
-import org.springframework.mock.web.portlet.MockPortletSession;
 import org.springframework.mock.web.portlet.MockRenderRequest;
 import org.springframework.mock.web.portlet.MockRenderResponse;
 import org.springframework.web.context.WebApplicationContext;
-import org.springframework.web.context.request.RequestAttributes;
-import org.springframework.web.context.request.RequestContextHolder;
 import org.springframework.web.context.support.StaticWebApplicationContext;
 import org.springframework.web.multipart.MaxUploadSizeExceededException;
 import org.springframework.web.portlet.context.PortletApplicationContextUtils;
 import org.springframework.web.portlet.context.PortletConfigAwareBean;
 import org.springframework.web.portlet.context.PortletContextAwareBean;
-import org.springframework.web.portlet.context.PortletRequestAttributes;
-import org.springframework.web.portlet.handler.PortletSessionRequiredException;
 import org.springframework.web.portlet.multipart.MultipartActionRequest;
 import org.springframework.web.portlet.multipart.PortletMultipartResolver;
 import org.springframework.web.servlet.ViewRendererServlet;
@@ -64,25 +51,16 @@ import org.springframework.web.servlet.view.InternalResourceView;
  */
 public class DispatcherPortletTests extends TestCase {
 
-	private MockPortletConfig simplePortletConfig;
-
 	private MockPortletConfig complexPortletConfig;
 
-	private DispatcherPortlet simpleDispatcherPortlet;
-
 	private DispatcherPortlet complexDispatcherPortlet;
 
 
 	@Override
 	protected void setUp() throws PortletException {
-		simplePortletConfig = new MockPortletConfig(new MockPortletContext(), "simple");
-		complexPortletConfig = new MockPortletConfig(simplePortletConfig.getPortletContext(), "complex");
+		complexPortletConfig = new MockPortletConfig(new MockPortletContext(), "complex");
 		complexPortletConfig.addInitParameter("publishContext", "false");
 
-		simpleDispatcherPortlet = new DispatcherPortlet();
-		simpleDispatcherPortlet.setContextClass(SimplePortletApplicationContext.class);
-		simpleDispatcherPortlet.init(simplePortletConfig);
-
 		complexDispatcherPortlet = new DispatcherPortlet();
 		complexDispatcherPortlet.setContextClass(ComplexPortletApplicationContext.class);
 		complexDispatcherPortlet.setNamespace("test");
@@ -103,14 +81,6 @@ public class DispatcherPortletTests extends TestCase {
 	}
 
 	public void testDispatcherPortlets() {
-		assertTrue("Correct namespace",
-				("simple" + FrameworkPortlet.DEFAULT_NAMESPACE_SUFFIX).equals(simpleDispatcherPortlet.getNamespace()));
-		assertTrue("Correct attribute",
-				(FrameworkPortlet.PORTLET_CONTEXT_PREFIX + "simple").equals(simpleDispatcherPortlet.getPortletContextAttributeName()));
-		assertTrue("Context published",
-				simpleDispatcherPortlet.getPortletApplicationContext() ==
-						getPortletContext().getAttribute(FrameworkPortlet.PORTLET_CONTEXT_PREFIX + "simple"));
-
 		assertTrue("Correct namespace", "test".equals(complexDispatcherPortlet.getNamespace()));
 		assertTrue("Correct attribute",
 				(FrameworkPortlet.PORTLET_CONTEXT_PREFIX + "complex").equals(complexDispatcherPortlet.getPortletContextAttributeName()));
@@ -118,192 +88,6 @@ public class DispatcherPortletTests extends TestCase {
 				getPortletContext().getAttribute(FrameworkPortlet.PORTLET_CONTEXT_PREFIX + "complex") == null);
 	}
 
-	public void testSimpleValidActionRequest() throws Exception {
-		MockActionRequest request = new MockActionRequest();
-		MockActionResponse response = new MockActionResponse();
-		request.setParameter("action", "form");
-		request.setParameter("age", "29");
-		simpleDispatcherPortlet.processAction(request, response);
-		String exceptionParam = response.getRenderParameter(DispatcherPortlet.ACTION_EXCEPTION_RENDER_PARAMETER);
-		assertNull(exceptionParam);
-		SimplePortletApplicationContext ac = (SimplePortletApplicationContext)simpleDispatcherPortlet.getPortletApplicationContext();
-		String commandAttribute = ac.getRenderCommandSessionAttributeName();
-		TestBean testBean = (TestBean) request.getPortletSession().getAttribute(commandAttribute);
-		assertEquals(39, testBean.getAge());
-	}
-
-	public void testSimpleInvalidActionRequest() throws Exception {
-		MockActionRequest request = new MockActionRequest();
-		MockActionResponse response = new MockActionResponse();
-		request.setParameter("action", "invalid");
-		simpleDispatcherPortlet.processAction(request, response);
-		String exceptionParam = response.getRenderParameter(DispatcherPortlet.ACTION_EXCEPTION_RENDER_PARAMETER);
-		assertNotNull(exceptionParam);
-		assertTrue(exceptionParam.startsWith(NoHandlerFoundException.class.getName()));
-	}
-
-
-	public void testSimpleInvalidActionRequestWithoutHandling() throws Exception {
-		MockActionRequest request = new MockActionRequest();
-		MockActionResponse response = new MockActionResponse();
-		request.setParameter("action", "invalid");
-		simpleDispatcherPortlet.setForwardActionException(false);
-		try {
-			simpleDispatcherPortlet.processAction(request, response);
-			fail("Should have thrown a " + NoHandlerFoundException.class);
-		}
-		catch (NoHandlerFoundException ex) {
-			// expected
-		}
-	}
-
-	public void testSimpleValidEventRequest() throws Exception {
-		MockEvent event = new MockEvent("test-event");
-		MockEventRequest request = new MockEventRequest(event);
-		MockEventResponse response = new MockEventResponse();
-		request.setParameter("action", "form");
-		simpleDispatcherPortlet.processEvent(request, response);
-		assertEquals("test-event", response.getRenderParameter("event"));
-	}
-
-	public void testSimpleInvalidEventRequest() throws Exception {
-		MockEvent event = new MockEvent("test-event");
-		MockEventRequest request = new MockEventRequest(event);
-		MockEventResponse response = new MockEventResponse();
-		request.setParameter("action", "invalid");
-		try {
-			simpleDispatcherPortlet.processEvent(request, response);
-			fail("Should have thrown a " + NoHandlerFoundException.class);
-		}
-		catch (NoHandlerFoundException ex) {
-			// expected
-		}
-	}
-
-	public void testSimpleInvalidEventRequestWithHandling() throws Exception {
-		MockEvent event = new MockEvent("event");
-		MockEventRequest request = new MockEventRequest(event);
-		MockEventResponse response = new MockEventResponse();
-		request.setParameter("action", "invalid");
-		simpleDispatcherPortlet.setForwardEventException(true);
-		simpleDispatcherPortlet.processEvent(request, response);
-		String exceptionParam = response.getRenderParameter(DispatcherPortlet.ACTION_EXCEPTION_RENDER_PARAMETER);
-		assertNotNull(exceptionParam);
-		assertTrue(exceptionParam.startsWith(NoHandlerFoundException.class.getName()));
-	}
-
-	public void testSimpleFormViewNoBindOnNewForm() throws Exception {
-		MockRenderRequest request = new MockRenderRequest();
-		MockRenderResponse response = new MockRenderResponse();
-		request.setParameter("action", "form");
-		request.setParameter("age", "29");
-		simpleDispatcherPortlet.doDispatch(request, response);
-		assertEquals("5", response.getContentAsString());
-	}
-
-	public void testSimpleFormViewBindOnNewForm() throws Exception {
-		MockRenderRequest request = new MockRenderRequest();
-		MockRenderResponse response = new MockRenderResponse();
-		request.setParameter("action", "form-bind");
-		request.setParameter("age", "29");
-		simpleDispatcherPortlet.doDispatch(request, response);
-		assertEquals("34", response.getContentAsString());
-	}
-
-	public void testSimpleFormViewWithSessionAndBindOnNewForm() throws Exception {
-		MockRenderRequest renderRequest = new MockRenderRequest();
-		MockRenderResponse renderResponse = new MockRenderResponse();
-		renderRequest.setParameter("action", "form-session-bind");
-		renderRequest.setParameter("age", "30");
-		TestBean testBean = new TestBean();
-		testBean.setAge(40);
-		SimplePortletApplicationContext ac =
-				(SimplePortletApplicationContext)simpleDispatcherPortlet.getPortletApplicationContext();
-		String formAttribute = ac.getFormSessionAttributeName();
-		PortletSession session = new MockPortletSession();
-		session.setAttribute(formAttribute, testBean);
-		renderRequest.setSession(session);
-		simpleDispatcherPortlet.doDispatch(renderRequest, renderResponse);
-		assertEquals("35", renderResponse.getContentAsString());
-	}
-
-	public void testSimpleFormViewWithSessionNoBindOnNewForm() throws Exception {
-		MockActionRequest actionRequest = new MockActionRequest();
-		MockActionResponse actionResponse = new MockActionResponse();
-		actionRequest.setSession(new MockPortletSession());
-		actionRequest.setParameter("action", "form-session-nobind");
-		actionRequest.setParameter("age", "27");
-		simpleDispatcherPortlet.processAction(actionRequest, actionResponse);
-		Map renderParameters = actionResponse.getRenderParameterMap();
-
-		MockRenderRequest renderRequest = new MockRenderRequest();
-		MockRenderResponse renderResponse = new MockRenderResponse();
-		renderRequest.setParameters(renderParameters);
-		renderRequest.setParameter("action", "form-session-nobind");
-		renderRequest.setParameter("age", "30");
-		renderRequest.setSession(actionRequest.getPortletSession());
-		simpleDispatcherPortlet.doDispatch(renderRequest, renderResponse);
-		assertEquals("finished42", renderResponse.getContentAsString());
-	}
-
-	public void testSimpleRequiredSessionFormWithoutSession() throws Exception {
-		MockRenderRequest request = new MockRenderRequest();
-		MockRenderResponse response = new MockRenderResponse();
-		request.setParameter("action", "form-session-bind");
-		try {
-			simpleDispatcherPortlet.doDispatch(request, response);
-			fail("Should have thrown PortletSessionRequiredException");
-		}
-		catch (PortletSessionRequiredException ex) {
-// expected
-		}
-	}
-
-	public void testSimpleFormSubmission() throws Exception {
-		MockActionRequest actionRequest = new MockActionRequest();
-		MockActionResponse actionResponse = new MockActionResponse();
-		actionRequest.setParameter("action", "form");
-		actionRequest.setParameter("age", "29");
-		simpleDispatcherPortlet.processAction(actionRequest, actionResponse);
-
-		MockRenderRequest renderRequest = new MockRenderRequest();
-		MockRenderResponse renderResponse = new MockRenderResponse();
-		renderRequest.setSession(actionRequest.getPortletSession());
-		renderRequest.setParameters(actionResponse.getRenderParameterMap());
-		renderRequest.setParameter("action", "form");
-		simpleDispatcherPortlet.doDispatch(renderRequest, renderResponse);
-		assertEquals("finished44", renderResponse.getContentAsString());
-	}
-
-	public void testSimpleFormSubmissionWithValidationError() throws Exception {
-		MockActionRequest actionRequest = new MockActionRequest();
-		MockActionResponse actionResponse = new MockActionResponse();
-		actionRequest.setParameter("action", "form");
-		actionRequest.setParameter("age", "XX");
-		simpleDispatcherPortlet.processAction(actionRequest, actionResponse);
-
-		MockRenderRequest renderRequest = new MockRenderRequest();
-		MockRenderResponse renderResponse = new MockRenderResponse();
-		renderRequest.setSession(actionRequest.getPortletSession());
-		renderRequest.setParameters(actionResponse.getRenderParameterMap());
-		renderRequest.setParameter("action", "form");
-		simpleDispatcherPortlet.doDispatch(renderRequest, renderResponse);
-		assertEquals("5", renderResponse.getContentAsString());
-	}
-
-	public void testSimpleInvalidRenderRequest() throws Exception {
-		MockRenderRequest request = new MockRenderRequest();
-		MockRenderResponse response = new MockRenderResponse();
-		request.setParameter("action", "invalid");
-		try {
-			simpleDispatcherPortlet.doDispatch(request, response);
-			fail("Should have thrown UnavailableException");
-		}
-		catch (NoHandlerFoundException ex) {
-// expected
-		}
-	}
-
 	public void testPortletModeParameterMappingHelp1() throws Exception {
 		MockActionRequest request = new MockActionRequest();
 		MockActionResponse response = new MockActionResponse();
@@ -341,7 +125,7 @@ public class DispatcherPortletTests extends TestCase {
 		request.setPortletMode(PortletMode.HELP);
 		request.setParameter("action", "help3");
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		assertTrue(model.get("exception").getClass().equals(NoHandlerFoundException.class));
 		InternalResourceView view = (InternalResourceView) request.getAttribute(ViewRendererServlet.VIEW_ATTRIBUTE);
 		assertEquals("failed-unavailable", view.getBeanName());
@@ -380,7 +164,7 @@ public class DispatcherPortletTests extends TestCase {
 		request.setParameter("action", "not mapped");
 		request.setParameter("myParam", "not mapped");
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		assertEquals("view was here", model.get("result"));
 		InternalResourceView view = (InternalResourceView) request.getAttribute(ViewRendererServlet.VIEW_ATTRIBUTE);
 		assertEquals("someViewName", view.getBeanName());
@@ -394,7 +178,7 @@ public class DispatcherPortletTests extends TestCase {
 		request.setParameter("action", "not mapped");
 		request.setParameter("myParam", "not mapped");
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		Exception exception = (Exception) model.get("exception");
 		assertNotNull(exception);
 		assertTrue(exception.getClass().equals(PortletSecurityException.class));
@@ -438,7 +222,7 @@ public class DispatcherPortletTests extends TestCase {
 		MockRenderResponse response = new MockRenderResponse();
 		request.setParameter("myParam", "unknown");
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		Exception exception = (Exception)model.get("exception");
 		assertTrue(exception.getClass().equals(PortletException.class));
 		assertTrue(exception.getMessage().indexOf("No adapter for handler") != -1);
@@ -471,7 +255,7 @@ public class DispatcherPortletTests extends TestCase {
 		MockRenderResponse response = new MockRenderResponse();
 		request.setParameter("myParam", "test1");
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		Exception exception = (Exception) model.get("exception");
 		assertTrue(exception.getClass().equals(NoHandlerFoundException.class));
 		InternalResourceView view = (InternalResourceView) request.getAttribute(ViewRendererServlet.VIEW_ATTRIBUTE);
@@ -549,7 +333,7 @@ public class DispatcherPortletTests extends TestCase {
 		request.setParameter("myParam", "requestLocaleChecker");
 		request.addPreferredLocale(Locale.ENGLISH);
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		Exception exception = (Exception) model.get("exception");
 		assertTrue(exception.getClass().equals(PortletException.class));
 		assertEquals("Incorrect Locale in RenderRequest", exception.getMessage());
@@ -572,7 +356,7 @@ public class DispatcherPortletTests extends TestCase {
 		request.setParameter("myParam", "contextLocaleChecker");
 		request.addPreferredLocale(Locale.ENGLISH);
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		Exception exception = (Exception) model.get("exception");
 		assertTrue(exception.getClass().equals(PortletException.class));
 		assertEquals("Incorrect Locale in LocaleContextHolder", exception.getMessage());
@@ -617,7 +401,7 @@ public class DispatcherPortletTests extends TestCase {
 		request.addUserRole("role1");
 		request.addParameter("noView", "false");
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		assertEquals("view was here", model.get("result"));
 		InternalResourceView view = (InternalResourceView) request.getAttribute(ViewRendererServlet.VIEW_ATTRIBUTE);
 		assertEquals("someViewName", view.getBeanName());
@@ -630,7 +414,7 @@ public class DispatcherPortletTests extends TestCase {
 		request.addUserRole("role1");
 		request.addParameter("noView", "true");
 		complexDispatcherPortlet.doDispatch(request, response);
-		Map model = (Map) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
+		Map<?, ?> model = (Map<?, ?>) request.getAttribute(ViewRendererServlet.MODEL_ATTRIBUTE);
 		assertNull(model);
 		InternalResourceView view = (InternalResourceView) request.getAttribute(ViewRendererServlet.VIEW_ATTRIBUTE);
 		assertNull(view);
@@ -859,115 +643,6 @@ public class DispatcherPortletTests extends TestCase {
 		}
 	}
 
-	public void testValidActionRequestWithExistingThreadLocalRequestContext() throws IOException, PortletException {
-		MockActionRequest request = new MockActionRequest();
-		MockActionResponse response = new MockActionResponse();
-		request.addPreferredLocale(Locale.GERMAN);
-		request.setParameter("action", "form");
-		request.setParameter("age", "29");
-
-// see RequestContextListener.requestInitialized()
-		try {
-			LocaleContextHolder.setLocale(request.getLocale());
-			RequestContextHolder.setRequestAttributes(new PortletRequestAttributes(request));
-
-			LocaleContext servletLocaleContext = LocaleContextHolder.getLocaleContext();
-			RequestAttributes servletRequestAttrs = RequestContextHolder.getRequestAttributes();
-
-			simpleDispatcherPortlet.processAction(request, response);
-
-			assertSame(servletLocaleContext, LocaleContextHolder.getLocaleContext());
-			assertSame(servletRequestAttrs, RequestContextHolder.getRequestAttributes());
-		}
-		finally {
-			RequestContextHolder.resetRequestAttributes();
-			LocaleContextHolder.resetLocaleContext();
-		}
-	}
-
-	public void testValidRenderRequestWithExistingThreadLocalRequestContext() throws IOException, PortletException {
-		MockRenderRequest request = new MockRenderRequest();
-		MockRenderResponse response = new MockRenderResponse();
-		request.addPreferredLocale(Locale.GERMAN);
-
-// see RequestContextListener.requestInitialized()
-		try {
-			LocaleContextHolder.setLocale(request.getLocale());
-			RequestContextHolder.setRequestAttributes(new PortletRequestAttributes(request));
-
-			LocaleContext servletLocaleContext = LocaleContextHolder.getLocaleContext();
-			RequestAttributes servletRequestAttrs = RequestContextHolder.getRequestAttributes();
-
-			request.setParameter("action", "form");
-			request.setParameter("age", "29");
-			simpleDispatcherPortlet.doDispatch(request, response);
-
-			assertSame(servletLocaleContext, LocaleContextHolder.getLocaleContext());
-			assertSame(servletRequestAttrs, RequestContextHolder.getRequestAttributes());
-		}
-		finally {
-			RequestContextHolder.resetRequestAttributes();
-			LocaleContextHolder.resetLocaleContext();
-		}
-	}
-
-	public void testInvalidActionRequestWithExistingThreadLocalRequestContext() throws IOException, PortletException {
-		MockActionRequest request = new MockActionRequest();
-		MockActionResponse response = new MockActionResponse();
-		request.addPreferredLocale(Locale.GERMAN);
-
-// see RequestContextListener.requestInitialized()
-		try {
-			LocaleContextHolder.setLocale(request.getLocale());
-			RequestContextHolder.setRequestAttributes(new PortletRequestAttributes(request));
-
-			LocaleContext servletLocaleContext = LocaleContextHolder.getLocaleContext();
-			RequestAttributes servletRequestAttrs = RequestContextHolder.getRequestAttributes();
-
-			request.setParameter("action", "invalid");
-			simpleDispatcherPortlet.processAction(request, response);
-			String exceptionParam = response.getRenderParameter(DispatcherPortlet.ACTION_EXCEPTION_RENDER_PARAMETER);
-			assertNotNull(exceptionParam); // ensure that an exceptional condition occured
-
-			assertSame(servletLocaleContext, LocaleContextHolder.getLocaleContext());
-			assertSame(servletRequestAttrs, RequestContextHolder.getRequestAttributes());
-		}
-		finally {
-			RequestContextHolder.resetRequestAttributes();
-			LocaleContextHolder.resetLocaleContext();
-		}
-	}
-
-	public void testInvalidRenderRequestWithExistingThreadLocalRequestContext() throws IOException, PortletException {
-		MockRenderRequest request = new MockRenderRequest();
-		MockRenderResponse response = new MockRenderResponse();
-		request.addPreferredLocale(Locale.GERMAN);
-
-// see RequestContextListener.requestInitialized()
-		try {
-			LocaleContextHolder.setLocale(request.getLocale());
-			RequestContextHolder.setRequestAttributes(new PortletRequestAttributes(request));
-
-			LocaleContext servletLocaleContext = LocaleContextHolder.getLocaleContext();
-			RequestAttributes servletRequestAttrs = RequestContextHolder.getRequestAttributes();
-
-			try {
-				simpleDispatcherPortlet.doDispatch(request, response);
-				fail("should have failed to find a handler and raised an NoHandlerFoundExceptionException");
-			}
-			catch (NoHandlerFoundException ex) {
-// expected
-			}
-
-			assertSame(servletLocaleContext, LocaleContextHolder.getLocaleContext());
-			assertSame(servletRequestAttrs, RequestContextHolder.getRequestAttributes());
-		}
-		finally {
-			RequestContextHolder.resetRequestAttributes();
-			LocaleContextHolder.resetLocaleContext();
-		}
-	}
-
 	public void testDispatcherPortletRefresh() throws PortletException {
 		MockPortletContext portletContext = new MockPortletContext("org/springframework/web/portlet/context");
 		DispatcherPortlet portlet = new DispatcherPortlet();
