@@ -16,11 +16,6 @@
 
 package org.springframework.web.context.support;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-
 import java.io.IOException;
 import java.util.Collections;
 import java.util.HashMap;
@@ -30,8 +25,8 @@ import java.util.Map;
 import java.util.Set;
 
 import org.junit.Test;
+
 import org.springframework.beans.MutablePropertyValues;
-import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.beans.factory.BeanCreationException;
 import org.springframework.beans.factory.config.BeanDefinitionHolder;
 import org.springframework.beans.factory.config.ConstructorArgumentValues;
@@ -43,6 +38,9 @@ import org.springframework.beans.factory.support.ManagedSet;
 import org.springframework.beans.factory.support.RootBeanDefinition;
 import org.springframework.core.io.Resource;
 import org.springframework.mock.web.test.MockServletContext;
+import org.springframework.tests.sample.beans.TestBean;
+
+import static org.junit.Assert.*;
 
 /**
  * Tests for various ServletContext-related support classes.
@@ -53,21 +51,6 @@ import org.springframework.mock.web.test.MockServletContext;
  */
 public class ServletContextSupportTests {
 
-	@Test
-	@Deprecated
-	public void testServletContextFactoryBean() {
-		MockServletContext sc = new MockServletContext();
-
-		StaticWebApplicationContext wac = new StaticWebApplicationContext();
-		wac.setServletContext(sc);
-		MutablePropertyValues pvs = new MutablePropertyValues();
-		wac.registerSingleton("servletContext", ServletContextFactoryBean.class, pvs);
-		wac.refresh();
-
-		Object value = wac.getBean("servletContext");
-		assertEquals(sc, value);
-	}
-
 	@Test
 	public void testServletContextAttributeFactoryBean() {
 		MockServletContext sc = new MockServletContext();
@@ -101,7 +84,7 @@ public class ServletContextSupportTests {
 		catch (BeanCreationException ex) {
 			// expected
 			assertTrue(ex.getCause() instanceof IllegalStateException);
-			assertTrue(ex.getCause().getMessage().indexOf("myAttr") != -1);
+			assertTrue(ex.getCause().getMessage().contains("myAttr"));
 		}
 	}
 
@@ -138,7 +121,7 @@ public class ServletContextSupportTests {
 		catch (BeanCreationException ex) {
 			// expected
 			assertTrue(ex.getCause() instanceof IllegalStateException);
-			assertTrue(ex.getCause().getMessage().indexOf("myParam") != -1);
+			assertTrue(ex.getCause().getMessage().contains("myParam"));
 		}
 	}
 
