@@ -25,9 +25,9 @@ import javax.servlet.jsp.PageContext;
 import javax.servlet.jsp.tagext.BodyTag;
 import javax.servlet.jsp.tagext.Tag;
 
-import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.mock.web.test.MockBodyContent;
 import org.springframework.mock.web.test.MockPageContext;
+import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.validation.BeanPropertyBindingResult;
 import org.springframework.validation.BindingResult;
 import org.springframework.validation.Errors;
@@ -225,7 +225,7 @@ public class ErrorsTagTests extends AbstractFormTagTests {
 	}
 
 	public void testWithNonEscapedErrors() throws Exception {
-		this.tag.setHtmlEscape("false");
+		this.tag.setHtmlEscape(false);
 
 		// construct an errors instance of the tag
 		TestBean target = new TestBean();
