@@ -21,15 +21,14 @@ import java.beans.PropertyEditorSupport;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
-
 import javax.servlet.jsp.tagext.BodyTag;
 import javax.servlet.jsp.tagext.Tag;
 
-import org.springframework.tests.sample.beans.Colour;
-import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.beans.propertyeditors.StringArrayPropertyEditor;
 import org.springframework.mock.web.test.MockBodyContent;
 import org.springframework.mock.web.test.MockHttpServletRequest;
+import org.springframework.tests.sample.beans.Colour;
+import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.util.StringUtils;
 import org.springframework.validation.BeanPropertyBindingResult;
 import org.springframework.web.servlet.support.BindStatus;
@@ -78,7 +77,7 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 		getPageContext().setAttribute(SelectTag.LIST_VALUE_PAGE_ATTRIBUTE, new BindStatus(getRequestContext(), selectName, false));
 		this.tag.setValue("bar");
 		this.tag.setLabel("Bar");
-		this.tag.setDisabled("true");
+		this.tag.setDisabled(true);
 		int result = this.tag.doStartTag();
 		assertEquals(BodyTag.EVAL_BODY_BUFFERED, result);
 		result = this.tag.doEndTag();
@@ -186,59 +185,12 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 		try {
 			tag.doStartTag();
 			fail("Must not be able to use <option> tag without exposed context.");
-		}  catch (IllegalStateException ex) {
+		}
+		catch (IllegalStateException ex) {
 			// expected
 		}
 	}
 
-	public void testWithEnum() throws Exception {
-		String selectName = "testBean.favouriteColour";
-		getPageContext().setAttribute(SelectTag.LIST_VALUE_PAGE_ATTRIBUTE, new BindStatus(getRequestContext(), selectName, false));
-
-		String value = Colour.GREEN.getCode().toString();
-		String label = Colour.GREEN.getLabel();
-
-		this.tag.setValue(value);
-		this.tag.setLabel(label);
-
-		int result = this.tag.doStartTag();
-		assertEquals(BodyTag.EVAL_BODY_BUFFERED, result);
-		result = this.tag.doEndTag();
-		assertEquals(Tag.EVAL_PAGE, result);
-
-		String output = getOutput();
-
-		assertOptionTagOpened(output);
-		assertOptionTagClosed(output);
-		assertContainsAttribute(output, "value", value);
-		assertContainsAttribute(output, "selected", "selected");
-		assertBlockTagContains(output, label);
-	}
-
-	public void testWithEnumNotSelected() throws Exception {
-		String selectName = "testBean.favouriteColour";
-		getPageContext().setAttribute(SelectTag.LIST_VALUE_PAGE_ATTRIBUTE, new BindStatus(getRequestContext(), selectName, false));
-
-		String value = Colour.BLUE.getCode().toString();
-		String label = Colour.BLUE.getLabel();
-
-		this.tag.setValue(value);
-		this.tag.setLabel(label);
-
-		int result = this.tag.doStartTag();
-		assertEquals(BodyTag.EVAL_BODY_BUFFERED, result);
-		result = this.tag.doEndTag();
-		assertEquals(Tag.EVAL_PAGE, result);
-
-		String output = getOutput();
-
-		assertOptionTagOpened(output);
-		assertOptionTagClosed(output);
-		assertContainsAttribute(output, "value", value);
-		assertAttributeNotPresent(output, "selected");
-		assertBlockTagContains(output, label);
-	}
-
 	public void testWithPropertyEditor() throws Exception {
 		String selectName = "testBean.stringArray";
 		BindStatus bindStatus = new BindStatus(getRequestContext(), selectName, false) {
@@ -297,8 +249,8 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 	public void testWithCustomObjectSelected() throws Exception {
 		String selectName = "testBean.someNumber";
 		getPageContext().setAttribute(SelectTag.LIST_VALUE_PAGE_ATTRIBUTE, new BindStatus(getRequestContext(), selectName, false));
-		this.tag.setValue("${myNumber}");
-		this.tag.setLabel("GBP ${myNumber}");
+		this.tag.setValue(new Float(12.34));
+		this.tag.setLabel("GBP 12.34");
 		int result = this.tag.doStartTag();
 		assertEquals(BodyTag.EVAL_BODY_BUFFERED, result);
 		result = this.tag.doEndTag();
@@ -316,8 +268,8 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 	public void testWithCustomObjectNotSelected() throws Exception {
 		String selectName = "testBean.someNumber";
 		getPageContext().setAttribute(SelectTag.LIST_VALUE_PAGE_ATTRIBUTE, new BindStatus(getRequestContext(), selectName, false));
-		this.tag.setValue("${myOtherNumber}");
-		this.tag.setLabel("GBP ${myOtherNumber}");
+		this.tag.setValue(new Float(12.35));
+		this.tag.setLabel("GBP 12.35");
 		int result = this.tag.doStartTag();
 		assertEquals(BodyTag.EVAL_BODY_BUFFERED, result);
 		result = this.tag.doEndTag();
@@ -344,8 +296,8 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 		};
 		getPageContext().setAttribute(SelectTag.LIST_VALUE_PAGE_ATTRIBUTE, bindStatus);
 
-		this.tag.setValue("${myNumber}");
-		this.tag.setLabel("${myNumber}");
+		this.tag.setValue(new Float(12.34));
+		this.tag.setLabel("12.34f");
 
 		int result = this.tag.doStartTag();
 		assertEquals(BodyTag.EVAL_BODY_BUFFERED, result);
@@ -370,8 +322,8 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 		};
 		getPageContext().setAttribute(SelectTag.LIST_VALUE_PAGE_ATTRIBUTE, bindStatus);
 
-		this.tag.setValue("${myOtherNumber}");
-		this.tag.setLabel("${myOtherNumber}");
+		this.tag.setValue(new Float(12.35));
+		this.tag.setLabel("12.35f");
 
 		int result = this.tag.doStartTag();
 		assertEquals(BodyTag.EVAL_BODY_BUFFERED, result);
@@ -458,9 +410,7 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 		getPageContext().setAttribute(SelectTag.LIST_VALUE_PAGE_ATTRIBUTE, bindStatus);
 
 		RulesVariant rulesVariant = new RulesVariant("someRules", "someVariant");
-		getPageContext().getRequest().setAttribute("rule", rulesVariant);
-
-		this.tag.setValue("${rule}");
+		this.tag.setValue(rulesVariant);
 
 		int result = this.tag.doStartTag();
 		assertEquals(BodyTag.EVAL_BODY_BUFFERED, result);
@@ -522,8 +472,6 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 		bean.setFriends(friends);
 
 		request.setAttribute("testBean", bean);
-		request.setAttribute("myNumber", new Float(12.34));
-		request.setAttribute("myOtherNumber", new Float(12.35));
 	}
 
 
@@ -584,6 +532,7 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 			return new RulesVariant(rules, variant);
 		}
 
+		@Override
 		public boolean equals(Object obj) {
 			if (obj instanceof RulesVariant) {
 				RulesVariant other = (RulesVariant) obj;
@@ -592,6 +541,7 @@ public class OptionTagTests extends AbstractHtmlElementTagTests {
 			return false;
 		}
 
+		@Override
 		public int hashCode() {
 			return this.toId().hashCode();
 		}
