@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2014 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -38,11 +38,10 @@ import org.dom4j.DocumentException;
 import org.dom4j.Element;
 import org.dom4j.io.SAXReader;
 
-import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.beans.propertyeditors.CustomCollectionEditor;
 import org.springframework.format.Formatter;
 import org.springframework.format.support.FormattingConversionService;
-import org.springframework.mock.web.test.MockHttpServletRequest;
+import org.springframework.tests.sample.beans.TestBean;
 import org.springframework.validation.BeanPropertyBindingResult;
 import org.springframework.validation.BindingResult;
 import org.springframework.web.servlet.support.BindStatus;
@@ -129,7 +128,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 
 	public void testWithResolvedList() throws Exception {
 		this.tag.setPath("country");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		assertList(true);
 	}
 
@@ -151,7 +150,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 
 	public void testWithListAndNoLabel() throws Exception {
 		this.tag.setPath("country");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		int result = this.tag.doStartTag();
 		assertEquals(Tag.SKIP_BODY, result);
@@ -174,7 +173,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 
 	public void testWithListAndTransformTagAndEditor() throws Exception {
 		this.tag.setPath("realCountry");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		BeanPropertyBindingResult bindingResult = new BeanPropertyBindingResult(getTestBean(), "testBean");
 		bindingResult.getPropertyAccessor().registerCustomEditor(Country.class, new PropertyEditorSupport() {
 			@Override
@@ -195,14 +194,12 @@ public class SelectTagTests extends AbstractFormTagTests {
 		transformTag.setParent(this.tag);
 		transformTag.setPageContext(getPageContext());
 		transformTag.doStartTag();
-		String output = getOutput();
-		System.err.println(output);
 		assertEquals("Austria", getPageContext().findAttribute("key"));
 	}
 
 	public void testWithListAndEditor() throws Exception {
 		this.tag.setPath("realCountry");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		this.tag.setItemLabel("name");
 		BeanPropertyBindingResult bindingResult = new BeanPropertyBindingResult(getTestBean(), "testBean");
@@ -226,7 +223,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 
 	public void testNestedPathWithListAndEditorAndNullValue() throws Exception {
 		this.tag.setPath("bean.realCountry");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		this.tag.setItemLabel("name");
 		this.tag.setMultiple("false");
@@ -256,15 +253,15 @@ public class SelectTagTests extends AbstractFormTagTests {
 		getPageContext().getRequest().setAttribute(BindingResult.MODEL_KEY_PREFIX + "testBean", bindingResult);
 		this.tag.doStartTag();
 		String output = getOutput();
-		System.err.println(output);
 		assertTrue(output.startsWith("<select "));
 		assertTrue(output.endsWith("</select>"));
 		assertFalse(output.contains("selected=\"selected\""));
+		assertFalse(output.contains("multiple=\"multiple\""));
 	}
 
 	public void testNestedPathWithListAndEditor() throws Exception {
 		this.tag.setPath("bean.realCountry");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		this.tag.setItemLabel("name");
 		TestBeanWrapper testBean = new TestBeanWrapper();
@@ -290,7 +287,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 
 	public void testWithListAndEditorAndNullValue() throws Exception {
 		this.tag.setPath("realCountry");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		this.tag.setItemLabel("name");
 		TestBeanWithRealCountry testBean = (TestBeanWithRealCountry) getTestBean();
@@ -313,7 +310,6 @@ public class SelectTagTests extends AbstractFormTagTests {
 		getPageContext().getRequest().setAttribute(BindingResult.MODEL_KEY_PREFIX + "testBean", bindingResult);
 		this.tag.doStartTag();
 		String output = getOutput();
-		System.err.println(output);
 		assertTrue(output.startsWith("<select "));
 		assertTrue(output.endsWith("</select>"));
 		assertFalse(output.contains("selected=\"selected\""));
@@ -321,14 +317,14 @@ public class SelectTagTests extends AbstractFormTagTests {
 
 	public void testWithMap() throws Exception {
 		this.tag.setPath("sex");
-		this.tag.setItems("${sexes}");
+		this.tag.setItems(getSexes());
 		int result = this.tag.doStartTag();
 		assertEquals(Tag.SKIP_BODY, result);
 	}
 
 	public void testWithInvalidList() throws Exception {
 		this.tag.setPath("country");
-		this.tag.setItems("${other}");
+		this.tag.setItems(new TestBean());
 		this.tag.setItemValue("isoCode");
 		try {
 			this.tag.doStartTag();
@@ -336,8 +332,8 @@ public class SelectTagTests extends AbstractFormTagTests {
 		}
 		catch (JspException expected) {
 			String message = expected.getMessage();
-			assertTrue(message.indexOf("items") > -1);
-			assertTrue(message.indexOf("org.springframework.tests.sample.beans.TestBean") > -1);
+			assertTrue(message.contains("items"));
+			assertTrue(message.contains("org.springframework.tests.sample.beans.TestBean"));
 		}
 	}
 
@@ -367,7 +363,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 
 	public void testWithResolvedStringArray() throws Exception {
 		this.tag.setPath("name");
-		this.tag.setItems("${names}");
+		this.tag.setItems(getNames());
 		assertStringArray();
 	}
 
@@ -447,7 +443,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 		this.bean.setSomeList(list);
 
 		this.tag.setPath("someList");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		int result = this.tag.doStartTag();
 		assertEquals(Tag.SKIP_BODY, result);
@@ -495,7 +491,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 		exposeBindingResult(errors);
 
 		this.tag.setPath("realCountry");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		int result = this.tag.doStartTag();
 		assertEquals(Tag.SKIP_BODY, result);
@@ -542,7 +538,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 		exposeBindingResult(errors);
 
 		this.tag.setPath("someList");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		int result = this.tag.doStartTag();
 		assertEquals(Tag.SKIP_BODY, result);
@@ -587,7 +583,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 		exposeBindingResult(errors);
 
 		this.tag.setPath("someList");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		int result = this.tag.doStartTag();
 		assertEquals(Tag.SKIP_BODY, result);
@@ -621,7 +617,7 @@ public class SelectTagTests extends AbstractFormTagTests {
 		this.bean.setSomeMap(someMap);
 
 		this.tag.setPath("someMap");
-		this.tag.setItems("${sexes}");
+		this.tag.setItems(getSexes());
 
 		int result = this.tag.doStartTag();
 		assertEquals(Tag.SKIP_BODY, result);
@@ -665,7 +661,6 @@ public class SelectTagTests extends AbstractFormTagTests {
 	 * </ul>
 	 */
 	public void testWithMultiMapWithItemValueAndItemLabel() throws Exception {
-
 		// Save original default locale.
 		final Locale defaultLocale = Locale.getDefault();
 		// Use a locale that doesn't result in the generation of HTML entities
@@ -681,13 +676,12 @@ public class SelectTagTests extends AbstractFormTagTests {
 			this.bean.setSomeMap(someMap);
 
 			this.tag.setPath("someMap"); // see: TestBean
-			this.tag.setItems("${countryToLocaleMap}"); // see: extendRequest()
+			this.tag.setItems(getCountryToLocaleMap());
 			this.tag.setItemValue("isoCode"); // Map key: Country
 			this.tag.setItemLabel("displayLanguage"); // Map value: Locale
 
 			BeanPropertyBindingResult bindingResult = new BeanPropertyBindingResult(getTestBean(), COMMAND_NAME);
 			bindingResult.getPropertyAccessor().registerCustomEditor(Country.class, new PropertyEditorSupport() {
-
 				@Override
 				public void setAsText(final String text) throws IllegalArgumentException {
 					setValue(Country.getCountryWithIsoCode(text));
@@ -738,11 +732,11 @@ public class SelectTagTests extends AbstractFormTagTests {
 		}
 	}
 
-	public void testMultiWithEmptyCollection() throws Exception {
+	public void testMultipleForCollection() throws Exception {
 		this.bean.setSomeList(new ArrayList());
 
 		this.tag.setPath("someList");
-		this.tag.setItems("${countries}");
+		this.tag.setItems(Country.getCountries());
 		this.tag.setItemValue("isoCode");
 		int result = this.tag.doStartTag();
 		assertEquals(Tag.SKIP_BODY, result);
@@ -767,6 +761,140 @@ public class SelectTagTests extends AbstractFormTagTests {
 		assertNotNull(inputElement);
 	}
 
+	public void testMultipleWithStringValue() throws Exception {
+		this.tag.setPath("name");
+		this.tag.setItems(Country.getCountries());
+		this.tag.setItemValue("isoCode");
+		this.tag.setMultiple("multiple");
+		int result = this.tag.doStartTag();
+		assertEquals(Tag.SKIP_BODY, result);
+
+		String output = getOutput();
+		output = "<doc>" + output + "</doc>";
+
+		SAXReader reader = new SAXReader();
+		Document document = reader.read(new StringReader(output));
+		Element rootElement = document.getRootElement();
+		assertEquals(2, rootElement.elements().size());
+
+		Element selectElement = rootElement.element("select");
+		assertEquals("select", selectElement.getName());
+		assertEquals("name", selectElement.attribute("name").getValue());
+		assertEquals("multiple", selectElement.attribute("multiple").getValue());
+
+		List children = selectElement.elements();
+		assertEquals("Incorrect number of children", 4, children.size());
+
+		Element inputElement = rootElement.element("input");
+		assertNotNull(inputElement);
+	}
+
+	public void testMultipleExplicitlyTrue() throws Exception {
+		this.tag.setPath("name");
+		this.tag.setItems(Country.getCountries());
+		this.tag.setItemValue("isoCode");
+		this.tag.setMultiple("true");
+		int result = this.tag.doStartTag();
+		assertEquals(Tag.SKIP_BODY, result);
+
+		String output = getOutput();
+		output = "<doc>" + output + "</doc>";
+
+		SAXReader reader = new SAXReader();
+		Document document = reader.read(new StringReader(output));
+		Element rootElement = document.getRootElement();
+		assertEquals(2, rootElement.elements().size());
+
+		Element selectElement = rootElement.element("select");
+		assertEquals("select", selectElement.getName());
+		assertEquals("name", selectElement.attribute("name").getValue());
+		assertEquals("multiple", selectElement.attribute("multiple").getValue());
+
+		List children = selectElement.elements();
+		assertEquals("Incorrect number of children", 4, children.size());
+
+		Element inputElement = rootElement.element("input");
+		assertNotNull(inputElement);
+	}
+
+	public void testMultipleExplicitlyFalse() throws Exception {
+		this.tag.setPath("name");
+		this.tag.setItems(Country.getCountries());
+		this.tag.setItemValue("isoCode");
+		this.tag.setMultiple("false");
+		int result = this.tag.doStartTag();
+		assertEquals(Tag.SKIP_BODY, result);
+
+		String output = getOutput();
+		output = "<doc>" + output + "</doc>";
+
+		SAXReader reader = new SAXReader();
+		Document document = reader.read(new StringReader(output));
+		Element rootElement = document.getRootElement();
+		assertEquals(1, rootElement.elements().size());
+
+		Element selectElement = rootElement.element("select");
+		assertEquals("select", selectElement.getName());
+		assertEquals("name", selectElement.attribute("name").getValue());
+		assertNull(selectElement.attribute("multiple"));
+
+		List children = selectElement.elements();
+		assertEquals("Incorrect number of children", 4, children.size());
+	}
+
+	public void testMultipleWithBooleanTrue() throws Exception {
+		this.tag.setPath("name");
+		this.tag.setItems(Country.getCountries());
+		this.tag.setItemValue("isoCode");
+		this.tag.setMultiple(true);
+		int result = this.tag.doStartTag();
+		assertEquals(Tag.SKIP_BODY, result);
+
+		String output = getOutput();
+		output = "<doc>" + output + "</doc>";
+
+		SAXReader reader = new SAXReader();
+		Document document = reader.read(new StringReader(output));
+		Element rootElement = document.getRootElement();
+		assertEquals(2, rootElement.elements().size());
+
+		Element selectElement = rootElement.element("select");
+		assertEquals("select", selectElement.getName());
+		assertEquals("name", selectElement.attribute("name").getValue());
+		assertEquals("multiple", selectElement.attribute("multiple").getValue());
+
+		List children = selectElement.elements();
+		assertEquals("Incorrect number of children", 4, children.size());
+
+		Element inputElement = rootElement.element("input");
+		assertNotNull(inputElement);
+	}
+
+	public void testMultipleWithBooleanFalse() throws Exception {
+		this.tag.setPath("name");
+		this.tag.setItems(Country.getCountries());
+		this.tag.setItemValue("isoCode");
+		this.tag.setMultiple(false);
+		int result = this.tag.doStartTag();
+		assertEquals(Tag.SKIP_BODY, result);
+
+		String output = getOutput();
+		output = "<doc>" + output + "</doc>";
+
+		SAXReader reader = new SAXReader();
+		Document document = reader.read(new StringReader(output));
+		Element rootElement = document.getRootElement();
+		assertEquals(1, rootElement.elements().size());
+
+		Element selectElement = rootElement.element("select");
+		assertEquals("select", selectElement.getName());
+		assertEquals("name", selectElement.attribute("name").getValue());
+		assertNull(selectElement.attribute("multiple"));
+
+		List children = selectElement.elements();
+		assertEquals("Incorrect number of children", 4, children.size());
+	}
+
 
 	private void assertStringArray() throws JspException, DocumentException {
 		int result = this.tag.doStartTag();
@@ -807,22 +935,12 @@ public class SelectTagTests extends AbstractFormTagTests {
 	}
 
 	private Map getSexes() {
-		Map sexes = new HashMap();
+		Map<String, String> sexes = new HashMap<String, String>();
 		sexes.put("F", "Female");
 		sexes.put("M", "Male");
 		return sexes;
 	}
 
-	@Override
-	protected void extendRequest(MockHttpServletRequest request) {
-		super.extendRequest(request);
-		request.setAttribute("countries", Country.getCountries());
-		request.setAttribute("countryToLocaleMap", getCountryToLocaleMap());
-		request.setAttribute("sexes", getSexes());
-		request.setAttribute("other", new TestBean());
-		request.setAttribute("names", getNames());
-	}
-
 	private void assertList(boolean selected) throws JspException, DocumentException {
 		this.tag.setItemValue("isoCode");
 		this.tag.setItemLabel("name");
